@@ -39,7 +39,7 @@ public:
     /**
     * Default Constructor
     */
-    explicit HighlightedOperationSkroogoid(QObject* parent, const QVariantList& args);
+    explicit HighlightedOperationSkroogoid(QObject* iParent, const QVariantList& args);
 
     /**
      * Reimplemented from Plasma::Applet
