@@ -46,27 +46,21 @@ void SKGAdviceDataEngine::init()
 
 bool SKGAdviceDataEngine::updateSourceEvent(const QString& source)
 {
-
     if (source != "skrooge") {
         return false;
     }
 
-    //Get list of ignored advice
+    // Get list of ignored advice
     QString currentMonth = QDate::currentDate().toString("yyyy-MM");
     QStringList ignoredAdvice = document->getParameters("advice", "t_value='I' OR t_value='I_" % currentMonth % '\'');
 
-    //Build the list of all advice by requesting all plugins
+    // Build the list of all advice by requesting all plugins
     int index = 0;
     while (index >= 0) {
-
         SKGInterfacePlugin* plugin = SKGMainPanel::getMainPanel()->getPluginByIndex(index);
-
         if (plugin) {
-
             foreach(const SKGAdvice & advice, plugin->advice(ignoredAdvice)) {
-
                 if (!ignoredAdvice.contains(advice.getUUID()) && !ignoredAdvice.contains(SKGServices::splitCSVLine(advice.getUUID(), '|').at(0))) {
-
                     QVariantHash values;
                     values["priority"] = SKGServices::intToString(advice.getPriority());
                     values["shortMessage"] = advice.getShortMessage();
@@ -74,10 +68,11 @@ bool SKGAdviceDataEngine::updateSourceEvent(const QString& source)
                     values["correction"] = advice.getAutoCorrections();
 
                     setData("skrooge", advice.getUUID(), values);
-
                 }
             }
-        } else index = -2;
+        } else {
+            index = -2;
+        }
         ++index;
     }
 
