@@ -20,13 +20,15 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgdebugplugin.h"
+
+#include <KActionCollection>
+#include <KAboutData>
+#include <KGenericFactory>
+
 #include "skgdebugpluginwidget.h"
 #include "skgmainpanel.h"
 #include "skgtraces.h"
 
-#include <kactioncollection.h>
-#include <kaboutdata.h>
-#include <kgenericfactory.h>
 /**
  * This plugin factory.
  */
@@ -36,8 +38,9 @@ K_PLUGIN_FACTORY(SKGDebugPluginFactory, registerPlugin<SKGDebugPlugin>();)
  */
 K_EXPORT_PLUGIN(SKGDebugPluginFactory("skg_debug", "skg_debug"))
 
-SKGDebugPlugin::SKGDebugPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
+SKGDebugPlugin::SKGDebugPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
 {
+    Q_UNUSED(iWidget);
     SKGTRACEIN(10, "SKGDebugPlugin::SKGDebugPlugin");
 }
 
@@ -57,7 +60,7 @@ bool SKGDebugPlugin::setupActions(SKGDocument* iDocument, const QStringList& iAr
     setComponentData(KGlobal::mainComponent());
     setXMLFile("../skg_debug/skg_debug.rc");
 
-    //Menu
+    // Menu
     KAction* restartProfiling = new KAction(KIcon("fork"), i18nc("Restart the profiling, a method used for analysing performances", "Restart profiling"), this);
     connect(restartProfiling, SIGNAL(triggered(bool)), this, SLOT(onRestartProfiling()));
     restartProfiling->setShortcut(Qt::CTRL + Qt::Key_Pause);
@@ -110,7 +113,7 @@ void SKGDebugPlugin::onRestartProfiling()
 
 void SKGDebugPlugin::onOpenProfiling()
 {
-    //Call debug plugin
+    // Call debug plugin
     QString dumpString;
     QStringList dump = SKGTraces::getProfilingStatistics();
 
