@@ -20,17 +20,18 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgdebugpluginwidget.h"
+
+#include <Kross/Manager>
+#include <Kross/Action>
+
+#include <QDomDocument>
+
 #include "skgmainpanel.h"
 #include "skgdocument.h"
 #include "skgtransactionmng.h"
 #include "skgservices.h"
 #include "skgtraces.h"
 
-#include <kross/core/manager.h>
-#include <kross/core/action.h>
-
-#include <QDomDocument>
-
 SKGDebugPluginWidget::SKGDebugPluginWidget(SKGDocument* iDocument)
     : SKGTabPage(iDocument)
 {
@@ -39,12 +40,12 @@ SKGDebugPluginWidget::SKGDebugPluginWidget(SKGDocument* iDocument)
 
     ui.setupUi(this);
 
-    //Set icons
+    // Set icons
     ui.kSQLPushButton->setIcon(KIcon("system-run"));
     ui.kSQLTransactionPushButton->setIcon(KIcon("system-run"));
     ui.kRefreshViewsAndIndexes->setIcon(KIcon("view-refresh"));
 
-    //Fill combo box
+    // Fill combo box
     ui.kExplainCmb->addItem(KIcon("system-run"), i18nc("Execute an SQL query", "Execute"));
     ui.kExplainCmb->addItem(KIcon("help-hint"), i18nc("Explain an SQL query", "Explain"));
     ui.kExplainCmb->addItem(KIcon("games-hint"), i18nc("Explain the SQL query plan", "Explain query plan"));
@@ -53,31 +54,31 @@ SKGDebugPluginWidget::SKGDebugPluginWidget(SKGDocument* iDocument)
     }
     ui.kInput->setVisible(false);
 
-    //Set level trace
+    // Set level trace
     ui.kTraceLevel->setValue(SKGTraces::SKGLevelTrace);
 
-    //Set profiling mode
+    // Set profiling mode
     ui.kEnableProfilingChk->setCheckState(SKGTraces::SKGPerfo ? Qt::Checked : Qt::Unchecked);
 
-    //Init debug page
+    // Init debug page
     QStringList tables;
     ui.kSQLInput->addItem("SELECT * FROM sqlite_master;");
     iDocument->getDistinctValues("sqlite_master", "name", "type in ('table', 'view')", tables);
     int nb = tables.count();
     for (int i = 0; i < nb; ++i) {
-        ui.kSQLInput->addItem("SELECT * FROM " % tables[i] % ';');
+        ui.kSQLInput->addItem("SELECT * FROM " % tables.at(i) % ';');
     }
     ui.kSQLInput->addItem("ANALYZE;");
     ui.kSQLInput->addItem("PRAGMA integrity_check;");
     for (int i = 0; i < nb; ++i) {
-        ui.kSQLInput->addItem("PRAGMA table_info(" % tables[i] % ");");
-        ui.kSQLInput->addItem("PRAGMA index_list(" % tables[i] % ");");
+        ui.kSQLInput->addItem("PRAGMA table_info(" % tables.at(i) % ");");
+        ui.kSQLInput->addItem("PRAGMA index_list(" % tables.at(i) % ");");
     }
 
     iDocument->getDistinctValues("sqlite_master", "name", "type='index'", tables);
     nb = tables.count();
     for (int i = 0; i < nb; ++i) {
-        ui.kSQLInput->addItem("PRAGMA index_info(" % tables[i] % ");");
+        ui.kSQLInput->addItem("PRAGMA index_info(" % tables.at(i) % ");");
     }
 }
 
@@ -132,7 +133,7 @@ void SKGDebugPluginWidget::onExecuteSqlOrder(bool iInTransaction)
     SKGError err;
     int exp = ui.kExplainCmb->currentIndex();
     if (exp > 2) {
-        //Script execution
+        // Script execution
         ui.kSQLResult->clear();
         QString text = ui.kInput->toPlainText();
         Kross::Action action(this, "MyScript");
@@ -145,17 +146,19 @@ void SKGDebugPluginWidget::onExecuteSqlOrder(bool iInTransaction)
 
         action.addObject(ui.kSQLResult, "skgresult");
         action.addObject(getDocument(), "skgdocument");
-        //action.addObject(&err, "skgerror");
+        // action.addObject(&err, "skgerror");
         action.addObject(SKGMainPanel::getMainPanel(), "skgmainpanel");
 
         // Finally execute the scripting code.
-        //qScriptRegisterMetaType(action.engine(), SKGErrorToScriptValue, SKGErrorFromScriptValue);
+        // qScriptRegisterMetaType(action.engine(), SKGErrorToScriptValue, SKGErrorFromScriptValue);
         action.trigger();
     } else {
-        //SQL execution
+        // SQL execution
         QString text = ui.kSQLInput->currentText();
         if (exp == 1)  text = "EXPLAIN " % text;
-        else if (exp == 2)  text = "EXPLAIN QUERY PLAN " % text;
+        else if (exp == 2) {
+            text = "EXPLAIN QUERY PLAN " % text;
+        }
         QString oResult;
         double time = SKGServices::getMicroTime();
         if (iInTransaction) {
