@@ -20,29 +20,29 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgfileplugin.h"
-#include "skgfile_settings.h"
 
+#include <KActionCollection>
+#include <KStandardAction>
+#include <KRecentFilesAction>
+#include <KFileDialog>
+#include <KSplashScreen>
+#include <KCmdLineArgs>
+#include <KAboutData>
+#include <KNewPasswordDialog>
+#include <KPasswordDialog>
+#include <kwallet.h>
+#include <KGenericFactory>
+
+#include <QtGui/QWidget>
+#include <QFile>
+#include <KMessageWidget>
+
+#include "skgfile_settings.h"
 #include "skgtraces.h"
 #include "skgerror.h"
 #include "skgmainpanel.h"
 #include "skgtransactionmng.h"
 
-#include <kactioncollection.h>
-#include <kstandardaction.h>
-#include <krecentfilesaction.h>
-#include <kfiledialog.h>
-#include <ksplashscreen.h>
-#include <kcmdlineargs.h>
-#include <kaboutdata.h>
-#include <knewpassworddialog.h>
-#include <kpassworddialog.h>
-#include <kwallet.h>
-#include <kgenericfactory.h>
-
-#include <QtGui/QWidget>
-#include <QFile>
-#include <kmessagewidget.h>
-
 /**
  * This plugin factory.
  */
@@ -52,13 +52,14 @@ K_PLUGIN_FACTORY(SKGFilePluginFactory, registerPlugin<SKGFilePlugin>();)
  */
 K_EXPORT_PLUGIN(SKGFilePluginFactory("skg_file", "skg_file"))
 
-SKGFilePlugin::SKGFilePlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) :
+SKGFilePlugin::SKGFilePlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
     SKGInterfacePlugin(iParent),
     m_saveAction(NULL), m_saveAsAction(NULL), m_passwordAction(NULL), m_recentFiles(NULL), m_currentDocument(NULL)
 {
+    Q_UNUSED(iWidget);
     SKGTRACEIN(10, "SKGFilePlugin::SKGFilePlugin");
 
-    //Set save on close mode
+    // Set save on close mode
     SKGMainPanel::getMainPanel()->setSaveOnClose(skgfile_settings::saveonclose());
 }
 
@@ -84,7 +85,7 @@ bool SKGFilePlugin::setupActions(SKGDocument* iDocument, const QStringList& iArg
     setComponentData(KGlobal::mainComponent());
     setXMLFile("../skg_file/skg_file.rc");
 
-    //Menu
+    // Menu
     KAction* opennew = KStandardAction::openNew(this, SLOT(onNew()), actionCollection());
     registerGlobalAction("file_new", opennew);
 
@@ -102,15 +103,15 @@ bool SKGFilePlugin::setupActions(SKGDocument* iDocument, const QStringList& iArg
     m_passwordAction->setShortcut(Qt::CTRL + Qt::Key_K);
     registerGlobalAction("file_change_password", m_passwordAction);
 
-    //Recent file
+    // Recent file
     m_recentFiles = KStandardAction::openRecent(this, SLOT(onOpen(KUrl)), actionCollection());
     if (m_recentFiles) m_recentFiles->loadEntries(KConfigGroup(KGlobal::config(), "RecentFiles"));
 
-    //Get last argument
+    // Get last argument
     connect(this, SIGNAL(loadFile(KUrl)), this, SLOT(onOpen(KUrl)), Qt::QueuedConnection);
 
     int nbArg = iArgument.count();
-    int openMode = 1; //0=no open, 1=open last opened if settings set, 2=new document
+    int openMode = 1;  // 0=no open, 1=open last opened if settings set, 2=new document
     if (nbArg) {
         openMode = 2;
         QString filename = iArgument.at(nbArg - 1);
@@ -123,7 +124,7 @@ bool SKGFilePlugin::setupActions(SKGDocument* iDocument, const QStringList& iArg
     }
 
     if (openMode) {
-        //Read Setting
+        // Read Setting
         bool openlastfile = skgfile_settings::openlastfile();
         if (openMode == 1 && openlastfile) {
             SKGTRACEIN(10, "SKGFilePlugin::openlastfile");
@@ -134,7 +135,9 @@ bool SKGFilePlugin::setupActions(SKGDocument* iDocument, const QStringList& iArg
                     if (splashScreen) splashScreen->showMessage(i18nc("Splash screen message",  "Opening file %1...", lastOpenedFile), Qt::AlignLeft, QColor(221, 130, 8));          // krazy:exclude=qmethods
                 }
                 Q_EMIT loadFile(lastOpenedFile);
-            } else openMode = 2;
+            } else {
+                openMode = 2;
+            }
         }
 
         if (openMode == 2) {
@@ -142,15 +145,16 @@ bool SKGFilePlugin::setupActions(SKGDocument* iDocument, const QStringList& iArg
         }
     }
 
-    //To be sure that the document has the right parameters
+    // To be sure that the document has the right parameters
     savePreferences();
 
     return true;
 }
 
-void SKGFilePlugin::processArguments(const QStringList& iArgument)
+bool SKGFilePlugin::processArguments(const QStringList& iArgument)
 {
     SKGTRACEIN(10, "SKGFilePlugin::processArguments");
+    bool output = false;
     int nbArg = iArgument.count();
     if (nbArg && m_currentDocument) {
         QString filename = iArgument.at(nbArg - 1);
@@ -162,15 +166,17 @@ void SKGFilePlugin::processArguments(const QStringList& iArgument)
                 if (splashScreen) splashScreen->showMessage(i18nc("Splash screen message", "Opening file %1...", filename), Qt::AlignLeft, QColor(221, 130, 8));          // krazy:exclude=qmethods
             }
             Q_EMIT loadFile(filename);
+            output = true;
         }
     }
+    return output;
 }
 
 QWidget* SKGFilePlugin::getPreferenceWidget()
 {
     SKGTRACEIN(10, "SKGFilePlugin::getPreferenceWidget");
-    QWidget* widget = new QWidget();
-    ui.setupUi(widget);
+    QWidget* w = new QWidget();
+    ui.setupUi(w);
 
     ui.kcfg_prefix->addItem("");
     ui.kcfg_prefix->addItem(".");
@@ -183,7 +189,7 @@ QWidget* SKGFilePlugin::getPreferenceWidget()
 
     ui.kcfg_selectedWallet->addItems(KWallet::Wallet::walletList());
 
-    return widget;
+    return w;
 }
 
 KConfigSkeleton* SKGFilePlugin::getPreferenceSkeleton()
@@ -195,7 +201,7 @@ SKGError SKGFilePlugin::savePreferences() const
 {
     SKGError err;
     if (m_currentDocument) {
-        //Read Setting
+        // Read Setting
         QString prefix;
         QString suffix;
         if (skgfile_settings::backup_enabled()) {
@@ -203,10 +209,10 @@ SKGError SKGFilePlugin::savePreferences() const
             suffix = skgfile_settings::suffix();
         }
 
-        //Save setting in document
+        // Save setting in document
         m_currentDocument->setBackupParameters(prefix, suffix);
 
-        //Set save on close mode
+        // Set save on close mode
         SKGMainPanel::getMainPanel()->setSaveOnClose(skgfile_settings::saveonclose());
     }
     return err;
@@ -216,7 +222,7 @@ void SKGFilePlugin::refresh()
 {
     SKGTRACEIN(10, "SKGFilePlugin::refresh");
 
-    //Refresh action status
+    // Refresh action status
     if (m_currentDocument) {
         bool test = (m_currentDocument->getDatabase() != NULL);
         if (m_saveAction) m_saveAction->setEnabled(m_currentDocument->isFileModified());
@@ -250,7 +256,7 @@ QStringList SKGFilePlugin::tips() const
 
 int SKGFilePlugin::getOrder() const
 {
-    //Must be one of the first
+    // Must be one of the first
     return 1;
 }
 
@@ -269,11 +275,13 @@ void SKGFilePlugin::onNew()
         IFOKDO(err, m_currentDocument->setLanguage(loc->language()))
         QApplication::restoreOverrideCursor();
 
-        //status bar
+        // status bar
         IFOKDO(err, SKGError(0, i18nc("Successful message after creating a document", "Document successfully created.")))
-        else err.addError(ERR_FAIL, i18nc("Error message: Could not create a document",  "Document creation failed."));
+        else {
+            err.addError(ERR_FAIL, i18nc("Error message: Could not create a document",  "Document creation failed."));
+        }
 
-        //Display error
+        // Display error
         SKGMainPanel::displayErrorMessage(err);
     }
 }
@@ -289,14 +297,16 @@ void SKGFilePlugin::onSave()
             err = m_currentDocument->save();
             QApplication::restoreOverrideCursor();
 
-            //Refresh
+            // Refresh
             SKGMainPanel::getMainPanel()->refresh();
 
-            //status bar
+            // status bar
             IFOKDO(err, SKGError(0, i18nc("Successfully saved a file", "File successfully saved.")))
-            else err.addError(ERR_FAIL, i18nc("Error message: Could not save a file",  "Cannot save file"));
+            else {
+                err.addError(ERR_FAIL, i18nc("Error message: Could not save a file",  "Cannot save file"));
+            }
 
-            //Display error
+            // Display error
             SKGMainPanel::displayErrorMessage(err);
         }
     }
@@ -316,25 +326,27 @@ void SKGFilePlugin::onSaveAs()
         err = m_currentDocument->saveAs(fileName, true);
         QApplication::restoreOverrideCursor();
 
-        //Refresh
+        // Refresh
         SKGMainPanel::getMainPanel()->refresh();
 
-        //status bar
+        // status bar
         IFOK(err) {
             err = SKGError(0, i18nc("Successfully saved a file", "File '%1' saved.", fileName));
-            //Add in recentFiles
+            // Add in recentFiles
             if (m_recentFiles) {
                 m_recentFiles->addUrl(fileName);
                 m_recentFiles->saveEntries(KConfigGroup(KGlobal::config(), "RecentFiles"));
             }
-            //Set as last open file in kcfg
+            // Set as last open file in kcfg
             KSharedConfigPtr config = KSharedConfig::openConfig();
             KConfigGroup pref = config->group("File");
             pref.writePathEntry("lastfilepath", fileName);
 
-        } else err.addError(ERR_FAIL, i18nc("Error message: Could not save a file",  "Failed to save '%1'.", fileName));
+        } else {
+            err.addError(ERR_FAIL, i18nc("Error message: Could not save a file",  "Failed to save '%1'.", fileName));
+        }
 
-        //Display error
+        // Display error
         SKGMainPanel::displayErrorMessage(err);
     }
 }
@@ -362,7 +374,7 @@ void SKGFilePlugin::onOpen(const KUrl& iUrl)
                                                "*." % m_currentDocument->getFileExtension() % '|' % i18nc("Associated with the file extension : for example, .csv --> CSV document", "%1 document", programName) ,
                                                SKGMainPanel::getMainPanel()).pathOrUrl();
         if (!fileName.isEmpty()) {
-            //Check if temporary file exists
+            // Check if temporary file exists
             bool restoreTmpFile = false;
             QString tmpFile = SKGDocument::getTemporaryFile(fileName);
             if (QFile(tmpFile).exists()) {
@@ -377,7 +389,7 @@ void SKGFilePlugin::onOpen(const KUrl& iUrl)
                 restoreTmpFile = true;
             }
 
-            //Open
+            // Open
             QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
             SKGMainPanel::getMainPanel()->closeAllPages(true);
             err = m_currentDocument->load(fileName, "", restoreTmpFile);
@@ -386,27 +398,27 @@ void SKGFilePlugin::onOpen(const KUrl& iUrl)
             if (err && err.getReturnCode() == ERR_ENCRYPTION) {
                 m_currentDocument->close();
 
-                //Open failed
-                //Password must be asked
+                // Open failed
+                // Password must be asked
                 QString additionalMessage;
                 do {
-                    //Reset error
+                    // Reset error
                     err = SKGError(0, "");
                     pwd = "";
 
-                    //Get password
+                    // Get password
                     if (useKWallet) {
                         SKGTRACEINRC(10, "SKGFilePlugin::onOpen-get kwallet passport", err);
-                        //Use KWallet
+                        // Use KWallet
                         QString walletName = KWallet::Wallet::walletList().value(SKGServices::stringToInt(skgfile_settings::selectedWallet()));
                         if (walletName.isEmpty()) walletName = "kdewallet";
                         KWallet::Wallet* w = KWallet::Wallet::openWallet(walletName, SKGMainPanel::getMainPanel()->winId());
                         if (w) {
-                            //Change folder
+                            // Change folder
                             if (!w->hasFolder(programName)) w->createFolder(programName);
                             w->setFolder(programName);
 
-                            //Read password
+                            // Read password
                             w->readPassword(fileName, pwd);
                             if (pwd.isEmpty()) useKWallet = false;
 
@@ -416,14 +428,14 @@ void SKGFilePlugin::onOpen(const KUrl& iUrl)
                     }
 
                     if (!useKWallet) {
-                        //Use password dialog
+                        // Use password dialog
                         QPointer<KPasswordDialog> dlg = new KPasswordDialog(SKGMainPanel::getMainPanel());
                         dlg->setPrompt(additionalMessage % i18nc("Question", "This file seems to be protected.\nPlease enter the password."));
                         if (dlg->exec() == QDialog::Accepted) pwd = dlg->password();
                         delete dlg;
                     }
 
-                    //Load file
+                    // Load file
                     if (!pwd.isEmpty()) {
                         KSplashScreen* splashScreen = SKGMainPanel::getMainPanel()->splashScreen();
                         if (splashScreen) splashScreen->hide();
@@ -435,7 +447,7 @@ void SKGFilePlugin::onOpen(const KUrl& iUrl)
                                 additionalMessage = i18nc("The user did not provide the correct password", "<b>Wrong password.</b>\n");
                                 useKWallet = false;
                             } else {
-                                //Load error
+                                // Load error
                                 QApplication::restoreOverrideCursor();
                                 break;
                             }
@@ -450,30 +462,30 @@ void SKGFilePlugin::onOpen(const KUrl& iUrl)
             KLocale* loc = KGlobal::locale();
             IFOKDO(err, m_currentDocument->setLanguage(loc->language()))
 
-            //status bar
+            // status bar
             IFOK(err) {
                 err = SKGError(0, i18nc("Successfully opened a file", "File '%1' opened.", fileName));
-                //Add in recentFiles
+                // Add in recentFiles
                 if (m_recentFiles) {
                     m_recentFiles->addUrl(fileName);
                     m_recentFiles->saveEntries(KConfigGroup(KGlobal::config(), "RecentFiles"));
                 }
-                //Set as last open file in kcfg
+                // Set as last open file in kcfg
                 KSharedConfigPtr config = KSharedConfig::openConfig();
                 KConfigGroup pref = config->group("File");
                 pref.writePathEntry("lastfilepath", fileName);
 
-                //Store password if KDE wallet if needed
+                // Store password if KDE wallet if needed
                 if (skgfile_settings::storeInKdeWallet() && !useKWallet) {
-                    //Use KWallet
+                    // Use KWallet
                     QString walletName = KWallet::Wallet::walletList().value(SKGServices::stringToInt(skgfile_settings::selectedWallet()));
                     if (walletName.isEmpty()) walletName = "kdewallet";
                     KWallet::Wallet* w = KWallet::Wallet::openWallet(walletName, SKGMainPanel::getMainPanel()->winId());
                     if (w) {
-                        //Change folder
+                        // Change folder
                         w->setFolder(programName);
 
-                        //Write password
+                        // Write password
                         w->writePassword(fileName, pwd);
 
                         delete w;
@@ -485,7 +497,7 @@ void SKGFilePlugin::onOpen(const KUrl& iUrl)
                 err.addError(ERR_FAIL, i18nc("Error message: Could not open a file",  "Failed to open '%1'.", fileName));
             }
 
-            //Display error
+            // Display error
             SKGMainPanel::displayErrorMessage(err);
         }
     }
@@ -503,13 +515,15 @@ void SKGFilePlugin::onChangePassword()
             SKGBEGINLIGHTTRANSACTION(*m_currentDocument, i18nc("Action allowing user to change the document password", "Change password"), err);
             err = m_currentDocument->changePassword(dlg->password());
 
-            //status
+            // status
             IFOKDO(err, SKGError(0, i18nc("Successfully changed the document password", "Password changed.")))
-            else err.addError(ERR_FAIL, i18nc("Error message: Could not change the document password",  "Failed to change password."));
+            else {
+                err.addError(ERR_FAIL, i18nc("Error message: Could not change the document password",  "Failed to change password."));
+            }
         }
         delete dlg;
 
-        //Display error
+        // Display error
         SKGMainPanel::displayErrorMessage(err);
     }
 }
@@ -519,7 +533,7 @@ SKGAdviceList SKGFilePlugin::advice(const QStringList& iIgnoredAdvice)
     SKGTRACEIN(10, "SKGFilePlugin::advice");
     SKGAdviceList output;
 
-    //Backup
+    // Backup
     if (!iIgnoredAdvice.contains("skgfileplugin_notvalidated")) {
         SKGAdvice ad;
         ad.setUUID("skgfileplugin_notvalidated");
