@@ -20,15 +20,16 @@
  * @author Stephane MANKOWSKI
  */
 #include "skghighlightplugin.h"
+
+#include <KActionCollection>
+#include <KStandardAction>
+#include <KAboutData>
+#include <KGenericFactory>
+
 #include "skgtraces.h"
 #include "skgmainpanel.h"
 #include "skgtransactionmng.h"
 
-#include <kactioncollection.h>
-#include <kstandardaction.h>
-#include <kaboutdata.h>
-#include <kgenericfactory.h>
-
 /**
  * This plugin factory.
  */
@@ -38,10 +39,11 @@ K_PLUGIN_FACTORY(SKGHighlightPluginFactory, registerPlugin<SKGHighlightPlugin>()
  */
 K_EXPORT_PLUGIN(SKGHighlightPluginFactory("skg_highlight", "skg_highlight"))
 
-SKGHighlightPlugin::SKGHighlightPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) :
+SKGHighlightPlugin::SKGHighlightPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
     SKGInterfacePlugin(iParent),
     m_currentDocument(NULL), m_switchHighLight(NULL)
 {
+    Q_UNUSED(iWidget);
     SKGTRACEIN(10, "SKGHighlightPlugin::SKGHighlightPlugin");
 }
 
@@ -62,14 +64,14 @@ bool SKGHighlightPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     setComponentData(KGlobal::mainComponent());
     setXMLFile("../skg_highlight/skg_highlight.rc");
 
-    //------------
+    // ------------
     m_switchHighLight = new KAction(KIcon("bookmarks"), i18nc("Verb", "Switch highlight"), this);
     connect(m_switchHighLight, SIGNAL(triggered(bool)), this, SLOT(onSwitchHighLight()));
     m_switchHighLight->setShortcut(Qt::CTRL + Qt::Key_H);
     registerGlobalAction("edit_switch_highlight", m_switchHighLight);
 
 
-    //Create yours actions here
+    // Create yours actions here
     return true;
 }
 
@@ -110,7 +112,7 @@ void SKGHighlightPlugin::onSwitchHighLight()
 {
     SKGError err;
     SKGTRACEINRC(10, "SKGHighlightPlugin::onSwitchHighLight", err);
-    //Get Selection
+    // Get Selection
     if (SKGMainPanel::getMainPanel() && m_currentDocument) {
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
         int nb = selection.count();
@@ -124,11 +126,13 @@ void SKGHighlightPlugin::onSwitchHighLight()
             }
         }
 
-        //status bar
+        // status bar
         IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Highlighted.")))
-        else err.addError(ERR_FAIL, i18nc("Error message",  "Highlight failed"));
+        else {
+            err.addError(ERR_FAIL, i18nc("Error message",  "Highlight failed"));
+        }
 
-        //Display error
+        // Display error
         SKGMainPanel::displayErrorMessage(err);
     }
 }
