@@ -20,6 +20,15 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgimportplugingnc.h"
+
+#include <KLocale>
+#include <KFilterDev>
+#include <KGenericFactory>
+
+#include <QDomDocument>
+#include <QFileInfo>
+#include <cmath>
+
 #include "skgtraces.h"
 #include "skgservices.h"
 #include "skgbankincludes.h"
@@ -27,14 +36,6 @@
 #include "skgpayeeobject.h"
 #include "skgimportexportmanager.h"
 
-#include <klocale.h>
-#include <kfilterdev.h>
-#include <kgenericfactory.h>
-
-#include <QDomDocument>
-#include <QFileInfo>
-#include <cmath>
-
 #ifdef Q_OS_WIN
 #define isnan(a) _isnan(a)
 #define isinf(a) !_finite(a)
@@ -77,13 +78,13 @@ SKGError SKGImportPluginGnc::importFile()
     SKGError err;
     SKGTRACEINRC(2, "SKGImportPluginGnc::importFile(", err);
 
-    //Open file
+    // Open file
     QIODevice* file = KFilterDev::deviceForFile(m_importer->getLocalFileName(), "application/x-gzip");
     if (!file->open(QIODevice::ReadOnly)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
     else {
         QDomDocument doc;
 
-        //Set the file without uncompression
+        // Set the file without uncompression
         QString errorMsg;
         int errorLine = 0;
         int errorCol = 0;
@@ -92,10 +93,10 @@ SKGError SKGImportPluginGnc::importFile()
 
         if (!contentOK) err.setReturnCode(ERR_ABORT).setMessage(i18nc("Error message",  "%1-%2: '%3'", errorLine, errorCol, errorMsg)).addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName().prettyUrl()));
         else {
-            //Get root
+            // Get root
             QDomElement docElem = doc.documentElement();
 
-            ////Get book
+            // // Get book
             QDomElement book = docElem.firstChildElement("gnc:book");
             if (book.isNull()) {
                 book = docElem;
@@ -106,7 +107,7 @@ SKGError SKGImportPluginGnc::importFile()
                 QMap<QString, SKGUnitObject> mapUnitIdUnit;
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "GNC"), 6);
                 IFOK(err) {
-                    //Step 1-Get units
+                    // Step 1-Get units
                     SKGUnitObject defaultUnit;
                     {
                         QDomNodeList unitList = book.elementsByTagName("gnc:commodity");
@@ -119,12 +120,12 @@ SKGError SKGImportPluginGnc::importFile()
                             if (!unitName.isNull() && !unitSpace.isNull()) {
                                 SKGUnitObject unitObj(m_importer->getDocument());
                                 if (unitSpace.text() == "ISO4217") {
-                                    //We try a creation
+                                    // We try a creation
                                     SKGUnitObject::createCurrencyUnit(m_importer->getDocument(), unitName.text(), unitObj);
                                 }
 
                                 if (!err && !unitObj.exist()) {
-                                    //Creation of unit
+                                    // Creation of unit
                                     err = unitObj.setName(unitName.text());
                                     IFOKDO(err, unitObj.setSymbol(unitName.text()))
                                     IFOKDO(err, unitObj.setType(SKGUnitObject::SHARE))
@@ -143,7 +144,7 @@ SKGError SKGImportPluginGnc::importFile()
                     }
                     IFOKDO(err, m_importer->getDocument()->stepForward(1))
 
-                    //Step 2-Get accounts and categories
+                    // Step 2-Get accounts and categories
                     SKGAccountObject gnucashTemporaryAccount(m_importer->getDocument());
                     QMap<QString, QString> mapIdName;
                     QMap<QString, QChar> mapIdType;
@@ -151,7 +152,7 @@ SKGError SKGImportPluginGnc::importFile()
                     QMap<QString, SKGAccountObject> mapIdAccount;
                     QMap<QString, SKGCategoryObject> mapIdCategory;
 
-                    //Create bank and temporary account for gnucash import
+                    // Create bank and temporary account for gnucash import
                     SKGBankObject bank(m_importer->getDocument());
                     IFOKDO(err, m_importer->getDocument()->addOrModifyAccount("GNUCASH-TEMPORARY-ACCOUNT", "", "GNUCASH"))
                     IFOKDO(err, bank.setName("GNUCASH"))
@@ -160,7 +161,7 @@ SKGError SKGImportPluginGnc::importFile()
                     IFOKDO(err, gnucashTemporaryAccount.load())
 
                     {
-                        //Create accounts
+                        // Create accounts
                         QDomNodeList accountList = book.elementsByTagName("gnc:account");
                         int nbAccount = accountList.count();
                         IFOKDO(err, m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import banks and accounts"), nbAccount))
@@ -178,7 +179,7 @@ SKGError SKGImportPluginGnc::importFile()
                                 if (!accountId.isNull() && !accountType.isNull() && !realAccountName.isEmpty()) {
                                     QString type = accountType.text();
                                     if (type == "INCOME" || type == "EXPENSE") {
-                                        //It is a category
+                                        // It is a category
                                         QString fullName = realAccountName;
 
                                         QDomElement accountParent = account.firstChildElement("act:parent");
@@ -189,9 +190,19 @@ SKGError SKGImportPluginGnc::importFile()
                                         err = SKGCategoryObject::createPathCategory(m_importer->getDocument(), fullName, catObj);
 
                                         mapIdCategory[accountId.text()] = catObj;
-                                        mapIdType[accountId.text()] = 'C'; //Memorize an account
-                                    } else if (type == "BANK" || type == "STOCK" || type == "ASSET" || type == "LIABILITY" || type == "RECEIVABLE" || type == "CREDITCARD" || type == "CASH") {
-                                        //It is a real account
+                                        mapIdType[accountId.text()] = 'C';  // Memorize an account
+                                    } else if (type == "BANK" ||
+                                               type == "CREDIT" ||
+                                               type == "STOCK" ||
+                                               type == "ASSET" ||
+                                               type == "LIABILITY" ||
+                                               type == "RECEIVABLE" ||
+                                               type == "PAYABLE" ||
+                                               type == "TRADING" ||
+                                               type == "CREDITCARD" ||
+                                               type == "CASH" ||
+                                               type == "MUTUAL") {
+                                        // It is a real account
                                         SKGAccountObject act(m_importer->getDocument());
                                         err = bank.addAccount(act);
                                         IFOKDO(err, act.setName(realAccountName))
@@ -202,18 +213,22 @@ SKGError SKGImportPluginGnc::importFile()
                                             err = act.setName(realAccountName);
                                         }
                                         if (!err && accountCode.isNull()) err = act.setNumber(accountCode.text());
-                                        IFOKDO(err, act.setType(type == "ASSET" ? SKGAccountObject::ASSETS : type == "STOCK" ? SKGAccountObject::INVESTMENT : type == "CASH" ? SKGAccountObject::WALLET : type == "LIABILITY" ? SKGAccountObject::LOAN : SKGAccountObject::CURRENT))
+                                        IFOKDO(err, act.setType(type == "ASSET" ? SKGAccountObject::ASSETS :
+                                                                type == "STOCK" || type == "MUTUAL" || type == "RECEIVABLE" || type == "PAYABLE" || type == "TRADING" ? SKGAccountObject::INVESTMENT :
+                                                                type == "CASH" ? SKGAccountObject::WALLET :
+                                                                type == "LIABILITY" ? SKGAccountObject::LOAN :
+                                                                type == "CREDIT" ? SKGAccountObject::CREDITCARD : SKGAccountObject::CURRENT))
                                         IFOKDO(err, act.save())
 
                                         mapIdAccount[accountId.text()] = act;
-                                        mapIdType[accountId.text()] = 'A'; //Memorize an account
+                                        mapIdType[accountId.text()] = 'A';  // Memorize an account
 
                                         QDomNodeList accountUnits = account.elementsByTagName("cmdty:id");
                                         if (!err && accountUnits.count()) mapIdUnit[accountId.text()] = mapUnitIdUnit[accountUnits.at(0).toElement().text()];
                                     } else if (type == "EQUITY") {
-                                        mapIdType[accountId.text()] = 'E'; //Memorize an account
+                                        mapIdType[accountId.text()] = 'E';  // Memorize an account
                                     } else {
-                                        mapIdType[accountId.text()] = ' '; //Memorize an account
+                                        mapIdType[accountId.text()] = ' ';  // Memorize an account
                                     }
 
 
@@ -228,7 +243,7 @@ SKGError SKGImportPluginGnc::importFile()
                     }
                     IFOKDO(err, m_importer->getDocument()->stepForward(2))
 
-                    //Step 3- Get operations
+                    // Step 3- Get operations
                     QMap<QString, SKGOperationObject> mapIdScheduledOperation;
                     {
                         QDomNodeList operationsList = book.elementsByTagName("gnc:transaction");
@@ -246,7 +261,7 @@ SKGError SKGImportPluginGnc::importFile()
                             SKGOperationObject operationObj;
                             err = gnucashTemporaryAccount.addOperation(operationObj, true);
                             if (!err && !operationDate.isNull()) {
-                                //Format 2007-01-13 00:00:00 +0100
+                                // Format 2007-01-13 00:00:00 +0100
                                 err = operationObj.setDate(QDate::fromString(operationDate.text().left(10), "yyyy-MM-dd"));
                             }
                             if (!err && !operationNumber.isNull()) err = operationObj.setNumber(SKGServices::stringToInt(operationNumber.text()));
@@ -280,7 +295,7 @@ SKGError SKGImportPluginGnc::importFile()
                             }
                             IFOKDO(err, operationObj.save())
 
-                            //Get splits
+                            // Get splits
                             bool parentSet = false;
                             double quantity = 0;
                             QDomElement splits = operation.firstChildElement("trn:splits");
@@ -298,8 +313,11 @@ SKGError SKGImportPluginGnc::importFile()
                                     info.account = info.subOp.firstChildElement("split:account");
                                     info.value = 0;
                                     QStringList vals = SKGServices::splitCSVLine(info.subOp.firstChildElement("split:quantity").text(), '/');
-                                    if (vals.count() == 1) info.value = SKGServices::stringToDouble(vals.at(0));
-                                    else if (vals.count() == 2) info.value = SKGServices::stringToDouble(vals.at(0)) / SKGServices::stringToDouble(vals.at(1));
+                                    if (vals.count() == 1) {
+                                        info.value = SKGServices::stringToDouble(vals.at(0));
+                                    } else if (vals.count() == 2) {
+                                        info.value = SKGServices::stringToDouble(vals.at(0)) / SKGServices::stringToDouble(vals.at(1));
+                                    }
 
                                     QDomElement suboperationSlots = info.subOp.firstChildElement("split:slots");
                                     if (!suboperationSlots.isNull()) {
@@ -312,7 +330,7 @@ SKGError SKGImportPluginGnc::importFile()
                                             QDomElement value = slot.firstChildElement("slot:value");
                                             if (!key.isNull() && !value.isNull()) {
                                                 if (key.text() == "sched-xaction") {
-                                                    //This is a scheduled operation
+                                                    // This is a scheduled operation
                                                     QDomNodeList scheduledSlotList = value.elementsByTagName("slot");
                                                     int nbscheduledSlotList = scheduledSlotList.count();
                                                     for (int k2 = 0; !err && k2 < nbscheduledSlotList; ++k2) {
@@ -326,12 +344,18 @@ SKGError SKGImportPluginGnc::importFile()
                                                                 info.account = value2;
                                                             } else if (key2.text() == "debit-formula" && !value2.text().isEmpty()) {
                                                                 QStringList vals2 = SKGServices::splitCSVLine(value2.text(), '/');
-                                                                if (vals2.count() == 1) info.value = SKGServices::stringToDouble(vals2.at(0));
-                                                                else if (vals2.count() == 2) info.value = SKGServices::stringToDouble(vals2.at(0)) / SKGServices::stringToDouble(vals2.at(1));
+                                                                if (vals2.count() == 1) {
+                                                                    info.value = SKGServices::stringToDouble(vals2.at(0));
+                                                                } else if (vals2.count() == 2) {
+                                                                    info.value = SKGServices::stringToDouble(vals2.at(0)) / SKGServices::stringToDouble(vals2.at(1));
+                                                                }
                                                             } else if (key2.text() == "credit-formula" && !value2.text().isEmpty()) {
                                                                 QStringList vals2 = SKGServices::splitCSVLine(value2.text(), '/');
-                                                                if (vals2.count() == 1) info.value = -SKGServices::stringToDouble(vals2.at(0));
-                                                                else if (vals2.count() == 2) info.value = -SKGServices::stringToDouble(vals2.at(0)) / SKGServices::stringToDouble(vals2.at(1));
+                                                                if (vals2.count() == 1) {
+                                                                    info.value = -SKGServices::stringToDouble(vals2.at(0));
+                                                                } else if (vals2.count() == 2) {
+                                                                    info.value = -SKGServices::stringToDouble(vals2.at(0)) / SKGServices::stringToDouble(vals2.at(1));
+                                                                }
                                                             }
                                                         }
                                                     }
@@ -362,7 +386,7 @@ SKGError SKGImportPluginGnc::importFile()
                                 QDomElement suboperationMemo = suboperation.firstChildElement("split:memo");
                                 QDomElement suboperationAction = suboperation.firstChildElement("split:action");
 
-                                //Set operation attribute
+                                // Set operation attribute
                                 if (!suboperationReconciled.isNull() && operationObj.getStatus() == SKGOperationObject::NONE) {
                                     QString val = suboperationReconciled.text();
                                     IFOKDO(err, operationObj.setStatus(val == "c" ? SKGOperationObject::POINTED : val == "y" ? SKGOperationObject::CHECKED : SKGOperationObject::NONE))
@@ -373,7 +397,7 @@ SKGError SKGImportPluginGnc::importFile()
 
                                 QChar accountType = mapIdType[suboperationInfo.account.text()];
                                 if (accountType == 'C') {
-                                    //It is a split on category
+                                    // It is a split on category
                                     SKGCategoryObject cat = mapIdCategory[suboperationInfo.account.text()];
 
                                     double q = -suboperationInfo.value;
@@ -383,21 +407,21 @@ SKGError SKGImportPluginGnc::importFile()
                                     if (!err && !suboperationMemo.isNull()) err = suboperationObj.setComment(suboperationMemo.text());
                                     IFOKDO(err, suboperationObj.save())
                                 } else if (accountType == 'E') {
-                                    //Set as initial balance
+                                    // Set as initial balance
                                     IFOKDO(err, operationObj.setAttribute("d_date", "0000-00-00"))
                                     IFOKDO(err, operationObj.setStatus(SKGOperationObject::CHECKED))
                                     IFOKDO(err, operationObj.save())
                                 } else if (accountType == 'A') {
-                                    //It is a transfer of account
+                                    // It is a transfer of account
                                     SKGAccountObject act(m_importer->getDocument());
                                     IFOKDO(err, act.setName(mapIdName[suboperationInfo.account.text()]))
                                     IFOKDO(err, act.load())
 
-                                    //Set Unit
+                                    // Set Unit
                                     SKGUnitObject unitName = mapIdUnit[suboperationInfo.account.text()];
 
                                     if (parentSet) {
-                                        //If the parent is already set, it means that is a transfer
+                                        // If the parent is already set, it means that is a transfer
                                         SKGOperationObject operationObj2;
                                         IFOKDO(err, act.addOperation(operationObj2, true))
                                         IFOKDO(err, operationObj2.setDate(operationObj.getDate()))
@@ -419,26 +443,26 @@ SKGError SKGImportPluginGnc::importFile()
                                         IFOKDO(err, operationObj2.setGroupOperation(operationObj))
                                         IFOKDO(err, operationObj2.save())
 
-                                        //Create sub operation on operationObj2
+                                        // Create sub operation on operationObj2
                                         SKGSubOperationObject suboperationObj2;
                                         IFOKDO(err, operationObj2.addSubOperation(suboperationObj2))
                                         IFOK(err) {
-                                            //We must take the quality of the split having an action
+                                            // We must take the quality of the split having an action
                                             quantity = suboperationInfo.value;
                                             err = suboperationObj2.setQuantity(suboperationInfo.value);
                                         }
                                         if (!err && !suboperationMemo.isNull()) err = suboperationObj2.setComment(suboperationMemo.text());
                                         IFOKDO(err, suboperationObj2.save())
                                     } else {
-                                        //We set the parent
+                                        // We set the parent
                                         IFOKDO(err, operationObj.setParentAccount(act))
                                         if (!err && unitName.exist()) err = operationObj.setUnit(unitName);
                                         IFOKDO(err, operationObj.save())
 
-                                        //Compute quantity
+                                        // Compute quantity
                                         quantity = suboperationInfo.value;
 
-                                        //Create sub operation on operationObj
+                                        // Create sub operation on operationObj
                                         quantity -= SKGServices::stringToDouble(operationObj.getAttribute("f_QUANTITY"));
                                         if (fabs(quantity) > 10e-9) {
                                             IFOKDO(err, operationObj.addSubOperation(suboperationObj))
@@ -461,9 +485,9 @@ SKGError SKGImportPluginGnc::importFile()
                     }
                     IFOKDO(err, m_importer->getDocument()->stepForward(3))
 
-                    //Step 4-Get scheduled
+                    // Step 4-Get scheduled
                     {
-                        //Create scheduled
+                        // Create scheduled
                         QDomNodeList scheduleList = book.elementsByTagName("gnc:schedxaction");
                         int nbSchedule = scheduleList.count();
                         IFOKDO(err, m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import scheduled operations"), nbSchedule))
@@ -507,8 +531,11 @@ SKGError SKGImportPluginGnc::importFile()
                                 if (!err && !scheduleMult.isNull() && !schedulePeriod.isNull()) {
                                     int p = SKGServices::stringToInt(scheduleMult.text());
                                     SKGRecurrentOperationObject::PeriodUnit punit = SKGRecurrentOperationObject::DAY;
-                                    if (schedulePeriod.text() == "month") punit = SKGRecurrentOperationObject::MONTH;
-                                    else if (schedulePeriod.text() == "week") punit = SKGRecurrentOperationObject::WEEK;
+                                    if (schedulePeriod.text() == "month") {
+                                        punit = SKGRecurrentOperationObject::MONTH;
+                                    } else if (schedulePeriod.text() == "week") {
+                                        punit = SKGRecurrentOperationObject::WEEK;
+                                    }
 
                                     err = recuOperation.setPeriodIncrement(p);
                                     IFOKDO(err, recuOperation.setPeriodUnit(punit))
@@ -531,9 +558,9 @@ SKGError SKGImportPluginGnc::importFile()
                     }
                     IFOKDO(err, m_importer->getDocument()->stepForward(4))
 
-                    //Step 5-Get unit values
+                    // Step 5-Get unit values
                     {
-                        //Create unit values
+                        // Create unit values
                         QDomElement pricedb = book.firstChildElement("gnc:pricedb");
                         if (!pricedb.isNull()) {
                             QDomNodeList priceList = pricedb.elementsByTagName("price");
@@ -552,22 +579,23 @@ SKGError SKGImportPluginGnc::importFile()
 
                                     double val = 0;
                                     QStringList vals = SKGServices::splitCSVLine(priceValue.text(), '/');
-                                    if (vals.count() == 1) val = SKGServices::stringToDouble(vals.at(0));
-                                    else if (vals.count() == 2) val = SKGServices::stringToDouble(vals.at(0)) / SKGServices::stringToDouble(vals.at(1));
+                                    if (vals.count() == 1) {
+                                        val = SKGServices::stringToDouble(vals.at(0));
+                                    } else if (vals.count() == 2) {
+                                        val = SKGServices::stringToDouble(vals.at(0)) / SKGServices::stringToDouble(vals.at(1));
+                                    }
 
                                     err = m_importer->getDocument()->addOrModifyUnitValue(unitName, unitDate, val);
-
                                 }
 
                                 IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                             }
-
                             SKGENDTRANSACTION(m_importer->getDocument(),  err);
                         }
                     }
                     IFOKDO(err, m_importer->getDocument()->stepForward(5))
 
-                    //Step 6-Remove useless account and temporary account
+                    // Step 6-Remove useless account and temporary account
                     {
                         IFOKDO(err, gnucashTemporaryAccount.remove(false, true))
 
