@@ -20,6 +20,14 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgimportplugingsb.h"
+
+#include <KLocale>
+#include <KFilterDev>
+#include <KGenericFactory>
+
+#include <QDomDocument>
+#include <QFileInfo>
+
 #include "skgtraces.h"
 #include "skgservices.h"
 #include "skgbankincludes.h"
@@ -27,13 +35,6 @@
 #include "skgimportexportmanager.h"
 #include "skgpayeeobject.h"
 
-#include <klocale.h>
-#include <kfilterdev.h>
-#include <kgenericfactory.h>
-
-#include <QDomDocument>
-#include <qfileinfo.h>
-
 /**
  * This plugin factory.
  */
@@ -65,26 +66,26 @@ SKGError SKGImportPluginGsb::importFile()
     SKGError err;
     SKGTRACEINRC(2, "SKGImportPluginGsb::importFile", err);
 
-    //Initialisation
-    //Open file
+    // Initialisation
+    // Open file
     QIODevice* file = KFilterDev::deviceForFile(m_importer->getLocalFileName(), "application/x-gzip");
     if (!file->open(QIODevice::ReadOnly)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
     else {
         QDomDocument doc;
 
-        //Set the file without uncompression
+        // Set the file without uncompression
         QString errorMsg;
         int errorLine = 0;
         int errorCol = 0;
         bool contentOK = doc.setContent(file->readAll(), &errorMsg, &errorLine, &errorCol);
         file->close();
 
-        //Get root
+        // Get root
         QDomElement docElem = doc.documentElement();
 
         if (!contentOK) err.setReturnCode(ERR_ABORT).setMessage(i18nc("Error message",  "%1-%2: '%3'", errorLine, errorCol, errorMsg));
         else {
-            //Check version
+            // Check version
             QDomElement general = docElem.firstChildElement("General");
             if (general.isNull()) {
                 err.setReturnCode(ERR_ABORT).setMessage(i18nc("Error message",  "Bad version of Grisbi document. Version must be >= 0.6.0"));
@@ -105,18 +106,18 @@ SKGError SKGImportPluginGsb::importFile()
             QMap<QString, QString> mapIdMode;
             QMap<QString, QString> mapIdBudgetCat;
 
-            //Specifications: http://wiki.grisbi.org/doku.php?id=docs:dev:format_gsb
+            // Specifications: http://wiki.grisbi.org/doku.php?id=docs:dev:format_gsb
 
-            //Step 1-Create units
+            // Step 1-Create units
             IFOK(err) {
                 QDomNodeList currencyList = docElem.elementsByTagName("Currency");
                 int nb = currencyList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import units"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
-                    //Get account object
+                    // Get account object
                     QDomElement currency = currencyList.at(i).toElement();
 
-                    //Creation of the units
+                    // Creation of the units
                     SKGUnitObject unitObj(m_importer->getDocument());
                     IFOKDO(err, unitObj.setName(getAttribute(currency,  "Na")))
                     IFOKDO(err, unitObj.setSymbol(getAttribute(currency,  "Co")))
@@ -132,16 +133,16 @@ SKGError SKGImportPluginGsb::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(1))
 
-            //Step 2-Create banks
+            // Step 2-Create banks
             IFOK(err) {
                 QDomNodeList bankList = docElem.elementsByTagName("Bank");
                 int nb = bankList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import banks"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
-                    //Get account object
+                    // Get account object
                     QDomElement bank = bankList.at(i).toElement();
 
-                    //Creation of the banks
+                    // Creation of the banks
                     SKGBankObject bankObj(m_importer->getDocument());
                     IFOKDO(err, bankObj.setName(getAttribute(bank,  "Na")))
                     IFOKDO(err, bankObj.setNumber(getAttribute(bank,  "BIC")))
@@ -156,7 +157,7 @@ SKGError SKGImportPluginGsb::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(2))
 
-            //Step 3-Create accounts
+            // Step 3-Create accounts
             SKGBankObject bankDefault(m_importer->getDocument());
             IFOKDO(err, bankDefault.setName("GRISBI"))
             IFOKDO(err, bankDefault.save())
@@ -165,10 +166,10 @@ SKGError SKGImportPluginGsb::importFile()
                 int nb = accountList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import accounts"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
-                    //Get account object
+                    // Get account object
                     QDomElement account = accountList.at(i).toElement();
 
-                    //Creation of the account
+                    // Creation of the account
                     SKGAccountObject accountObj;
                     SKGBankObject bank = mapIdBank[getAttribute(account,  "Bank")];
                     if (!bank.exist()) bank = bankDefault;
@@ -192,13 +193,13 @@ SKGError SKGImportPluginGsb::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(3))
 
-            //Step 4-Get payees
+            // Step 4-Get payees
             IFOK(err) {
                 QDomNodeList partyList = docElem.elementsByTagName("Party");
                 int nb = partyList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import payees"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
-                    //Get payee object
+                    // Get payee object
                     QDomElement party = partyList.at(i).toElement();
                     SKGPayeeObject payeeObject;
                     err = SKGPayeeObject::createPayee(m_importer->getDocument(), getAttribute(party,  "Na"), payeeObject);
@@ -211,13 +212,13 @@ SKGError SKGImportPluginGsb::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(4))
 
-            //Step 5-Get payement mode
+            // Step 5-Get payement mode
             IFOK(err) {
                 QDomNodeList paymentList = docElem.elementsByTagName("Payment");
                 int nb = paymentList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import payment mode"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
-                    //Get mode object
+                    // Get mode object
                     QDomElement payment = paymentList.at(i).toElement();
                     mapIdMode[getAttribute(payment,  "Number")] = getAttribute(payment,  "Name");
 
@@ -228,16 +229,16 @@ SKGError SKGImportPluginGsb::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(5))
 
-            //Step 6-Create categories
+            // Step 6-Create categories
             IFOK(err) {
                 QDomNodeList categoryList = docElem.elementsByTagName("Category");
                 int nb = categoryList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import categories"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
-                    //Get account object
+                    // Get account object
                     QDomElement category = categoryList.at(i).toElement();
 
-                    //Creation of the categories
+                    // Creation of the categories
                     SKGCategoryObject catObj(m_importer->getDocument());
                     IFOKDO(err, catObj.setName(getAttribute(category,  "Na")))
                     IFOKDO(err, catObj.save())
@@ -252,16 +253,16 @@ SKGError SKGImportPluginGsb::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(6))
 
-            //Step 7-Create subcategories
+            // Step 7-Create subcategories
             IFOK(err) {
                 QDomNodeList categoryList = docElem.elementsByTagName("Sub_category");
                 int nb = categoryList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import categories"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
-                    //Get account object
+                    // Get account object
                     QDomElement category = categoryList.at(i).toElement();
 
-                    //Creation of the subcategories
+                    // Creation of the subcategories
                     SKGCategoryObject catParentObj = mapIdCategory[SKGServices::intToString(10000 * SKGServices::stringToInt(getAttribute(category,  "Nbc")))];
                     SKGCategoryObject catObj;
                     IFOKDO(err, catParentObj.addCategory(catObj))
@@ -278,12 +279,12 @@ SKGError SKGImportPluginGsb::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(7))
 
-            //Step 8-Index of budget categories
+            // Step 8-Index of budget categories
             IFOK(err) {
                 QDomNodeList budgetaryList = docElem.elementsByTagName("Budgetary");
                 int nb = budgetaryList.count();
                 for (int i = 0; !err && i < nb; ++i) {
-                    //Get account object
+                    // Get account object
                     QDomElement budgetary = budgetaryList.at(i).toElement();
                     QString id = SKGServices::intToString(10000 * SKGServices::stringToInt(getAttribute(budgetary,  "Nb")));
                     mapIdBudgetCat[id] = getAttribute(budgetary,  "Na");
@@ -293,7 +294,7 @@ SKGError SKGImportPluginGsb::importFile()
                 QDomNodeList budgetaryList = docElem.elementsByTagName("Sub_budgetary");
                 int nb = budgetaryList.count();
                 for (int i = 0; !err && i < nb; ++i) {
-                    //Get account object
+                    // Get account object
                     QDomElement budgetary = budgetaryList.at(i).toElement();
                     QString id1 = SKGServices::intToString(10000 * SKGServices::stringToInt(getAttribute(budgetary,  "Nb")));
                     QString id = SKGServices::intToString(10000 * SKGServices::stringToInt(getAttribute(budgetary,  "Nbb")) + SKGServices::stringToInt(getAttribute(budgetary,  "Nb")));
@@ -302,16 +303,16 @@ SKGError SKGImportPluginGsb::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(8))
 
-            //Step 9-Create transaction
+            // Step 9-Create transaction
             IFOK(err) {
                 QDomNodeList transactionList = docElem.elementsByTagName("Transaction");
                 int nb = transactionList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
-                    //Get account object
+                    // Get account object
                     QDomElement transaction = transactionList.at(i).toElement();
 
-                    //Creation of the operation
+                    // Creation of the operation
                     SKGOperationObject opObj;
                     QString parentOpId = getAttribute(transaction,  "Mo");
                     if (parentOpId == "0") {
@@ -332,7 +333,7 @@ SKGError SKGImportPluginGsb::importFile()
                         opObj = mapIdOperation[parentOpId];
                     }
 
-                    //Budgetary allocation
+                    // Budgetary allocation
                     IFOK(err) {
                         int sbu = SKGServices::stringToInt(getAttribute(transaction,  "Sbu"));
                         QString id = SKGServices::intToString(10000 * SKGServices::stringToInt(getAttribute(transaction,  "Bu")) + qMax(sbu, 0));
@@ -343,7 +344,7 @@ SKGError SKGImportPluginGsb::importFile()
                         }
                     }
 
-                    //Fiscal year
+                    // Fiscal year
                     IFOK(err) {
                         QString fiscalYear = getAttribute(transaction,  "Vo");
                         if (!fiscalYear.isEmpty()) {
@@ -372,16 +373,16 @@ SKGError SKGImportPluginGsb::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(9))
 
-            //Step 10-Create scheduled transaction
+            // Step 10-Create scheduled transaction
             IFOK(err) {
                 QDomNodeList scheduledList = docElem.elementsByTagName("Scheduled");
                 int nb = scheduledList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import scheduled operations"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
-                    //Get account object
+                    // Get account object
                     QDomElement transaction = scheduledList.at(i).toElement();
 
-                    //Creation of the operation
+                    // Creation of the operation
                     SKGAccountObject account = mapIdAccount[getAttribute(transaction,  "Ac")];
                     SKGOperationObject opObj;
                     IFOKDO(err, account.addOperation(opObj, true))
@@ -407,7 +408,7 @@ SKGError SKGImportPluginGsb::importFile()
 
                     QString Tra = getAttribute(transaction,  "Tra");
                     if (Tra != "0") {
-                        //This is a transfer
+                        // This is a transfer
                         SKGOperationObject opObj2;
                         IFOKDO(err, opObj.duplicate(opObj2, opObj.getDate(), true))
                         IFOKDO(err, opObj2.setImported(true))
@@ -422,18 +423,18 @@ SKGError SKGImportPluginGsb::importFile()
                             IFOKDO(err, subObj2.save())
                         }
 
-                        //Group operations
+                        // Group operations
                         IFOKDO(err, opObj.setGroupOperation(opObj2))
                         IFOKDO(err, opObj.save())
                     }
 
-                    //Create the schedule
+                    // Create the schedule
                     SKGRecurrentOperationObject recuObj;
                     IFOKDO(err, opObj.addRecurrentOperation(recuObj))
                     IFOKDO(err, recuObj.setAutoWriteDays(0))
                     IFOKDO(err, recuObj.autoWriteEnabled(getAttribute(transaction,  "Au") != "0"))
                     IFOK(err) {
-                        //text_frequency [] = { _("Once"), _("Weekly"), _("Monthly"), _("two months"), ("trimester"), _("Yearly"), _("Custom"), NULL };
+                        // text_frequency [] = { _("Once"), _("Weekly"), _("Monthly"), _("two months"), ("trimester"), _("Yearly"), _("Custom"), NULL };
                         int occu = 1;
                         SKGRecurrentOperationObject::PeriodUnit period = SKGRecurrentOperationObject::DAY;
                         QString Pe = getAttribute(transaction,  "Pe");
@@ -455,13 +456,17 @@ SKGError SKGImportPluginGsb::importFile()
                         } else if (Pe == "5") {
                             period = SKGRecurrentOperationObject::YEAR;
                         } else if (Pe == "6") {
-                            //text_frequency_user [] = { _("Days"), _("Weeks"), _("Months"), _("Years"), NULL };
+                            // text_frequency_user [] = { _("Days"), _("Weeks"), _("Months"), _("Years"), NULL };
                             occu = SKGServices::stringToInt(getAttribute(transaction,  "Pep"));
                             QString Pei = getAttribute(transaction,  "Pei");
                             if (Pei == "0") period = SKGRecurrentOperationObject::DAY;
-                            else if (Pei == "1") period = SKGRecurrentOperationObject::WEEK;
-                            else if (Pei == "2") period = SKGRecurrentOperationObject::MONTH;
-                            else period = SKGRecurrentOperationObject::YEAR;
+                            else if (Pei == "1") {
+                                period = SKGRecurrentOperationObject::WEEK;
+                            } else if (Pei == "2") {
+                                period = SKGRecurrentOperationObject::MONTH;
+                            } else {
+                                period = SKGRecurrentOperationObject::YEAR;
+                            }
                         }
 
                         IFOKDO(err, recuObj.setPeriodUnit(period))
