@@ -20,6 +20,16 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgbankpluginwidget.h"
+
+#include <KStandardDirs>
+#include <KMessageBox>
+#include <KFileDialog>
+
+#include <QDomDocument>
+#include <QFile>
+#include <QDir>
+#include <QKeyEvent>
+
 #include "skgmainpanel.h"
 #include "skgobjectmodel.h"
 #include "skgtransactionmng.h"
@@ -32,15 +42,6 @@
 #include "skgtablewithgraph.h"
 #include "skgboardwidget.h"
 
-#include <kstandarddirs.h>
-#include <kmessagebox.h>
-#include <kfiledialog.h>
-
-#include <QDomDocument>
-#include <QFile>
-#include <QDir>
-#include <QKeyEvent>
-
 SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
     : SKGTabPage(iDocument)
 {
@@ -49,12 +50,12 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
 
     ui.setupUi(this);
 
-    //Add report
+    // Add report
     SKGInterfacePlugin* reportPlugin = SKGMainPanel::getMainPanel()->getPluginByName("Skrooge report plugin");
     if (reportPlugin) {
         m_graph = reportPlugin->getDashboardWidget(0);
         if (m_graph) {
-            //To avoid hidden page when no account exist
+            // To avoid hidden page when no account exist
             QWidget* w = new QWidget(this);
             QVBoxLayout* verticalLayout = new QVBoxLayout(w);
             verticalLayout->addWidget(m_graph);
@@ -62,7 +63,7 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
             m_graph->hideTitle();
 
             ui.verticalLayout->insertWidget(2, w);
-            //Set initial state
+            // Set initial state
             m_graph->hide();
 
             QDomDocument doc1("SKGML");
@@ -102,7 +103,7 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
         }
     }
 
-    //Set label titles
+    // Set label titles
     ui.kAccountLbl->setText(i18n("%1:", iDocument->getDisplay("t_ACCOUNT")));
     ui.kTypeLbl->setText(i18n("%1:", iDocument->getDisplay("t_type")));
     ui.kBankNumberLbl->setText(i18n("%1:", iDocument->getDisplay("t_bank_number")));
@@ -115,7 +116,7 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
 
     ui.kUnitEdit->setDocument(iDocument);
 
-    //Set show widget
+    // Set show widget
     ui.kView->getShowWidget()->addGroupedItem("all", i18n("All"));
     ui.kView->getShowWidget()->addGroupedItem("opened", i18n("Opened"), "", "t_close='N'");
     ui.kView->getShowWidget()->addGroupedItem("closed", i18n("Closed"), "dialog-close", "t_close='Y'");
@@ -130,7 +131,7 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
     m_timer.setSingleShot(true);
     connect(&m_timer, SIGNAL(timeout()), this, SLOT(refreshInfoZone()), Qt::QueuedConnection);
 
-    //Add Standard KDE Icons to buttons to Accounts
+    // Add Standard KDE Icons to buttons to Accounts
     ui.kAccountCreatorUpdate->setIcon(KIcon("dialog-ok-apply"));
     ui.kAccountCreatorAdd->setIcon(KIcon("list-add"));
 
@@ -139,21 +140,22 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
     list.push_back(ui.SKGEditionButtonswidget);
     ui.kWidgetSelector->addButton(KIcon("configure"), i18n("Edit"), i18n("Display the account edit panel"), list);
 
-    //Add NLS values for type of account
-    //C=current D=credit card P=passif (for objects) I=Investment O=other
+    // Add NLS values for type of account
+    // C=current D=credit card P=passif (for objects) I=Investment O=other
     ui.kAccountCreatorType->addItem(KIcon("view-bank-account-savings"), i18nc("Noun, a type of account", "Current"), SKGAccountObject::CURRENT);
     ui.kAccountCreatorType->addItem(KIcon("view-credit-card-account"), i18nc("Noun, a type of account", "Credit card"), SKGAccountObject::CREDITCARD);
     ui.kAccountCreatorType->addItem(KIcon("view-bank-account-savings"), i18nc("Noun, a type of account", "Saving"), SKGAccountObject::SAVING);
     ui.kAccountCreatorType->addItem(KIcon("view-stock-account"), i18nc("Noun, a type of account", "Investment"), SKGAccountObject::INVESTMENT);
     ui.kAccountCreatorType->addItem(KIcon("view-loan-asset"), i18nc("Noun, a type of account", "Assets"), SKGAccountObject::ASSETS);
     ui.kAccountCreatorType->addItem(KIcon("view-loan-asset"), i18nc("Noun, a type of account", "Loan"), SKGAccountObject::LOAN);
+    ui.kAccountCreatorType->addItem(KIcon("view-loan-asset"), i18nc("Noun, a type of account", "Pension"), SKGAccountObject::PENSION);
     ui.kAccountCreatorType->addItem(KIcon("kwalletmanager"), i18nc("Noun, a type of account", "Wallet"), SKGAccountObject::WALLET);
     ui.kAccountCreatorType->addItem(i18nc("Noun, a type of account", "Other"), SKGAccountObject::OTHER);
 
-    //Bind account creation view
+    // Bind account creation view
     ui.kView->setModel(new SKGObjectModel(static_cast<SKGDocumentBank*>(getDocument()), "v_account_display", "1=0", this, "", false));
 
-    //Add registered global action in contextual menu
+    // Add registered global action in contextual menu
     if (SKGMainPanel::getMainPanel()) {
         ui.kView->getView()->insertGlobalAction();
         ui.kView->getView()->insertGlobalAction("open");
@@ -169,11 +171,11 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
     connect(ui.kView->getView(), SIGNAL(doubleClicked(QModelIndex)), SKGMainPanel::getMainPanel()->getGlobalAction("open"), SLOT(trigger()));
     connect(ui.kView->getView(), SIGNAL(selectionChangedDelayed()), this, SLOT(onSelectionChanged()));
 
-    //Search file list
+    // Search file list
     QString listIconFile = KStandardDirs::locate("data", "skrooge/images/logo/l10n/" % KGlobal::locale()->country() % "/list_bank.txt");
     if (listIconFile.isEmpty()) listIconFile = KStandardDirs::locate("data", "skrooge/images/logo/list_bank.txt");
 
-    //Logo for banks
+    // Logo for banks
     ui.kAccountCreatorIcon->addItem("");
     QFile file(listIconFile);
     if (file.open(QIODevice::ReadOnly | QIODevice::Text)) {
@@ -189,7 +191,7 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
 
                 QRegExp rx("(.+) {2,}(.+)");
                 if (rx.indexIn(bankName) != -1) {
-                    //Icon is something like <bank name>__<banknumber>.png
+                    // Icon is something like <bank name>__<banknumber>.png
                     ui.kAccountCreatorIcon->addItem(QIcon(dirLogo.absoluteFilePath(line)), rx.cap(1), rx.cap(2));
                 } else {
                     ui.kAccountCreatorIcon->addItem(QIcon(dirLogo.absoluteFilePath(line)), bankName, "");
@@ -201,13 +203,13 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
         file.close();
     }
 
-    //Set Event filters to catch CTRL+ENTER or SHIFT+ENTER
+    // Set Event filters to catch CTRL+ENTER or SHIFT+ENTER
     this->installEventFilter(this);
 
     // Activate the edit panel per default
     ui.kWidgetSelector->setSelectedMode(0);
 
-    //Refresh
+    // Refresh
     connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
     dataModified("", 0);
 }
@@ -217,11 +219,11 @@ SKGBankPluginWidget::~SKGBankPluginWidget()
     SKGTRACEIN(10, "SKGBankPluginWidget::~SKGBankPluginWidget");
 }
 
-bool SKGBankPluginWidget::eventFilter(QObject* object, QEvent* event)
+bool SKGBankPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 {
-    if (event && event->type() == QEvent::KeyPress) {
-        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
-        if ((keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && object == this) {
+    if (iEvent && iEvent->type() == QEvent::KeyPress) {
+        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(iEvent);
+        if ((keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && iObject == this) {
             if (QApplication::keyboardModifiers() &Qt::ControlModifier && ui.kAccountCreatorAdd->isEnabled()) {
                 ui.kAccountCreatorAdd->click();
             } else if (QApplication::keyboardModifiers() &Qt::ShiftModifier && ui.kAccountCreatorUpdate->isEnabled()) {
@@ -236,10 +238,10 @@ bool SKGBankPluginWidget::eventFilter(QObject* object, QEvent* event)
 void SKGBankPluginWidget::onSelectionChanged()
 {
     SKGTRACEIN(10, "SKGBankPluginWidget::onSelectionChanged");
-    //Mapping
+    // Mapping
     int nbSelect = ui.kView->getView()->getNbSelectedObjects();
     if (nbSelect == 1) {
-        //set the icon
+        // set the icon
         SKGAccountObject account(ui.kView->getView()->getFirstSelectedObject());
         SKGBankObject bank;
         account.getBank(bank);
@@ -254,15 +256,18 @@ void SKGBankPluginWidget::onSelectionChanged()
                 iconName = rx.cap(1);
             }
             if (ui.kAccountCreatorIcon->contains(iconName)) ui.kAccountCreatorIcon->setText(iconName);
-            else if (ui.kAccountCreatorIcon->contains(fileName)) ui.kAccountCreatorIcon->setText(fileName);
-            else {
+            else if (ui.kAccountCreatorIcon->contains(fileName)) {
+                ui.kAccountCreatorIcon->setText(fileName);
+            } else {
                 int c = ui.kAccountCreatorIcon->count() - 1;
                 bool b = ui.kAccountCreatorIcon->blockSignals(true);
                 ui.kAccountCreatorIcon->insertItem(c, QIcon(fileName), fileName);
                 ui.kAccountCreatorIcon->setCurrentIndex(c);
                 ui.kAccountCreatorIcon->blockSignals(b);
             }
-        } else ui.kAccountCreatorIcon->setText("");
+        } else {
+            ui.kAccountCreatorIcon->setText("");
+        }
 
         ui.kAccountCreatorBank->setText(account.getAttribute("t_BANK"));
         ui.kAccountCreatorAccount->setText(account.getAttribute("t_name"));
@@ -316,7 +321,7 @@ void SKGBankPluginWidget::onSelectionChanged()
         ui.kMinLimit->setCheckState(Qt::PartiallyChecked);
     }
 
-    //Refresh graph
+    // Refresh graph
     m_timer2.start(300);
 
     onAccountCreatorModified();
@@ -358,7 +363,9 @@ void SKGBankPluginWidget::onRefreshGraph()
                         }
                         wc += ')';
                     }
-                } else wc = "1=0";
+                } else {
+                    wc = "1=0";
+                }
                 root2.setAttribute("operationWhereClause", wc);
                 root2.setAttribute("title", title);
                 root2.setAttribute("lines", nbSelect ? "t_ACCOUNT" : "#NOTHING#");
@@ -387,13 +394,25 @@ void SKGBankPluginWidget::onIconChanged()
                 ui.kAccountCreatorIcon->setCurrentIndex(c);
                 ui.kAccountCreatorIcon->blockSignals(b);
             }
-        } else ui.kAccountCreatorIcon->setCurrentIndex(c - 1);
+        } else {
+            ui.kAccountCreatorIcon->setCurrentIndex(c - 1);
+        }
     }
 
-    ui.kAccountCreatorBank->setText(ui.kAccountCreatorIcon->currentIndex() != 0 ? ui.kAccountCreatorIcon->currentText() : "");
+    if (ui.kAccountCreatorIcon->currentIndex() != 0) {
+        // Set the bank name
+        QString name = ui.kAccountCreatorIcon->currentText();
+        QFileInfo f(name);
+        if (f.exists()) {
+            name = f.baseName();
+            name = name.replace('_', ' ');
+        }
+        ui.kAccountCreatorBank->setText(name);
+    } else {
+        ui.kAccountCreatorBank->setText("");
+    }
 }
 
-
 void SKGBankPluginWidget::onAccountCreatorModified()
 {
     SKGTRACEIN(10, "SKGBankPluginWidget::onAccountCreatorModified");
@@ -410,14 +429,14 @@ void SKGBankPluginWidget::onAccountCreatorModified()
     ui.kAccountCreatorAdd->setEnabled(activated || (wallet && activatedForWallet));
     ui.kAccountCreatorUpdate->setEnabled((activated || (wallet && activatedForWallet)) && nbSelect > 0);
 
-    //Wallet specific mode
+    // Wallet specific mode
     ui.kNumeroFrm->setVisible(!wallet);
     ui.kBankFrm->setVisible(!wallet);
     ui.kBankLbl->setVisible(!wallet);
     ui.kAccountCreatorAddress->setVisible(!wallet);
     ui.kAgencyAddressLbl->setVisible(!wallet);
 
-    //Facilitate bank number
+    // Facilitate bank number
     if (ui.kAccountCreatorBankNumber->text().isEmpty()) {
         QString code = ui.kAccountCreatorIcon->itemData(ui.kAccountCreatorIcon->currentIndex()).toString();
         ui.kAccountCreatorBankNumber->setText(code);
@@ -444,11 +463,11 @@ void SKGBankPluginWidget::onAddAccountClicked()
         {
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Creating an account", "Account creation '%1'", name), err);
 
-            //Create bank object in case of missing
+            // Create bank object in case of missing
             SKGBankObject bankObj(getDocument());
             IFOKDO(err, bankObj.setName(ui.kAccountCreatorBank->text()))
             IFOK(err) {
-                //Build icon name
+                // Build icon name
                 QString icon = ui.kAccountCreatorIcon->currentText();
                 if (!QFile(icon).exists() && !icon.isEmpty()) {
                     QString code = ui.kAccountCreatorIcon->itemData(ui.kAccountCreatorIcon->currentIndex()).toString();
@@ -464,7 +483,7 @@ void SKGBankPluginWidget::onAddAccountClicked()
             IFOKDO(err, bankObj.save())
             IFOKDO(err, bankObj.load())
 
-            //Create account object in case of missing
+            // Create account object in case of missing
             IFOKDO(err, bankObj.addAccount(accountObj))
             IFOKDO(err, accountObj.setName(accountName))
             IFOKDO(err, accountObj.setAgencyNumber(ui.kAccountCreatorAgencyNumber->text()))
@@ -484,14 +503,16 @@ void SKGBankPluginWidget::onAddAccountClicked()
             IFOKDO(err, accountObj.save())
         }
 
-        //status bar
+        // status bar
         IFOK(err) {
             err = SKGError(0, i18nc("Successfully created an account", "Account '%1' created", name));
             ui.kView->getView()->selectObject(accountObj.getUniqueID());
-        } else err.addError(ERR_FAIL, i18nc("Error message : Could not create an account",  "Account creation failed"));
+        } else {
+            err.addError(ERR_FAIL, i18nc("Error message : Could not create an account",  "Account creation failed"));
+        }
     }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
@@ -500,24 +521,24 @@ void SKGBankPluginWidget::onModifyAccountClicked()
     SKGError err;
     SKGTRACEINRC(10, "SKGBankPluginWidget::onModifyAccountClicked", err);
     {
-        //Get Selection
+        // Get Selection
         SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
 
         int nb = selection.count();
 
-        //Is it a massive modification of accounts to merge them ?
+        // Is it a massive modification of accounts to merge them ?
         SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Updating an account", "Account update"), err, nb);
         if (nb > 1 && ui.kAccountCreatorAccount->text() != NOUPDATE && !ui.kAccountCreatorAccount->text().startsWith(QLatin1String(" = "))) {
             getDocument()->sendMessage(i18nc("Information message", "You tried to modify all names of selected accounts. Accounts have been merged."));
 
-            //Do the merge
+            // Do the merge
             SKGAccountObject accountObj1(selection[0]);
             for (int i = 1; !err && i < nb; ++i) {
                 SKGAccountObject accountObj(selection[i]);
                 err = accountObj1.merge(accountObj);
             }
 
-            //Change selection for the rest of the operation
+            // Change selection for the rest of the operation
             selection.clear();
             selection.push_back(accountObj1);
             nb = 1;
@@ -545,17 +566,17 @@ void SKGBankPluginWidget::onModifyAccountClicked()
 
             IFOKDO(err, accountObj.save())
 
-            //Update bank
+            // Update bank
             SKGBankObject bankObj;
             if (bankName == NOUPDATE) {
                 accountObj.getBank(bankObj);
             } else {
                 if (SKGNamedObject::getObjectByName(getDocument(), "bank", bankName, bankObj).isSucceeded()) {
-                    //The created bank already exist ==> update parent bank
+                    // The created bank already exist ==> update parent bank
                     IFOKDO(err, accountObj.setBank(bankObj))
                     IFOKDO(err, accountObj.save())
                 } else {
-                    //The bank does not exist
+                    // The bank does not exist
                     int code = KMessageBox::Yes;
                     SKGBankObject currentBank;
                     err = accountObj.getBank(currentBank);
@@ -571,10 +592,10 @@ void SKGBankPluginWidget::onModifyAccountClicked()
 
                     IFOKDO(err, accountObj.getBank(bankObj))
                     if (code == KMessageBox::Yes) {
-                        //The bank does not exist ==> update this one
+                        // The bank does not exist ==> update this one
                         IFOKDO(err, bankObj.setName(bankName))
                     } else {
-                        //The bank does not exist ==> create a new one
+                        // The bank does not exist ==> create a new one
                         IFOKDO(err, bankObj.resetID())
                         IFOKDO(err, bankObj.setName(bankName))
                         IFOKDO(err, bankObj.save())
@@ -585,7 +606,7 @@ void SKGBankPluginWidget::onModifyAccountClicked()
             }
             if (ui.kAccountCreatorIcon->text() != NOUPDATE) {
                 IFOK(err) {
-                    //Build icon name
+                    // Build icon name
                     QString icon = ui.kAccountCreatorIcon->currentText();
                     if (!QFile(icon).exists() && !icon.isEmpty()) {
                         QString code = ui.kAccountCreatorIcon->itemData(ui.kAccountCreatorIcon->currentIndex()).toString();
@@ -602,16 +623,18 @@ void SKGBankPluginWidget::onModifyAccountClicked()
             IFOKDO(err, getDocument()->stepForward(i + 1))
         }
 
-        //Remove bank without account
+        // Remove bank without account
         IFOK(err) {
             err = getDocument()->executeSqliteOrder("DELETE FROM bank WHERE NOT EXISTS(SELECT 1 FROM account WHERE account.rd_bank_id = bank.id)");
         }
     }
 
-    //status bar
+    // status bar
     IFOKDO(err, SKGError(0, i18nc("Successfully updated an account", "Account updated.")))
-    else err.addError(ERR_FAIL, i18nc("Error message : Could not update an account",  "Update failed"));
-    //Display error
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message : Could not update an account",  "Update failed"));
+    }
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
@@ -691,19 +714,19 @@ void SKGBankPluginWidget::dataModified(const QString& iTableName, int iIdTransac
     SKGTRACEIN(10, "SKGBankPluginWidget::dataModified");
     Q_UNUSED(iIdTransaction);
 
-    //Refresh widgets
+    // Refresh widgets
     if (iTableName == "v_account_display" || iTableName.isEmpty()) {
-        //Refresh info area
+        // Refresh info area
         m_timer.start(300);
     }
 
     if (iTableName == "bank" || iTableName.isEmpty()) {
-        //Set completions
+        // Set completions
         SKGMainPanel::fillWithDistinctValue(ui.kAccountCreatorBank, getDocument(), "bank", "t_name", "", true);
     }
 
     if (iTableName == "account" || iTableName.isEmpty()) {
-        //Set completions
+        // Set completions
         SKGMainPanel::fillWithDistinctValue(ui.kAccountCreatorAccount, getDocument(), "account", "t_name", "", true);
         SKGMainPanel::fillWithDistinctValue(ui.kAccountCreatorBankNumber, getDocument(), "bank", "t_bank_number", "", true);
         SKGMainPanel::fillWithDistinctValue(ui.kAccountCreatorAgencyNumber, getDocument(), "account", "t_agency_number", "", true);
@@ -717,7 +740,7 @@ void SKGBankPluginWidget::refreshInfoZone()
 {
     SKGTRACEIN(10, "SKGBankPluginWidget::refreshInfoZone");
 
-    //Refresh info area
+    // Refresh info area
     SKGStringListList listTmp;
     getDocument()->executeSelectSqliteOrder(
         "SELECT TOTAL(f_TODAYAMOUNT), TOTAL(f_CURRENTAMOUNT), TOTAL(f_CHECKED), TOTAL(f_COMING_SOON) from v_account_display",
