@@ -20,6 +20,10 @@
  * @author Stephane MANKOWSKI
  */
 #include "skgbudgetpluginwidget.h"
+
+#include <QDomDocument>
+#include <QKeyEvent>
+
 #include "skgbudgetdelegate.h"
 #include "skgmainpanel.h"
 #include "skgobjectmodel.h"
@@ -30,9 +34,6 @@
 #include "skgtraces.h"
 #include "skgdocument.h"
 
-#include <QDomDocument>
-#include <QKeyEvent>
-
 SKGBudgetPluginWidget::SKGBudgetPluginWidget(SKGDocument* iDocument)
     : SKGTabPage(iDocument)
 {
@@ -67,52 +68,45 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(SKGDocument* iDocument)
     ui.kView->getShowWidget()->addItem("all", i18nc("Noun, budget items to display", "All"), "",
                                        "",
                                        "current;currentYear;currentMonth;previousYear;previousMonth",
-                                       "none"
-                                      );
+                                       "none");
     ui.kView->getShowWidget()->addItem("none", i18nc("Noun, budget items to display", "None"), "",
                                        "1=0",
-                                       "",  //Check when checked
-                                       "all;current;currentYear;currentMonth;previousYear;previousMonth",       //Uncheck when checked
-                                       "",       //Check when unchecked
-                                       "all"     //Uncheck when unchecked
-                                      );
+                                       "",  // Check when checked
+                                       "all;current;currentYear;currentMonth;previousYear;previousMonth",       // Uncheck when checked
+                                       "",       // Check when unchecked
+                                       "all");     // Uncheck when unchecked
     ui.kView->getShowWidget()->addSeparator();
     ui.kView->getShowWidget()->addItem("current", i18nc("Noun, budget items to display", "Current"), "",
                                        "t_PERIOD>=STRFTIME('%Y-%m', date('now')) OR t_PERIOD=STRFTIME('%Y', date('now'))",
-                                       "currentMonth",  //Check when checked
-                                       "none",       //Uncheck when checked
-                                       "",       //Check when unchecked
-                                       "all"     //Uncheck when unchecked
-                                      );
+                                       "currentMonth",  // Check when checked
+                                       "none",       // Uncheck when checked
+                                       "",       // Check when unchecked
+                                       "all");     // Uncheck when unchecked
     ui.kView->getShowWidget()->addItem("currentYear", i18nc("Noun, budget items to display", "Current year"), "view-calendar-month",
                                        "t_PERIOD LIKE STRFTIME('%Y', date('now'))||'%'",
                                        "",
                                        "none",
                                        "",
-                                       "all"
-                                      );
+                                       "all");
     ui.kView->getShowWidget()->addItem("currentMonth", i18nc("Noun, budget items to display", "Current month"), "view-calendar-week",
                                        "t_PERIOD=STRFTIME('%Y-%m', date('now'))",
                                        "",
                                        "none",
                                        "",
-                                       "all;current"
-                                      );
+                                       "all;current");
     ui.kView->getShowWidget()->addSeparator();
     ui.kView->getShowWidget()->addItem("previousYear", i18nc("Noun, budget items to display", "Previous year"), "view-calendar-month",
                                        "t_PERIOD LIKE STRFTIME('%Y', date('now','-1 Year'))||'%'",
                                        "",
                                        "none",
                                        "",
-                                       "all"
-                                      );
+                                       "all");
     ui.kView->getShowWidget()->addItem("previousMonth", i18nc("Noun, budget items to display", "Previous month"), "view-calendar-week",
                                        "t_PERIOD=STRFTIME('%Y-%m', date('now','-1 Month'))",
                                        "",
                                        "none",
                                        "",
-                                       "all"
-                                      );
+                                       "all");
     ui.kView->getShowWidget()->setDefaultState("current");
 
     m_timer.setSingleShot(true);
@@ -134,12 +128,12 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(SKGDocument* iDocument)
         ui.kUnitCmb->addItem(doc->getPrimaryUnit().Symbol);
         ui.kUnit->setText(doc->getPrimaryUnit().Symbol);
 
-        //Bind operation view
+        // Bind operation view
         m_objectModel = new SKGObjectModel(doc, "v_budget_display", "1=0", this, "", false);
         ui.kView->setModel(m_objectModel);
     }
 
-    //Add registered global action in contextual menu
+    // Add registered global action in contextual menu
     if (SKGMainPanel::getMainPanel()) {
         ui.kView->getView()->insertGlobalAction();
         ui.kView->getView()->insertGlobalAction("open");
@@ -149,7 +143,7 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(SKGDocument* iDocument)
     connect(ui.kView->getView(), SIGNAL(doubleClicked(QModelIndex)), SKGMainPanel::getMainPanel()->getGlobalAction("open"), SLOT(trigger()));
     connect(ui.kView->getView(), SIGNAL(selectionChangedDelayed()), this, SLOT(onSelectionChanged()));
 
-    //Add Standard KDE Icons to buttons to Operations
+    // Add Standard KDE Icons to buttons to Operations
     ui.kModifyBtn->setIcon(KIcon("dialog-ok-apply"));
     ui.kAddBtn->setIcon(KIcon("list-add"));
     QAction* processAction = SKGMainPanel::getMainPanel()->getGlobalAction("tool_process_budget_rules");
@@ -184,10 +178,10 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(SKGDocument* iDocument)
 
     ui.kWidgetSelector->setSelectedMode(0);
 
-    //Set Event filters to catch CTRL+ENTER or SHIFT+ENTER
+    // Set Event filters to catch CTRL+ENTER or SHIFT+ENTER
     this->installEventFilter(this);
 
-    //Refresh
+    // Refresh
     connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
     dataModified("", 0);
 }
@@ -198,11 +192,11 @@ SKGBudgetPluginWidget::~SKGBudgetPluginWidget()
     m_objectModel = NULL;
 }
 
-bool SKGBudgetPluginWidget::eventFilter(QObject* object, QEvent* event)
+bool SKGBudgetPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 {
-    if (event && event->type() == QEvent::KeyPress) {
-        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
-        if ((keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && object == this) {
+    if (iEvent && iEvent->type() == QEvent::KeyPress) {
+        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(iEvent);
+        if ((keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && iObject == this) {
             if (QApplication::keyboardModifiers() &Qt::ControlModifier && ui.kAddBtn->isEnabled()) {
                 ui.kAddBtn->click();
             } else if (QApplication::keyboardModifiers() &Qt::ShiftModifier && ui.kModifyBtn->isEnabled()) {
@@ -271,7 +265,7 @@ void SKGBudgetPluginWidget::refresh()
     QSqlDatabase* db = getDocument()->getDatabase();
     setEnabled(db != NULL);
     if (db != NULL) {
-        //Refresh yours widgets here
+        // Refresh yours widgets here
     }
 }
 
@@ -280,14 +274,14 @@ void SKGBudgetPluginWidget::dataModified(const QString& iTableName, int iIdTrans
     SKGTRACEIN(10, "SKGBudgetPluginWidget::dataModified");
     Q_UNUSED(iIdTransaction);
 
-    //Refresh widgets
+    // Refresh widgets
     if (iTableName == "budget" || iTableName.isEmpty()) {
-        //Refresh info area
+        // Refresh info area
         m_timer.start(300);
     }
 
     if (iTableName == "category" || iTableName.isEmpty()) {
-        //Set type category
+        // Set type category
         SKGMainPanel::fillWithDistinctValue(ui.kCategoryEdit, getDocument(), "category", "t_fullname", "");
         SKGMainPanel::fillWithDistinctValue(ui.kCategoryRule, getDocument(), "category", "t_fullname", "");
         SKGMainPanel::fillWithDistinctValue(ui.kCategoryTransfer, getDocument(), "category", "t_fullname", "");
@@ -320,7 +314,7 @@ void SKGBudgetPluginWidget::onAddClicked()
     _SKGTRACEINRC(10, "SKGBudgetPluginWidget::onAddClicked", err);
 
     if (ui.kWidgetSelector->getSelectedMode() == 2) {
-        //Creation of a rule
+        // Creation of a rule
         QStringList uniqueIDs;
         {
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Budget rule creation")  , err);
@@ -328,37 +322,39 @@ void SKGBudgetPluginWidget::onAddClicked()
             err = updateBudgetRule(budgetRule);
             uniqueIDs.push_back(budgetRule.getUniqueID());
         }
-        //status bar
+        // status bar
         IFOK(err) {
             err = SKGError(0, i18nc("Successful message after an user action", "Budget rule created"));
             ui.kView->getView()->selectObjects(uniqueIDs);
-        } else err.addError(ERR_FAIL, i18nc("Error message", "Budget rule creation failed"));
+        } else {
+            err.addError(ERR_FAIL, i18nc("Error message", "Budget rule creation failed"));
+        }
     } else {
-        //Creation of a budget
+        // Creation of a budget
         QStringList uniqueIDs;
         {
             SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Budget creation")  , err, 2);
             if (ui.kWidgetSelector->getSelectedMode() == 0) {
-                //Manual creation
+                // Manual creation
                 int mode = ui.kPeriod->currentIndex();
-                if (mode == 0) { //Monthly
+                if (mode == 0) {  // Monthly
                     for (int m = 1; !err && m <= 12; ++m) {
                         SKGBudgetObject budget(getDocument());
                         err = updateBudget(budget, m);
                         uniqueIDs.push_back(budget.getUniqueID());
                     }
-                } else if (mode == 1) { //Yearly
+                } else if (mode == 1) {  // Yearly
                     SKGBudgetObject budget(getDocument());
 
                     err = updateBudget(budget, 0);
                     uniqueIDs.push_back(budget.getUniqueID());
-                } else { //Individual
+                } else {  // Individual
                     SKGBudgetObject budget(getDocument());
                     err = updateBudget(budget);
                     uniqueIDs.push_back(budget.getUniqueID());
                 }
             } else {
-                //Automatic creation
+                // Automatic creation
                 if (ui.kAutoBudgetCheck->isChecked()) err = SKGBudgetObject::createAutomaticBudget(static_cast<SKGDocumentBank*>(getDocument()),
                             ui.kYearAuto->value(),
                             ui.kYearAutoBase->value(),
@@ -373,14 +369,16 @@ void SKGBudgetPluginWidget::onAddClicked()
             }
         }
 
-        //status bar
+        // status bar
         IFOK(err) {
             err = SKGError(0, i18nc("Successful message after an user action", "Budget created"));
             ui.kView->getView()->selectObjects(uniqueIDs);
-        } else err.addError(ERR_FAIL, i18nc("Error message", "Budget creation failed"));
+        } else {
+            err.addError(ERR_FAIL, i18nc("Error message", "Budget creation failed"));
+        }
     }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
@@ -388,7 +386,7 @@ void SKGBudgetPluginWidget::onUpdateClicked()
 {
     SKGError err;
     SKGTRACEINRC(10, "SKGBudgetPluginWidget::onUpdateClicked", err);
-    //Get Selection
+    // Get Selection
     SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
     if (ui.kWidgetSelector->getSelectedMode() == 2) {
         {
@@ -397,10 +395,12 @@ void SKGBudgetPluginWidget::onUpdateClicked()
             err = updateBudgetRule(rule);
         }
 
-        //status bar
+        // status bar
         IFOK(err) {
             err = SKGError(0, i18nc("Successful message after an user action", "Budget rule updated"));
-        } else err.addError(ERR_FAIL, i18nc("Error message",  "Budget rule update failed"));
+        } else {
+            err.addError(ERR_FAIL, i18nc("Error message",  "Budget rule update failed"));
+        }
     } else {
         {
             int nb = selection.count();
@@ -408,9 +408,9 @@ void SKGBudgetPluginWidget::onUpdateClicked()
             for (int i = 0; !err && i < nb; ++i) {
                 SKGBudgetObject budget(selection.at(i));
                 int mode = ui.kPeriod->currentIndex();
-                if (mode == 1) { //Yearly
+                if (mode == 1) {  // Yearly
                     err = updateBudget(budget, 0);
-                } else { //Individual
+                } else {  // Individual
                     err = updateBudget(budget);
                 }
 
@@ -418,14 +418,16 @@ void SKGBudgetPluginWidget::onUpdateClicked()
             }
         }
 
-        //status bar
+        // status bar
         IFOK(err) {
             err = SKGError(0, i18nc("Successful message after an user action", "Budget updated"));
-        } else err.addError(ERR_FAIL, i18nc("Error message",  "Budget update failed"));
+        } else {
+            err.addError(ERR_FAIL, i18nc("Error message",  "Budget update failed"));
+        }
     }
 
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
@@ -442,12 +444,12 @@ SKGError SKGBudgetPluginWidget::updateBudget(SKGBudgetObject& iBudget, int iMont
     IFOKDO(err, iBudget.enableSubCategoriesInclusion(ui.kIncludingSubCategories->isChecked()))
 
     double val = ui.kAmountEdit->value();
-    //Is the sign forced ?
+    // Is the sign forced ?
     if (ui.kAmountEdit->sign() == 0) {
-        //No
+        // No
         SKGObjectBase cat2(cat.getDocument(), "v_category_display", cat.getID());
 
-        //Are we able to find to sign with the category ?
+        // Are we able to find to sign with the category ?
         if (cat2.getAttribute("t_TYPEEXPENSE") == "-") val = -val;
     }
     IFOKDO(err, iBudget.setBudgetedAmount(val))
@@ -474,7 +476,7 @@ SKGError SKGBudgetPluginWidget::updateBudgetRule(SKGBudgetRuleObject& iRule)
     IFOK(err) {
         bool absolute = (ui.kUnitCmb->currentIndex() == 1);
         double val = ui.kAmountEdit2->value();
-        if (!absolute) val = qMin(qMax(double(0), val), double(100));
+        if (!absolute) val = qMin(qMax(static_cast<double>(0), val), static_cast<double>(100));
         err = iRule.setQuantity(val, absolute);
     }
     IFOKDO(err, iRule.setCondition(static_cast<SKGBudgetRuleObject::Condition>(ui.kConditionCmb->itemData(ui.kConditionCmb->currentIndex()).toInt())))
@@ -511,7 +513,7 @@ void SKGBudgetPluginWidget::onSelectionChanged()
             ui.kMonth->setValue(budget.getMonth());
             ui.kAmountEdit->setValue(budget.getBudgetedAmount());
             ui.kCategoryEdit->setText(budget.getAttribute("t_CATEGORY"));
-            ui.kPeriod->setCurrentIndex(budget.getMonth() == 0 ? 1 : 2); //Set yearly or individual
+            ui.kPeriod->setCurrentIndex(budget.getMonth() == 0 ? 1 : 2);  // Set yearly or individual
             ui.kIncludingSubCategories->setChecked(budget.isSubCategoriesInclusionEnabled());
 
             if (mode > 0) ui.kWidgetSelector->setSelectedMode(0);
@@ -560,7 +562,7 @@ void SKGBudgetPluginWidget::refreshInfoZone()
     if (doc && loc && ui.kWidgetSelector->getSelectedMode() != 2) {
         SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
         SKGServices::SKGUnitInfo secondary = doc->getSecondaryUnit();
-        //Refresh info area with selection
+        // Refresh info area with selection
         SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
 
         double budgeted = 0;
@@ -578,8 +580,8 @@ void SKGBudgetPluginWidget::refreshInfoZone()
         if (nb) {
             ui.kInfo->setText(i18np("Selection: %1 budget for %2", "Selection: %1 budgets for %2", nb, v));
             if (!secondary.Symbol.isEmpty() && secondary.Value) {
-                QString budgetedS = doc->formatMoney(budgeted, secondary);
-                QString modifiedS = doc->formatMoney(modified, secondary);
+                budgetedS = doc->formatMoney(budgeted, secondary);
+                modifiedS = doc->formatMoney(modified, secondary);
                 v = (budgetedS == modifiedS ? budgetedS : modifiedS % " <s><small>" % budgetedS % "</small></s>");
             }
             ui.kInfo->setToolTip(i18np("Selection: %1 budget for %2", "Selection: %1 budgets for %2", nb, v));
