@@ -20,6 +20,15 @@
  * @author Stephane MANKOWSKI
  */
 #include "skgcalculatorpluginwidget.h"
+
+#include <KStandardDirs>
+#include <KLocale>
+
+#include <QDomDocument>
+#include <QDir>
+#include <QKeyEvent>
+#include <qmath.h>
+
 #include "skgmainpanel.h"
 #include "skgtraces.h"
 #include "skgdocumentbank.h"
@@ -29,14 +38,6 @@
 #include "skgtransactionmng.h"
 #include "skgunitobject.h"
 
-#include <kstandarddirs.h>
-#include <klocale.h>
-
-#include <QDomDocument>
-#include <QDir>
-#include <QKeyEvent>
-#include <qmath.h>
-
 SKGCalculatorPluginWidget::SKGCalculatorPluginWidget(SKGDocumentBank* iDocument)
     : SKGTabPage(iDocument)
 {
@@ -81,7 +82,7 @@ SKGCalculatorPluginWidget::SKGCalculatorPluginWidget(SKGDocumentBank* iDocument)
     ui.kWidgetSelector->addButton(KIcon("accessories-calculator"), i18n("Amortization Table"), i18n("Loan amortization table calculator"), ui.kAmortizationFrm);
     connect(ui.kWidgetSelector, SIGNAL(selectedModeChanged(int)), this, SLOT(onBtnModeClicked(int)));
 
-    //Bind account creation view
+    // Bind account creation view
     m_objectModel = new SKGObjectModel(static_cast<SKGDocumentBank*>(getDocument()), "v_interest", "", this, "", false);
     ui.kInterestView->setModel(m_objectModel);
 
@@ -94,17 +95,17 @@ SKGCalculatorPluginWidget::SKGCalculatorPluginWidget(SKGDocumentBank* iDocument)
 
     ui.kWidgetSelector->setSelectedMode(0);
 
-    //Refresh
+    // Refresh
     connect(ui.kDisplayAccountCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(onFilterChanged()), Qt::QueuedConnection);
     connect(ui.KYearEdit, SIGNAL(currentIndexChanged(int)), this, SLOT(onFilterChanged()) , Qt::QueuedConnection);
 
     connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
     dataModified("", 0);
 
-    //Set Event filters to catch CTRL+ENTER or SHIFT+ENTER
+    // Set Event filters to catch CTRL+ENTER or SHIFT+ENTER
     this->installEventFilter(this);
 
-    //Synchronize zooms of both tables
+    // Synchronize zooms of both tables
     connect(ui.kInterestResultTable, SIGNAL(zoomChanged(int)), ui.kInterestView, SLOT(setZoomPosition(int)));
     connect(ui.kInterestView, SIGNAL(zoomChanged(int)), ui.kInterestResultTable, SLOT(setZoomPosition(int)));
 }
@@ -115,11 +116,11 @@ SKGCalculatorPluginWidget::~SKGCalculatorPluginWidget()
     m_objectModel = NULL;
 }
 
-bool SKGCalculatorPluginWidget::eventFilter(QObject* object, QEvent* event)
+bool SKGCalculatorPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 {
-    if (event && event->type() == QEvent::KeyPress) {
-        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
-        if ((keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && object == this) {
+    if (iEvent && iEvent->type() == QEvent::KeyPress) {
+        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(iEvent);
+        if ((keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && iObject == this) {
             if (QApplication::keyboardModifiers() &Qt::ControlModifier && ui.kAdd->isEnabled()) {
                 ui.kAdd->click();
             } else if (QApplication::keyboardModifiers() &Qt::ShiftModifier && ui.kUpdate->isEnabled()) {
@@ -149,7 +150,7 @@ QString SKGCalculatorPluginWidget::getState()
     root.setAttribute("amortizationInsuranceRate", SKGServices::doubleToString(ui.kInsuranceRateEdit->value()));
 
 
-    //Memorize table settings
+    // Memorize table settings
     root.setAttribute("view", ui.kInterestView->getState());
     root.setAttribute("viewResult", ui.kInterestResultTable->getState());
 
@@ -186,14 +187,14 @@ void SKGCalculatorPluginWidget::setState(const QString& iState)
 
     if (!year.isEmpty()) ui.KYearEdit->setText(year);
 
-    //Update model
+    // Update model
     if (m_objectModel) {
         bool previous = m_objectModel->blockRefresh(true);
         onFilterChanged();
         m_objectModel->blockRefresh(previous);
     }
 
-    //!!! Must be done here after onFilterChanged
+    // !!! Must be done here after onFilterChanged
     ui.kInterestView->setState(root.attribute("view"));
     ui.kInterestResultTable->setState(root.attribute("viewResult"));
 }
@@ -207,10 +208,10 @@ void SKGCalculatorPluginWidget::onBtnModeClicked(int mode)
 {
     Q_UNUSED(mode);
 
-    //Save zoom position of previous page
+    // Save zoom position of previous page
     int zoom = zoomPosition();
 
-    //Save zoom position on new page
+    // Save zoom position on new page
     setZoomPosition(zoom);
 
     Q_EMIT selectionChanged();
@@ -219,7 +220,7 @@ void SKGCalculatorPluginWidget::onBtnModeClicked(int mode)
 void SKGCalculatorPluginWidget::onSelectionChanged()
 {
     SKGTRACEIN(10, "SKGCalculatorPluginWidget::onSelectionChanged");
-    //Mapping
+    // Mapping
     QItemSelectionModel* selModel = ui.kInterestView->selectionModel();
     if (selModel) {
         QModelIndexList indexes = selModel->selectedRows();
@@ -246,23 +247,23 @@ void SKGCalculatorPluginWidget::dataModified(const QString& iTableName, int iIdT
     Q_UNUSED(iIdTransaction);
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
-    //Refresh widgets
+    // Refresh widgets
     QSqlDatabase* db = getDocument()->getDatabase();
     setEnabled(db != NULL);
     if (db != NULL && (iTableName == "interest" || iTableName.isEmpty())) {
-        //Correction bug 2299394 vvv
+        // Correction bug 2299394 vvv
         if (ui.kInterestView->isAutoResized()) ui.kInterestView->resizeColumnsToContentsDelayed();
-        //Correction bug 2299394 ^^^
+        // Correction bug 2299394 ^^^
 
-        //Correction 215658: vvv because the table is modified, the selection is modified
+        // Correction 215658: vvv because the table is modified, the selection is modified
         onSelectionChanged();
-        //Correction 215658: ^^^
+        // Correction 215658: ^^^
     }
 
-    //Refresh interest parameter view
+    // Refresh interest parameter view
     QString current = ui.kDisplayAccountCombo->currentText();
     if (db != NULL && (iTableName == "v_account_display" || iTableName.isEmpty())) {
-        //Clear
+        // Clear
         ui.kDisplayAccountCombo->clear();
 
         SKGStringListList listAccount;
@@ -271,21 +272,21 @@ void SKGCalculatorPluginWidget::dataModified(const QString& iTableName, int iIdT
         int nbAccounts = listAccount.count();
         if (nbAccounts >= 0) {
             QDir dirLogo(KStandardDirs::locate("data", QString::fromLatin1("skrooge/images/logo/")));
-            for (int i = 1; i < nbAccounts; ++i) { //Ignore header
+            for (int i = 1; i < nbAccounts; ++i) {  // Ignore header
                 QIcon icon(dirLogo.absoluteFilePath(listAccount.at(i).at(0)));
                 QString text = listAccount.at(i).at(1);
                 ui.kDisplayAccountCombo->addItem(icon, text);
             }
         }
 
-        int pos = ui.kDisplayAccountCombo->findText(current);
-        if (pos == -1) pos = 0;
-        ui.kDisplayAccountCombo->setCurrentIndex(pos);
+        int posText = ui.kDisplayAccountCombo->findText(current);
+        if (posText == -1) posText = 0;
+        ui.kDisplayAccountCombo->setCurrentIndex(posText);
 
         ui.kAdd->setEnabled(ui.kDisplayAccountCombo->count() > 0);
     }
 
-    //Fill years
+    // Fill years
     if (db != NULL && (iTableName == "v_operation_display" || iTableName.isEmpty())) {
         disconnect(ui.KYearEdit, SIGNAL(currentIndexChanged(int)), this, SLOT(onFilterChanged()));
 
@@ -296,18 +297,18 @@ void SKGCalculatorPluginWidget::dataModified(const QString& iTableName, int iIdT
         getDocument()->getDistinctValues("v_operation_display", "d_DATEYEAR", "", list);
         if (list.count()) firstYear = SKGServices::stringToInt(list.at(0));
 
-        QString y = ui.KYearEdit->text();
+        QString year = ui.KYearEdit->text();
         ui.KYearEdit->clear();
         for (int i = lastYear; i >= firstYear; --i) {
             QString v = SKGServices::intToString(i);
-            if (y.isEmpty()) y = v;
+            if (year.isEmpty()) year = v;
             ui.KYearEdit->addItem(v);
         }
 
-        ui.KYearEdit->setText(y);
+        ui.KYearEdit->setText(year);
         connect(ui.KYearEdit, SIGNAL(currentIndexChanged(int)), this, SLOT(onFilterChanged()));
     }
-    //Refresh computation
+    // Refresh computation
     if (db != NULL && (iTableName == "interest" || iTableName == "account" || iTableName.isEmpty())) {
         computeInterest();
     }
@@ -316,7 +317,7 @@ void SKGCalculatorPluginWidget::dataModified(const QString& iTableName, int iIdT
 
 void SKGCalculatorPluginWidget::computeInterest()
 {
-    //Compute
+    // Compute
     SKGAccountObject account(getDocument());
     SKGError err = account.setName(ui.kDisplayAccountCombo->currentText());
     IFOKDO(err, account.load())
@@ -324,10 +325,10 @@ void SKGCalculatorPluginWidget::computeInterest()
     double oInterests = 0;
     IFOKDO(err, account.getInterestItems(oInterestList, oInterests, SKGServices::stringToInt(ui.KYearEdit->text())))
     IFOK(err) {
-        //Refresh table
+        // Refresh table
         ui.kInterestResultTable->setState(ui.kInterestResultTable->getState());
 
-        //Set text
+        // Set text
         SKGDocumentBank* doc = static_cast<SKGDocumentBank*>(getDocument());
         if (doc) {
             SKGServices::SKGUnitInfo unit1 = doc->getPrimaryUnit();
@@ -349,15 +350,15 @@ void SKGCalculatorPluginWidget::onFilterChanged()
     if (!isEnabled()) return;
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
-    //Compute where clause
+    // Compute where clause
     QString account = ui.kDisplayAccountCombo->currentText();
     QString filter2 = "t_ACCOUNT='" % SKGServices::stringToSqlString(account) % "' ORDER BY d_date";
 
-    //Update model
+    // Update model
     if (m_objectModel) {
         if (m_objectModel->setFilter(filter2)) ui.kInterestView->setState(ui.kInterestView->getState());
 
-        //Compute result
+        // Compute result
         computeInterest();
     }
     QApplication::restoreOverrideCursor();
@@ -406,12 +407,12 @@ void SKGCalculatorPluginWidget::onAdd()
             QString accountname = ui.kDisplayAccountCombo->currentText();
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Lets the user create parameters for computing interests on an account", "Interest parameter creation for account '%1'", accountname), err);
 
-            //Get Parent account
+            // Get Parent account
             SKGAccountObject accountObj(getDocument());
             IFOKDO(err, accountObj.setName(accountname))
             IFOKDO(err, accountObj.load())
 
-            //Create interest object
+            // Create interest object
             IFOKDO(err, accountObj.addInterest(interestObj))
             IFOKDO(err, interestObj.setDate(ui.kDateEdit->date()))
             IFOKDO(err, interestObj.setRate(ui.kRateEdit->value()))
@@ -421,14 +422,16 @@ void SKGCalculatorPluginWidget::onAdd()
             IFOKDO(err, interestObj.save())
         }
 
-        //status bar
+        // status bar
         IFOK(err) {
             err = SKGError(0, i18nc("User defined parameters for computing interests were successfully created", "Interest parameter created"));
             ui.kInterestView->selectObject(interestObj.getUniqueID());
-        } else err.addError(ERR_FAIL, i18nc("Error message: User defined parameters for computing interests could not be created",  "Interest parameter creation failed"));
+        } else {
+            err.addError(ERR_FAIL, i18nc("Error message: User defined parameters for computing interests could not be created",  "Interest parameter creation failed"));
+        }
     }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
@@ -437,7 +440,7 @@ void SKGCalculatorPluginWidget::onUpdate()
     SKGError err;
     SKGTRACEINRC(10, "SKGCalculatorPluginWidget::onUpdate", err);
 
-    //Get Parent account
+    // Get Parent account
     QString accountname = ui.kDisplayAccountCombo->currentText();
     SKGAccountObject accountObj(getDocument());
     IFOKDO(err, accountObj.setName(accountname))
@@ -462,11 +465,13 @@ void SKGCalculatorPluginWidget::onUpdate()
         }
     }
 
-    //status bar
+    // status bar
     IFOKDO(err, SKGError(0, i18nc("User defined parameters for computing interests were successfully updated", "Interest parameter updated")))
-    else err.addError(ERR_FAIL, i18nc("Error message: User defined parameters for computing interests could not be updated",  "Interest parameter update failed"));
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message: User defined parameters for computing interests could not be updated",  "Interest parameter update failed"));
+    }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
@@ -482,7 +487,7 @@ void SKGCalculatorPluginWidget::onAmortizationComputation()
 
     KLocale* loc = KGlobal::locale();
     if (loc) {
-        //Get unit
+        // Get unit
         SKGServices::SKGUnitInfo unitInfo;
         unitInfo.Symbol = ui.kUnitEdit->text();
 
@@ -493,26 +498,26 @@ void SKGCalculatorPluginWidget::onAmortizationComputation()
 
         int p = qPow(10, unitInfo.NbDecimal);
 
-        //Computation
+        // Computation
         int periodInMonths = 12;
         int numberPayments = ui.kLenghtEdit->value() * periodInMonths;
         double periodicRate = ui.kAnnualRateEdit->value() / 100 / periodInMonths;
         double insurance = qRound(ui.kLoanEdit->value() * ui.kInsuranceRateEdit->value() / 100 / periodInMonths * p) / p;
         double periodicAmount = qRound(ui.kLoanEdit->value() * periodicRate / (1 - pow(1 + periodicRate, -numberPayments)) * p) / p;
 
-        //Fill table
+        // Fill table
         double dueAmount = ui.kLoanEdit->value();
         double sumInterest = 0;
         ui.kAmortizationTable->setRowCount(numberPayments);
         for (int i = 0; i < numberPayments; ++i) {
-            //Compute
+            // Compute
             double roundedInterest = qRound(dueAmount * periodicRate * p) / p;
             double principal = qRound((i == numberPayments - 1 ? dueAmount : periodicAmount - roundedInterest) * p) / p;
             double amount = roundedInterest + principal;
             dueAmount -= principal;
             sumInterest += roundedInterest;
 
-            //Add items
+            // Add items
             ui.kAmortizationTable->setItem(i, 0, new QTableWidgetItem(loc->formatMoney(amount, unitInfo.Symbol, unitInfo.NbDecimal)));
             ui.kAmortizationTable->setItem(i, 1, new QTableWidgetItem(loc->formatMoney(principal, unitInfo.Symbol, unitInfo.NbDecimal)));
             ui.kAmortizationTable->setItem(i, 2, new QTableWidgetItem(loc->formatMoney(roundedInterest, unitInfo.Symbol, unitInfo.NbDecimal)));
@@ -520,21 +525,20 @@ void SKGCalculatorPluginWidget::onAmortizationComputation()
             ui.kAmortizationTable->setItem(i, 4, new QTableWidgetItem(loc->formatMoney(dueAmount, unitInfo.Symbol, unitInfo.NbDecimal)));
         }
 
-        ui.kAmortizationResult->setText(i18n("Number of payments:	%1\n"
-                                             "Monthly payment: 	%2\n"
-                                             "Monthly insurance: 	%3\n"
-                                             "Total principal paid: 	%4\n"
-                                             "Total interest paid: 	%5\n"
-                                             "Total insurance paid: 	%6\n"
-                                             "Total paid: 		%7" ,
+        ui.kAmortizationResult->setText(i18n("Number of payments:	%1\n"  // NOLINT(whitespace/tab)
+                                             "Monthly payment: 	%2\n"  // NOLINT(whitespace/tab)
+                                             "Monthly insurance: 	%3\n"  // NOLINT(whitespace/tab)
+                                             "Total principal paid: 	%4\n"  // NOLINT(whitespace/tab)
+                                             "Total interest paid: 	%5\n"  // NOLINT(whitespace/tab)
+                                             "Total insurance paid: 	%6\n"  // NOLINT(whitespace/tab)
+                                             "Total paid: 		%7" ,  // NOLINT(whitespace/tab)
                                              SKGServices::intToString(numberPayments),
                                              loc->formatMoney(periodicAmount, unitInfo.Symbol, unitInfo.NbDecimal),
                                              loc->formatMoney(insurance, unitInfo.Symbol, unitInfo.NbDecimal),
                                              loc->formatMoney(ui.kLoanEdit->value(), unitInfo.Symbol, unitInfo.NbDecimal),
                                              loc->formatMoney(sumInterest, unitInfo.Symbol, unitInfo.NbDecimal),
                                              loc->formatMoney(numberPayments * insurance, unitInfo.Symbol, unitInfo.NbDecimal),
-                                             loc->formatMoney(ui.kLoanEdit->value() + sumInterest + numberPayments * insurance, unitInfo.Symbol, unitInfo.NbDecimal)
-                                            ));
+                                             loc->formatMoney(ui.kLoanEdit->value() + sumInterest + numberPayments * insurance, unitInfo.Symbol, unitInfo.NbDecimal)));
     }
 
     QApplication::restoreOverrideCursor();
@@ -543,7 +547,9 @@ void SKGCalculatorPluginWidget::onAmortizationComputation()
 QWidget* SKGCalculatorPluginWidget::zoomableWidget()
 {
     if (ui.kWidgetSelector->getSelectedMode() == 0) return ui.kInterestView;
-    else return ui.kAmortizationTable;
+    else {
+        return ui.kAmortizationTable;
+    }
 }
 
 #include "skgcalculatorpluginwidget.moc"
