@@ -20,16 +20,17 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgoperationboardwidget.h"
+
+#include <QDomDocument>
+
+#include <KAction>
+
 #include "skgdocumentbank.h"
 #include "skgtraces.h"
 #include "skgservices.h"
 #include "skgobjectbase.h"
 #include "skgmainpanel.h"
 
-#include <QDomDocument>
-
-#include <kaction.h>
-
 SKGOperationBoardWidget::SKGOperationBoardWidget(SKGDocument* iDocument)
     : SKGBoardWidget(iDocument, i18nc("Dashboard widget title", "Income & Expenditure"))
 {
@@ -53,7 +54,7 @@ SKGOperationBoardWidget::SKGOperationBoardWidget(SKGDocument* iDocument)
     connect(ui.kExpense_previousLabel, SIGNAL(linkActivated(QString)), this, SLOT(onOpen(QString)));
     connect(ui.kSaving_previousLabel, SIGNAL(linkActivated(QString)), this, SLOT(onOpen(QString)));
 
-    //Create menu
+    // Create menu
     setContextMenuPolicy(Qt::ActionsContextMenu);
 
     QStringList overlayopen;
@@ -84,7 +85,7 @@ SKGOperationBoardWidget::SKGOperationBoardWidget(SKGDocument* iDocument)
     connect(m_menuSuboperation, SIGNAL(triggered(bool)), this, SLOT(dataModified()));
     addAction(m_menuSuboperation);
 
-    //Refresh
+    // Refresh
     connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
 }
 
@@ -121,28 +122,37 @@ void SKGOperationBoardWidget::setState(const QString& iState)
 
 void SKGOperationBoardWidget::onOpen(const QString& iLink)
 {
-    //Call operation plugin
+    // Call operation plugin
     QString wc;
     if (iLink.endsWith(QLatin1String("C"))) wc = "d_DATEMONTH=STRFTIME('%Y-%m', date('now')) AND t_TYPEACCOUNT<>'L'";
-    else wc = "d_DATEMONTH=STRFTIME('%Y-%m', date('now','-1 Month')) AND t_TYPEACCOUNT<>'L'";
+    else {
+        wc = "d_DATEMONTH=STRFTIME('%Y-%m', date('now','-1 Month')) AND t_TYPEACCOUNT<>'L'";
+    }
 
     if (iLink.startsWith(QLatin1String("I"))) wc = wc % " AND t_TYPEEXPENSE='+'";
-    else if (iLink.startsWith(QLatin1String("E"))) wc = wc % " AND t_TYPEEXPENSE='-'";
+    else if (iLink.startsWith(QLatin1String("E"))) {
+        wc = wc % " AND t_TYPEEXPENSE='-'";
+    }
 
     wc = wc % (m_menuTransfert && m_menuTransfert->isChecked() ? "" : " AND t_TRANSFER='N'") % (m_menuTracked && m_menuTracked->isChecked() ? "" : " AND t_REFUND=''");
 
     QString title;
     if (iLink == "IC") title = i18nc("Title of a list of operations", "Incomes of current month");
-    else if (iLink == "EC") title = i18nc("Title of a list of operations", "Expenses of current month");
-    else if (iLink == "SC") title = i18nc("Title of a list of operations", "Savings of current month");
-    else if (iLink == "IP") title = i18nc("Title of a list of operations", "Incomes of previous month");
-    else if (iLink == "EP") title = i18nc("Title of a list of operations", "Expenses of previous month");
-    else if (iLink == "SP") title = i18nc("Title of a list of operations", "Savings of previous month");
+    else if (iLink == "EC") {
+        title = i18nc("Title of a list of operations", "Expenses of current month");
+    } else if (iLink == "SC") {
+        title = i18nc("Title of a list of operations", "Savings of current month");
+    } else if (iLink == "IP") {
+        title = i18nc("Title of a list of operations", "Incomes of previous month");
+    } else if (iLink == "EP") {
+        title = i18nc("Title of a list of operations", "Expenses of previous month");
+    } else if (iLink == "SP") {
+        title = i18nc("Title of a list of operations", "Savings of previous month");
+    }
 
     bool onSubOperation = (m_menuSuboperation && m_menuSuboperation->isChecked());
     SKGMainPanel::getMainPanel()->openPage("skg://skrooge_operation_plugin/" % QString(onSubOperation ? "SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS/" : "") % "?operationTable=" % SKGServices::encodeForUrl(onSubOperation ? "v_operation_consolidated" : "v_operation_display") % "&title_icon=view-financial-list&currentPage=-1&title=" % SKGServices::encodeForUrl(title) %
-                                           "&operationWhereClause=" % SKGServices::encodeForUrl(wc)
-                                          );
+                                           "&operationWhereClause=" % SKGServices::encodeForUrl(wc));
 }
 
 void SKGOperationBoardWidget::dataModified(const QString& iTableName, int iIdTransaction)
@@ -153,7 +163,7 @@ void SKGOperationBoardWidget::dataModified(const QString& iTableName, int iIdTra
     QString amount = (m_menuSuboperation && m_menuSuboperation->isChecked() ? "f_REALCURRENTAMOUNT" : "f_CURRENTAMOUNT");
 
     if (iTableName == table || iTableName.isEmpty()) {
-        //Get month
+        // Get month
         QDate date = QDate::currentDate();
         date = date.addDays(1 - date.day());
         QDate date1 = date.addDays(-1);
@@ -190,16 +200,20 @@ void SKGOperationBoardWidget::dataModified(const QString& iTableName, int iIdTra
                 double expense_month = 0;
 
                 int nbval = listTmp.count();
-                for (int i = 1; i < nbval; ++i) { //Ignore header
+                for (int i = 1; i < nbval; ++i) {  // Ignore header
                     QString m = listTmp.at(i).at(1);
                     double v = SKGServices::stringToDouble(listTmp.at(i).at(0));
                     if (v > 0 && m == month) income_month = v;
-                    else if (v < 0 && m == month) expense_month = -v;
-                    else if (v > 0 && m == previousmonth) income_previous_month = v;
-                    else if (v < 0 && m == previousmonth) expense_previous_month = -v;
+                    else if (v < 0 && m == month) {
+                        expense_month = -v;
+                    } else if (v > 0 && m == previousmonth) {
+                        income_previous_month = v;
+                    } else if (v < 0 && m == previousmonth) {
+                        expense_previous_month = -v;
+                    }
                 }
 
-                //Set Maximum
+                // Set Maximum
                 int max = qMax(income_previous_month, qMax(expense_previous_month, qMax(income_month, expense_month)));
                 if (nbval == 1 || max == 0) max = 100.0;
                 ui.kIncome->setMaximum(max);
@@ -209,7 +223,7 @@ void SKGOperationBoardWidget::dataModified(const QString& iTableName, int iIdTra
                 ui.kSaving->setMaximum(max);
                 ui.kSaving_previous->setMaximum(max);
 
-                //Set values
+                // Set values
                 ui.kIncome->setValue(income_month);
                 ui.kIncome_previous->setValue(income_previous_month);
                 ui.kExpense->setValue(expense_month);
@@ -217,7 +231,7 @@ void SKGOperationBoardWidget::dataModified(const QString& iTableName, int iIdTra
                 ui.kSaving->setValue(qAbs(income_month - expense_month));
                 ui.kSaving_previous->setValue(qAbs(income_previous_month - expense_previous_month));
 
-                //Set texts and tool tips
+                // Set texts and tool tips
                 ui.kIncome->setFormat(doc->formatMoney(income_month, primary, false));
                 ui.kIncome_previous->setFormat(doc->formatMoney(income_previous_month, primary, false));
                 ui.kExpense->setFormat(doc->formatMoney(expense_month, primary, false));
@@ -233,7 +247,7 @@ void SKGOperationBoardWidget::dataModified(const QString& iTableName, int iIdTra
                     ui.kSaving_previous->setToolTip(doc->formatMoney(income_previous_month - expense_previous_month, secondary, false));
                 }
 
-                //Change colors
+                // Change colors
                 ui.kIncome->setLimits(0, 0, max);
                 ui.kIncome_previous->setLimits(0, 0, max);
                 ui.kExpense->setLimits(max, -1, -1);
@@ -242,7 +256,7 @@ void SKGOperationBoardWidget::dataModified(const QString& iTableName, int iIdTra
                 ui.kSaving_previous->setLimits(income_previous_month - expense_previous_month < 0 ? max : 0, 0.1 * income_previous_month, max);
             }
 
-            //No widget if no account
+            // No widget if no account
             bool exist = false;
             doc->existObjects("account", "", exist);
             if (parentWidget()) setVisible(exist);
