@@ -20,17 +20,18 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgreportpluginwidget.h"
+
+#include <KLocale>
+#include <KMenu>
+
+#include <QtGui/QGraphicsScene>
+
 #include "skgmainpanel.h"
 #include "skgbankincludes.h"
 #include "skgtraces.h"
 #include "skgcolorbutton.h"
 #include "skgreport_settings.h"
 
-#include <klocale.h>
-#include <kmenu.h>
-
-#include <QtGui/QGraphicsScene>
-
 /**
  * The size of the forecast
  */
@@ -84,20 +85,20 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGDocumentBank* iDocument, bool iM
     ui.kForecastCmb->addItem(i18nc("Noun", "None"), 0);
     ui.kForecastCmb->addItem(KIcon("view-financial-forecast"), i18nc("Noun", "Moving average"), 2);
     ui.kForecastCmb->addItem(KIcon("view-financial-forecast"), i18nc("Noun", "Weighted moving average"), 3);
-    //TODO: ui.kForecastCmb->addItem(KIcon("applications-education-mathematics"), i18nc("Noun", "Interest rate") , 5);
+    // TODO(Stephane MANKOWSKI): ui.kForecastCmb->addItem(KIcon("applications-education-mathematics"), i18nc("Noun", "Interest rate") , 5);
     ui.kForecastCmb->addItem(KIcon("chronometer"), i18nc("Noun", "Schedule"), 1);
     ui.kForecastCmb->addItem(KIcon("view-income-categories"), i18nc("Noun", "Budget"), 4);
 
     ui.kWidgetSelector->addButton(KIcon("configure"), i18n("Setup Report"), i18n("Display the edit panel for report"), ui.setupWidget);
     connect(ui.kWidgetSelector, SIGNAL(selectedModeChanged(int)), this, SLOT(onBtnModeClicked(int)));
 
-    //Set colors
+    // Set colors
     setSettings();
     if (SKGMainPanel::getMainPanel()) {
         connect(SKGMainPanel::getMainPanel(), SIGNAL(settingsChanged()), this, SLOT(setSettings()));
     }
 
-    //Build contextual menu
+    // Build contextual menu
     KMenu* tableMenu = ui.kTableWithGraph->getTableContextualMenu();
     if (tableMenu) {
         tableMenu->addSeparator();
@@ -115,7 +116,7 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGDocumentBank* iDocument, bool iM
 
     connect(m_openReportAction, SIGNAL(triggered(bool)), this, SLOT(onOpenReport()));
 
-    //Init comboboxes
+    // Init comboboxes
     m_attsForColumns << "d_date" << "d_DATEWEEK" << "d_DATEMONTH" << "d_DATEQUARTER" << "d_DATESEMESTER" << "d_DATEYEAR";
     m_attsForLines << "#NOTHING#" <<
                    "t_BANK" << "t_ACCOUNTTYPE" << "t_ACCOUNT" << "t_TOACCOUNT" <<
@@ -126,14 +127,15 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGDocumentBank* iDocument, bool iM
                    "t_status" <<
                    "t_UNITTYPE" << "t_UNIT" <<
                    "t_REALREFUND" <<
-                   "t_TRANSFER" ;
+                   "t_TRANSFER";
 
-    //Adding properties
+    // Adding properties
     QStringList properties;
     iDocument->getDistinctValues("parameters", "t_name", "t_uuid_parent like '%-operation' AND t_name NOT LIKE 'SKG_%'", properties);
     int nb = properties.count();
-    for (int i = 0; i < nb; ++i)
+    for (int i = 0; i < nb; ++i) {
         m_attsForLines.push_back("p_" % properties.at(i));
+    }
     m_attsForColumns += m_attsForLines;
 
     if (iDocument) {
@@ -149,7 +151,7 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGDocumentBank* iDocument, bool iM
 
     connect(ui.kTableWithGraph, SIGNAL(selectionChanged()), this, SLOT(onSelectionChanged()));
 
-    //Refresh
+    // Refresh
     connect(ui.kColumns, SIGNAL(currentIndexChanged(int)), this, SLOT(refresh()), Qt::QueuedConnection);
     connect(ui.kLines, SIGNAL(currentIndexChanged(int)), this, SLOT(refresh()), Qt::QueuedConnection);
     connect(ui.kMode, SIGNAL(currentIndexChanged(int)), this, SLOT(refresh()), Qt::QueuedConnection);
@@ -191,7 +193,7 @@ void SKGReportPluginWidget::onResetInternalFilter()
 {
     SKGTRACEIN(10, "SKGReportPluginWidget::onResetInternalFilter");
 
-    //Initialisation
+    // Initialisation
     m_lastState.clear();
     m_operationWhereClause = "";
     ui.kTitle->hide();
@@ -286,11 +288,11 @@ void SKGReportPluginWidget::setState(const QString& iState)
     m_operationWhereClause = root.attribute("operationWhereClause");
     QString nbLevelLinesString = root.attribute("nbLevelLines");
     QString nbLevelColumnsString = root.attribute("nbLevelColumns");
-    QString zoomPosition = root.attribute("zoomPosition");
+    QString zoomPositionString = root.attribute("zoomPosition");
     QString correctedby = root.attribute("correctedby");
     QString correctedbymode = root.attribute("correctedbymode");
 
-    //Default values
+    // Default values
     if (nbLevelLinesString.isEmpty()) nbLevelLinesString = '0';
     if (nbLevelColumnsString.isEmpty()) nbLevelColumnsString = '0';
     if (columns.isEmpty()) columns = m_attsForColumns.at(2);
@@ -332,7 +334,7 @@ void SKGReportPluginWidget::setState(const QString& iState)
     ui.kLine->setVisible(currentPageInt >= -1);
     ui.kForecastCmb->setCurrentIndex(ui.kForecastCmb->findData(SKGServices::stringToInt(forecast)));
     ui.kForecastValue->setValue(SKGServices::stringToInt(forecastValue));
-    if (!zoomPosition.isEmpty()) setZoomPosition(SKGServices::stringToInt(zoomPosition));
+    if (!zoomPositionString.isEmpty()) setZoomPosition(SKGServices::stringToInt(zoomPositionString));
     if (!correctedby.isEmpty()) ui.kCorrectedBy->setCurrentIndex(ui.kCorrectedBy->findText(correctedby));
     if (!correctedbymode.isEmpty()) ui.kCorrectedByMode->setCurrentIndex(ui.kCorrectedByMode->findText(correctedbymode));
 
@@ -349,10 +351,12 @@ void SKGReportPluginWidget::setState(const QString& iState)
     }
     if (!title_icon.isEmpty()) ui.kTitle->setPixmap(KIcon(title_icon).pixmap(22, 22), KTitleWidget::ImageLeft);
     if (!m_operationWhereClause.isEmpty()) {
-        //We keep a copy of given state in case of bookmark
+        // We keep a copy of given state in case of bookmark
         m_lastState = doc;
         dataModified("", 0);
-    } else m_lastState.clear();
+    } else {
+        m_lastState.clear();
+    }
     m_previousParametersUsed = "";
 }
 
@@ -377,7 +381,7 @@ QList< QWidget* > SKGReportPluginWidget::printableWidgets()
 
 void SKGReportPluginWidget::getWhereClauseAndTitleForSelection(int row, int column, QString& oWc, QString& oTitle)
 {
-    //Build where clause and title
+    // Build where clause and title
     QString currentComment = ui.kTitle->comment();
     if (!currentComment.isEmpty()) {
         currentComment.remove("<html><body><b>");
@@ -385,7 +389,7 @@ void SKGReportPluginWidget::getWhereClauseAndTitleForSelection(int row, int colu
         oTitle = SKGServices::htmlToString(currentComment) % ". ";
     }
 
-    //Condition on line attribute
+    // Condition on line attribute
     oTitle += i18nc("Noun, a list of items", "Sub operations with ");
     SKGColorButton* btn = qobject_cast<SKGColorButton*>(ui.kTableWithGraph->table()->cellWidget(row, 0));
 
@@ -410,11 +414,11 @@ void SKGReportPluginWidget::getWhereClauseAndTitleForSelection(int row, int colu
     QString lineVal = (btn ? btn->text() : ui.kTableWithGraph->table()->item(row, 0)->data(1).toString());
     QString title = ui.kTableWithGraph->table()->horizontalHeaderItem(0)->text();
     if (lineVal.isEmpty() && row == ui.kTableWithGraph->table()->rowCount() - 1) {
-        //This is the last sum
+        // This is the last sum
         oWc = "";
         if (!attLine.isEmpty()) oWc = attLine % " NOT LIKE '%#NULL#%'";
     } else {
-        //This is not the last sum
+        // This is not the last sum
         if (lineVal.isEmpty()) oWc += " IS NULL OR " % attLine;
         oWc += " = '" % SKGServices::stringToSqlString(lineVal) % "' OR " %
                attLine % " like '" % SKGServices::stringToSqlString(lineVal) % OBJECTSEPARATOR % "%'";
@@ -422,7 +426,7 @@ void SKGReportPluginWidget::getWhereClauseAndTitleForSelection(int row, int colu
         oTitle += i18nc("Noun",  "'%1' with '%2'", title, lineVal);
     }
 
-    //Condition on column attribute
+    // Condition on column attribute
     int nbCol = ui.kTableWithGraph->getNbColumns();
     QString att = m_attsForColumns[ui.kColumns->currentIndex()];
     if (att == "#NOTHING#") att = "";
@@ -453,7 +457,7 @@ void SKGReportPluginWidget::getWhereClauseAndTitleForSelection(int row, int colu
         }
     }
 
-    //Condition on other attribute
+    // Condition on other attribute
     if (!oWc.isEmpty()) {
         oWc += " AND ";
         oTitle += i18nc("Noun",  " and ");
@@ -464,7 +468,7 @@ void SKGReportPluginWidget::getWhereClauseAndTitleForSelection(int row, int colu
     if (ui.kPeriod->currentIndex() == 4) {
         during += SKGServices::dateToSqlString(QDateTime(ui.kDateBegin->date())) % ' ' % SKGServices::dateToSqlString(QDateTime(ui.kDateEnd->date()));
     } else if (ui.kPeriod->currentIndex() > 0) {
-        if (ui.kNbIntervals->isVisible()) during += ' ' % SKGServices::intToString(ui.kNbIntervals->value()) % ' ' ;
+        if (ui.kNbIntervals->isVisible()) during += ' ' % SKGServices::intToString(ui.kNbIntervals->value()) % ' ';
         during += ui.kInterval->text();
     }
 
@@ -472,7 +476,9 @@ void SKGReportPluginWidget::getWhereClauseAndTitleForSelection(int row, int colu
     if (ui.kIncomes->isChecked()) types.push_back(i18nc("Noun",  "incomes"));
     if (ui.kExpenses->isChecked()) types.push_back(i18nc("Noun",  "expenses"));
     if (ui.kTransfers->isChecked()) types.push_back(i18nc("Noun",  "transfers"));
-    else if (ui.kGrouped->isChecked()) types.push_back(i18nc("Noun",  "grouped"));
+    else if (ui.kGrouped->isChecked()) {
+        types.push_back(i18nc("Noun",  "grouped"));
+    }
     if (ui.kTracked->isChecked()) types.push_back(i18nc("Noun",  "tracked"));
 
     oTitle += i18nc("Noun",  "during '%1' for '%2'", during, types.join(" "));
@@ -508,15 +514,19 @@ void SKGReportPluginWidget::onOpenReport()
             getWhereClauseAndTitleForSelection(selection.at(i)->row(), selection.at(i)->column(), wc2, title2);
             if (!wc2.isEmpty()) {
                 if (!wc.isEmpty()) wc = '(' % wc % ") OR (" % wc2 % ')';
-                else wc = wc2;
+                else {
+                    wc = wc2;
+                }
             }
             if (!title2.isEmpty()) {
                 if (!title.isEmpty()) title = i18n("(%1) or (%2)", title, title2);
-                else title = title2;
+                else {
+                    title = title2;
+                }
             }
         }
 
-        //Call report plugin
+        // Call report plugin
         QDomDocument doc("SKGML");
         doc.setContent(getState());
         QDomElement root = doc.documentElement();
@@ -533,7 +543,9 @@ void SKGReportPluginWidget::onOneLevelMore()
 {
     _SKGTRACEIN(10, "SKGTableWithGraph::onOneLevelMore");
     if (sender() == ui.kLineUp) ++m_nbLevelLines;
-    else ++m_nbLevelColumns;
+    else {
+        ++m_nbLevelColumns;
+    }
     refresh();
 }
 
@@ -541,7 +553,9 @@ void SKGReportPluginWidget::onOneLevelLess()
 {
     _SKGTRACEIN(10, "SKGTableWithGraph::onOneLevelLess");
     if (sender() == ui.kLineDown) --m_nbLevelLines;
-    else --m_nbLevelColumns;
+    else {
+        --m_nbLevelColumns;
+    }
     refresh();
 }
 
@@ -562,7 +576,7 @@ void SKGReportPluginWidget::onRemoveLine()
 
 QString SKGReportPluginWidget::getConsolidatedWhereClause(QString* oWhereClausForPreviousData, QString*  oWhereClausForForecastData)
 {
-    //Build where clause
+    // Build where clause
     QString wc;
 
     int forecastmode = ui.kForecastCmb->itemData(ui.kForecastCmb->currentIndex()).toInt();
@@ -658,12 +672,12 @@ QString SKGReportPluginWidget::getConsolidatedWhereClause(QString* oWhereClausFo
         ui.kDateBegin->setDate(a);
         ui.kDateEnd->setDate(b);
         wc = "strftime(" % strfFormat % ",d_date)>=strftime(" % strfFormat % ",date('now','start of month', '-" % SKGServices::intToString(val) % ' ' % sqlInterval % "'))";
-        if (forecastmode != 1) wc += " AND strftime(" % strfFormat % ",d_date)<=strftime(" % strfFormat % ",date('now','start of month', '-" % SKGServices::intToString(one) % ' ' % sqlInterval % "'))"; //For forecast based on scheduled operations
+        if (forecastmode != 1) wc += " AND strftime(" % strfFormat % ",d_date)<=strftime(" % strfFormat % ",date('now','start of month', '-" % SKGServices::intToString(one) % ' ' % sqlInterval % "'))";  // For forecast based on scheduled operations
         if (oWhereClausForPreviousData) *oWhereClausForPreviousData = "strftime(" % strfFormat % ",d_date) < strftime(" % strfFormat % ",date('now','start of month', '-" % SKGServices::intToString(val) % ' ' % sqlInterval % "'))";
         if (oWhereClausForForecastData) *oWhereClausForForecastData = "strftime(" % strfFormat % ",d_date) > strftime(" % strfFormat % ",date('now','start of month', '-" % SKGServices::intToString(one) % ' ' % sqlInterval % "'))";
         break;
     case 3:
-        //Last Interval
+        // Last Interval
         switch (ui.kInterval->currentIndex()) {
         case 0:
             // Interval is in days
@@ -687,14 +701,14 @@ QString SKGReportPluginWidget::getConsolidatedWhereClause(QString* oWhereClausFo
         ui.kDateBegin->setDate(a);
         ui.kDateEnd->setDate(b);
         wc = "d_date > date('now','-" % SKGServices::intToString(val) % ' ' % sqlInterval % "')";
-        if (forecastmode != 1) wc += " AND d_date<=date('now')"; //For forecast based on scheduled operations
+        if (forecastmode != 1) wc += " AND d_date<=date('now')";  // For forecast based on scheduled operations
         if (oWhereClausForPreviousData) *oWhereClausForPreviousData = "d_date <= date('now','-" % SKGServices::intToString(val) % ' ' % sqlInterval % "')";
         if (oWhereClausForForecastData) *oWhereClausForForecastData = "d_date > date('now')";
         break;
     case 4:
         // Custom Date
         wc = "d_date>='" % SKGServices::dateToSqlString(QDateTime(ui.kDateBegin->date())) % '\'';
-        if (forecastmode != 1) wc += "AND d_date<='" % SKGServices::dateToSqlString(QDateTime(ui.kDateEnd->date())) % '\''; //For forecast based on scheduled operations
+        if (forecastmode != 1) wc += "AND d_date<='" % SKGServices::dateToSqlString(QDateTime(ui.kDateEnd->date())) % '\'';  // For forecast based on scheduled operations
         if (oWhereClausForPreviousData) *oWhereClausForPreviousData = "d_date<'" % SKGServices::dateToSqlString(QDateTime(ui.kDateBegin->date())) % '\'';
         if (oWhereClausForForecastData) *oWhereClausForForecastData = "d_date > date('now')";
         break;
@@ -727,7 +741,7 @@ QString SKGReportPluginWidget::getConsolidatedWhereClause(QString* oWhereClausFo
         ui.kDateBegin->setDate(a);
         ui.kDateEnd->setDate(b);
         wc = "d_date>='" % SKGServices::dateToSqlString(QDateTime(ui.kDateBegin->date())) % '\'';
-        if (forecastmode != 1) wc += "AND d_date<='" % SKGServices::dateToSqlString(QDateTime(ui.kDateEnd->date())) % '\''; //For forecast based on scheduled operations
+        if (forecastmode != 1) wc += "AND d_date<='" % SKGServices::dateToSqlString(QDateTime(ui.kDateEnd->date())) % '\'';  // For forecast based on scheduled operations
         if (oWhereClausForPreviousData) *oWhereClausForPreviousData = "d_date<'" % SKGServices::dateToSqlString(QDateTime(ui.kDateBegin->date())) % '\'';
         if (oWhereClausForForecastData) *oWhereClausForForecastData = "d_date>'" % SKGServices::dateToSqlString(QDateTime(ui.kDateEnd->date())) % '\'';
         break;
@@ -803,7 +817,7 @@ void SKGReportPluginWidget::refresh()
     ui.kCorrectedBy->setEnabled(mode != 3);
     ui.kCorrectedByMode->setEnabled(mode != 3);
 
-    //Check dates
+    // Check dates
     ui.kDateSelect->setVisible(p > 0);
     ui.kDateSelect->setEnabled(p == 4);
     ui.kTimeline->setVisible(p == 5);
@@ -815,10 +829,12 @@ void SKGReportPluginWidget::refresh()
         ui.kDateEnd->setDate(d1);
     }
 
-    //Check income & expense
+    // Check income & expense
     if (!ui.kIncomes->isChecked() && !ui.kExpenses->isChecked()) {
         if (sender() == ui.kIncomes) ui.kExpenses->setChecked(true);
-        else ui.kIncomes->setChecked(true);
+        else {
+            ui.kIncomes->setChecked(true);
+        }
     }
 
     bool current = (p == 1);
@@ -850,15 +866,15 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
     SKGTRACEIN(10, "SKGReportPluginWidget::dataModified");
     Q_UNUSED(iIdTransaction);
 
-    //Refresh panel
+    // Refresh panel
     QSqlDatabase* db = getDocument()->getDatabase();
     setEnabled(db != NULL);
-    //Check if needed
+    // Check if needed
     if (db != NULL && (iTableName == "v_operation_consolidated" || iTableName.isEmpty())) {
         SKGError err;
         SKGDocumentBank* doc = static_cast<SKGDocumentBank*>(getDocument());
         if (doc) {
-            //Check if update is needed
+            // Check if update is needed
             SKGTabPage* page = SKGTabPage::parentTabPage(this->parentWidget());
             SKGTabPage* cpage = SKGMainPanel::getMainPanel()->currentPage();
             if (page != NULL && page != cpage) {
@@ -876,7 +892,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
             m_refreshNeeded = false;
             m_previousParametersUsed = ParametersUsed;
 
-            //Fill line and create title
+            // Fill line and create title
             QString lineString;
             QString title;
             int nb = m_attsForLinesAdded.count();
@@ -895,59 +911,59 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
             ui.kLineLabel->setText(lineString);
             ui.kLineLabel->setToolTip(lineString);
 
-            //Get parameters
+            // Get parameters
             int col = ui.kColumns->currentIndex();
             int line = ui.kLines->currentIndex();
 
             if (col >= 0 && line >= 0) {
                 int mode = ui.kMode->itemData(ui.kMode->currentIndex()).toInt();
 
-                //Mode history ?
+                // Mode history ?
                 bool modeHistory = (mode == 1 || mode == 8);
 
-                //Get condition (must be done before forecast on scheduled operations)
+                // Get condition (must be done before forecast on scheduled operations)
                 int nbVirtualColumn = 0;
                 QString conditionPrevious;
                 QString conditionForecast;
                 QString condition = getConsolidatedWhereClause(&conditionPrevious, &conditionForecast);
                 int forecastMode = ui.kForecastCmb->itemData(ui.kForecastCmb->currentIndex()).toInt();
 
-                //Compute forecast on scheduled operations
+                // Compute forecast on scheduled operations
                 bool transactionToRollback = false;
                 if (forecastMode == 1 || forecastMode == 4) {
-                    //Create operations
+                    // Create operations
                     QDate lastDate = QDate::currentDate().addDays(ui.kForecastValue->value() * 365.0 / ui.kForecastValue->maximum());
                     if (forecastMode == 1) {
-                        //Create scheduled operations
+                        // Create scheduled operations
                         doc->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Create scheduled operations"));
                         transactionToRollback = true;
                         int nbInserted = 0;
                         SKGRecurrentOperationObject::process(doc, nbInserted, true, lastDate);
                     } else {
-                        //Create budgeted operations
+                        // Create budgeted operations
                         SKGObjectBase::SKGListSKGObjectBase budgets;
                         IFOKDO(err, doc->getObjects("v_budget",
                                                     "t_PERIOD>STRFTIME('%Y-%m', date('now')) AND "
                                                     "t_PERIOD<=STRFTIME('%Y-%m', '" % SKGServices::dateToSqlString(QDateTime(lastDate)) % "')", budgets));
-                        int nb = budgets.count();
-                        if (nb) {
-                            //Get most active account
+                        int nbBudgets = budgets.count();
+                        if (nbBudgets) {
+                            // Get most active account
                             SKGStringListList list;
                             err = doc->executeSelectSqliteOrder("SELECT account.id FROM account, operation WHERE +operation.rd_account_id=account.id AND d_date>date('now', '-3 month') GROUP BY (t_name) ORDER BY COUNT(1) DESC LIMIT 1", list);
                             if (!err && list.count() == 2) {
                                 SKGAccountObject account(doc, SKGServices::stringToInt(list.at(1).at(0)));
                                 err = account.load();
 
-                                //Get unit
+                                // Get unit
                                 SKGUnitObject unit(doc);
                                 IFOKDO(err, unit.setName(doc->getPrimaryUnit().Name))
                                 IFOKDO(err, unit.setSymbol(doc->getPrimaryUnit().Symbol))
                                 IFOKDO(err, unit.load())
 
 
-                                doc->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Create budgeted operations"), nb);
+                                doc->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Create budgeted operations"), nbBudgets);
                                 transactionToRollback = true;
-                                for (int i = 0; !err && i < nb; ++i) {
+                                for (int i = 0; !err && i < nbBudgets; ++i) {
                                     SKGBudgetObject budget(budgets.at(i));
 
                                     SKGCategoryObject cat;
@@ -976,7 +992,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                     conditionForecast = "1=0";
                 }
 
-                //Execute sql order
+                // Execute sql order
                 SKGStringListList table;
                 QString tableName = "v_operation_consolidated";
                 QString attCol = m_attsForColumns[col ];
@@ -989,8 +1005,8 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                 QStringList listAtt = m_attsForLinesAdded;
                 if (listAtt.count() == 0 || line > 0) listAtt.push_back(m_attsForLines.at(line));
                 QString attLine;
-                int nb = listAtt.count();
-                for (int i = 0; i < nb; ++i) {
+                int nb2 = listAtt.count();
+                for (int i = 0; i < nb2; ++i) {
                     QString att = listAtt.at(i);
                     if (att == "#NOTHING#") att = "";
                     if (att.startsWith(QLatin1String("p_"))) {
@@ -1014,11 +1030,11 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                     }
                 }
 
-                //Remove #NULL# columns and lines
+                // Remove #NULL# columns and lines
                 if (!attLine.isEmpty()) condition = '(' % condition % ") AND " % attLine % " NOT LIKE '%#NULL#%'";
                 if (!attCol.isEmpty()) condition = '(' % condition % ") AND " % attCol % " NOT LIKE '%#NULL#%'";
 
-                //Limit size of the result
+                // Limit size of the result
                 condition = '(' % condition % ") AND (d_date>(SELECT date('now', '-50 year')) OR d_date='0000')";
 
                 QString coef;
@@ -1026,7 +1042,9 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                     SKGUnitObject unit = ui.kCorrectedBy->getUnit();
                     QString id = SKGServices::intToString(unit.getID());
                     if (ui.kCorrectedByMode->currentIndex() == 0) coef = '*';
-                    else coef = '/';
+                    else {
+                        coef = '/';
+                    }
                     coef = coef % "COALESCE((SELECT u1.f_quantity FROM unitvalue u1 where u1.rd_unit_id=" % id % " and u1.d_date=(SELECT MAX(u2.d_date) FROM unitvalue u2 where u2.rd_unit_id=" % id % " and u2.d_date<=v_operation_consolidated.d_date)), (SELECT u1.f_quantity FROM unitvalue u1 where u1.rd_unit_id=" % id % " and u1.d_date=(SELECT MIN(u2.d_date) FROM unitvalue u2 where u2.rd_unit_id=" % id % ")),0)";
                 }
 
@@ -1041,19 +1059,19 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                     }
                 }
 
-                //Rollback create operations
+                // Rollback create operations
                 if (transactionToRollback) doc->endTransaction(false);
 
                 if (forecastMode == 1 || forecastMode == 4) {
-                    //Compute nb date in futur
+                    // Compute nb date in futur
                     if (nbLines) {
                         QStringList line1 = table.at(0);
                         int nbCol = line1.count();
                         for (int i = 0; i < nbCol; ++i) {
-                            QString title = line1.at(i);
-                            if (title.endsWith(QLatin1String("999"))) {
-                                title = title.left(title.count() - 3);
-                                line1.replace(i, title);
+                            QString newTitle = line1.at(i);
+                            if (newTitle.endsWith(QLatin1String("999"))) {
+                                newTitle = newTitle.left(newTitle.count() - 3);
+                                line1.replace(i, newTitle);
                                 ++nbVirtualColumn;
                             }
                         }
@@ -1062,9 +1080,9 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                 }
 
                 IFOK(err) {
-                    //Update title
+                    // Update title
                     if (nbLines) {
-                        //Change title
+                        // Change title
                         QStringList line1 = table.at(0);
                         if (line1.count()) {
                             line1.replace(0, title);
@@ -1072,47 +1090,47 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                         }
                     }
 
-                    //Compute forecast on average
+                    // Compute forecast on average
                     if (nbLines && (forecastMode == 2 || forecastMode == 3)) {
                         QStringList newLine = table.at(0);
                         int nbVals = newLine.count() - 1;
                         int percent = ui.kForecastValue->value();
                         if (nbVals >= 3 && percent > 0) {
-                            //Compute nb value to add
+                            // Compute nb value to add
                             nbVirtualColumn = percent * nbVals / FORECASTMAX;
 
-                            //Build header
+                            // Build header
                             for (int i = 0; i < nbVirtualColumn; ++i) {
                                 newLine.push_back(i18nc("Noun", "N %1", (i + 1)));
                             }
                             table.replace(0, newLine);
 
-                            //Build values
+                            // Build values
                             for (int j = 1; j < nbLines; ++j) {
-                                QStringList newLine = table.at(j);
+                                QStringList newLineTmp = table.at(j);
                                 for (int i = 0; i < nbVirtualColumn; ++i) {
-                                    //Moving average
+                                    // Moving average
                                     double nv = 0;
                                     double weight = 0;
                                     for (int k = 0; k < nbVirtualColumn; ++k) {
                                         if (forecastMode == 2) {
-                                            //Simple mode
-                                            nv += SKGServices::stringToDouble(newLine.at(nbVals + i - k));
+                                            // Simple mode
+                                            nv += SKGServices::stringToDouble(newLineTmp.at(nbVals + i - k));
                                             ++weight;
                                         } else {
-                                            //Weighted mode
-                                            nv += (nbVirtualColumn - k) * SKGServices::stringToDouble(newLine.at(nbVals + i - k));
+                                            // Weighted mode
+                                            nv += (nbVirtualColumn - k) * SKGServices::stringToDouble(newLineTmp.at(nbVals + i - k));
                                             weight += nbVirtualColumn - k;
                                         }
                                     }
-                                    newLine.push_back(SKGServices::doubleToString(nv / weight));
+                                    newLineTmp.push_back(SKGServices::doubleToString(nv / weight));
                                 }
-                                table.replace(j, newLine);
+                                table.replace(j, newLineTmp);
                             }
                         }
                     }
 
-                    //Create grouped by lines table
+                    // Create grouped by lines table
                     int nbLevelLineMax = 0;
                     {
                         SKGStringListList groupedByLineTable = table;
@@ -1122,15 +1140,15 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                             if (groupedByLineTable.count()) {
                                 nbCols = groupedByLineTable.at(0).count();
                             }
-                            for (int i = 1; nbCols && i < groupedByLineTable.count(); ++i) { //Dynamically modified
-                                QStringList line = groupedByLineTable.at(i);
-                                QString val = line.at(0);
+                            for (int i = 1; nbCols && i < groupedByLineTable.count(); ++i) {  // Dynamically modified
+                                QStringList line2 = groupedByLineTable.at(i);
+                                QString val = line2.at(0);
 
-                                //Rebuild val for the number of level
+                                // Rebuild val for the number of level
                                 QStringList vals = val.split(OBJECTSEPARATOR);
                                 int nbvals = vals.count();
                                 if (nbvals > m_nbLevelLines + 1) {
-                                    //Rebuild val
+                                    // Rebuild val
                                     val = "";
                                     for (int k = 0; k <= m_nbLevelLines; ++k) {
                                         val += vals[k];
@@ -1140,11 +1158,11 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                                 nbLevelLineMax = qMax(nbLevelLineMax, nbvals - 1);
 
                                 if (val == previousLineName) {
-                                    //Current line is merged with previous one
+                                    // Current line is merged with previous one
                                     QStringList newLine;
                                     newLine.push_back(val);
                                     for (int k = 1; k < nbCols; ++k) {
-                                        QString valstring1 = line.at(k);
+                                        QString valstring1 = line2.at(k);
                                         QString valstring2 = groupedByLineTable.at(i - 1).at(k);
 
                                         if (!valstring1.isEmpty() || !valstring2.isEmpty()) {
@@ -1159,15 +1177,15 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
 
                                     groupedByLineTable.replace(i - 1, newLine);
 
-                                    //Remove current line
+                                    // Remove current line
                                     groupedByLineTable.removeAt(i);
                                     --i;
                                 } else {
-                                    //Current line is just modified
+                                    // Current line is just modified
                                     QStringList newLine;
                                     newLine.push_back(val);
                                     for (int k = 1; k < nbCols; ++k) {
-                                        newLine.push_back(line.at(k));
+                                        newLine.push_back(line2.at(k));
                                     }
                                     groupedByLineTable.replace(i, newLine);
 
@@ -1178,21 +1196,21 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                         table = groupedByLineTable;
                     }
 
-                    //Create grouped by columns table
+                    // Create grouped by columns table
                     int nbLevelColMax = 0;
                     {
                         SKGStringListList groupedByColTable = table;
-                        int nbLines = groupedByColTable.count();
-                        if (nbLines) {
+                        int nbLines2 = groupedByColTable.count();
+                        if (nbLines2) {
                             QString previousColumnName = "###";
-                            for (int i = 1; nbLines && i < groupedByColTable.at(0).count(); ++i) { //Dynamically modified
+                            for (int i = 1; nbLines2 && i < groupedByColTable.at(0).count(); ++i) {  // Dynamically modified
                                 QString val = groupedByColTable.at(0).at(i);
 
-                                //Rebuild val for the number of level
+                                // Rebuild val for the number of level
                                 QStringList vals = val.split(OBJECTSEPARATOR);
                                 int nbvals = vals.count();
                                 if (nbvals > m_nbLevelColumns + 1) {
-                                    //Rebuild val
+                                    // Rebuild val
                                     val = "";
                                     for (int k = 0; k <= m_nbLevelColumns; ++k) {
                                         val += vals[k];
@@ -1202,12 +1220,12 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                                 nbLevelColMax = qMax(nbLevelColMax, nbvals - 1);
 
                                 if (val == previousColumnName) {
-                                    //Current column is merged with previous one
+                                    // Current column is merged with previous one
                                     QStringList newLine = groupedByColTable.at(0);
                                     newLine.removeAt(i);
                                     groupedByColTable.replace(0, newLine);
 
-                                    for (int k = 1; k < nbLines; ++k) {
+                                    for (int k = 1; k < nbLines2; ++k) {
                                         newLine = groupedByColTable.at(k);
                                         QString valstring1 = newLine.at(i);
                                         QString valstring2 = newLine.at(i - 1);
@@ -1224,10 +1242,10 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                                         groupedByColTable.replace(k, newLine);
                                     }
 
-                                    //Remove current line
+                                    // Remove current line
                                     --i;
                                 } else {
-                                    //Current column is just modified
+                                    // Current column is just modified
                                     QStringList newLine = groupedByColTable.at(0);
                                     newLine.replace(i, val);
                                     groupedByColTable.replace(0, newLine);
@@ -1239,21 +1257,21 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                         table = groupedByColTable;
                     }
 
-                    //Initialize parameters
+                    // Initialize parameters
                     SKGServices::SKGUnitInfo primaryUnit = doc->getPrimaryUnit();
                     SKGServices::SKGUnitInfo secondaryUnit = doc->getSecondaryUnit();
 
                     SKGTableWithGraph::DisplayAdditionalFlag dmode = SKGTableWithGraph::NONE;
                     if (m_attsForColumns.at(col).startsWith(QLatin1String("d_"))) dmode |= SKGTableWithGraph::AVERAGE | SKGTableWithGraph::LIMITS;
 
-                    //Create history (must be done after groups)
+                    // Create history (must be done after groups)
                     if (modeHistory) table = SKGServices::getHistorizedTable(table);
                     else {
-                        //Add SUM if not in HISTORY mode
+                        // Add SUM if not in HISTORY mode
                         dmode |= SKGTableWithGraph::SUM;
                     }
 
-                    //Mode percent
+                    // Mode percent
                     bool modePercent = (mode == 2 || mode == 4 || mode == 5 || mode == 6);
                     if (modePercent) {
                         primaryUnit.Symbol = '%';
@@ -1263,22 +1281,22 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                         table = SKGServices::getPercentTable(table, (mode == 2 || mode == 5), (mode == 5 || mode == 6));
                     }
 
-                    //Mode base 100
+                    // Mode base 100
                     if (mode == 7 || mode == 8) {
                         table = SKGServices::getBase100Table(table);
                     }
 
-                    //Mode Count
+                    // Mode Count
                     if (mode == 3) {
                         primaryUnit.Symbol = ' ';
                         SKGServices::SKGUnitInfo empty;
                         secondaryUnit = empty;
                     }
 
-                    //Set data
+                    // Set data
                     ui.kTableWithGraph->setData(table, primaryUnit, secondaryUnit, dmode, nbVirtualColumn);
 
-                    //Enable/Disable buttons
+                    // Enable/Disable buttons
                     m_nbLevelLines = qMin(nbLevelLineMax, m_nbLevelLines);
                     ui.kLineDown->setEnabled(m_nbLevelLines > 0);
                     ui.kLineUp->setEnabled(m_nbLevelLines < nbLevelLineMax);
@@ -1289,10 +1307,9 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                 }
             }
             QApplication::restoreOverrideCursor();
-
         }
 
-        //Display error
+        // Display error
         SKGMainPanel::displayErrorMessage(err);
     }
 }
