@@ -20,6 +20,13 @@
  * @author Stephane MANKOWSKI
  */
 #include "skgscheduledpluginwidget.h"
+
+#include <KLineEdit>
+
+#include <QDomDocument>
+#include <QHeaderView>
+#include <QKeyEvent>
+
 #include "skgmainpanel.h"
 #include "skgtraces.h"
 #include "skgdocumentbank.h"
@@ -28,12 +35,6 @@
 #include "skgtransactionmng.h"
 #include "skgoperationobject.h"
 
-#include <klineedit.h>
-
-#include <QDomDocument>
-#include <QHeaderView>
-#include <QKeyEvent>
-
 SKGScheduledPluginWidget::SKGScheduledPluginWidget(SKGDocumentBank* iDocument)
     : SKGTabPage(iDocument)
 {
@@ -42,7 +43,7 @@ SKGScheduledPluginWidget::SKGScheduledPluginWidget(SKGDocumentBank* iDocument)
 
     ui.setupUi(this);
 
-    //Set show widget
+    // Set show widget
     ui.kView->getShowWidget()->addGroupedItem("all", i18n("All"));
     ui.kView->getShowWidget()->addGroupedItem("ongoing", i18n("Ongoing"), "task-ongoing", "t_times='N' OR i_nb_times>0");
     ui.kView->getShowWidget()->addGroupedItem("finished", i18n("Complete"), "task-complete", "t_times='Y' AND i_nb_times=0");
@@ -53,7 +54,7 @@ SKGScheduledPluginWidget::SKGScheduledPluginWidget(SKGDocumentBank* iDocument)
     connect(ui.kView->getView(), SIGNAL(doubleClicked(QModelIndex)), SKGMainPanel::getMainPanel()->getGlobalAction("open"), SLOT(trigger()));
     connect(ui.kView->getView(), SIGNAL(selectionChangedDelayed()), this, SLOT(onSelectionChanged()));
 
-    //Add registered global action in contextual menu
+    // Add registered global action in contextual menu
     if (SKGMainPanel::getMainPanel()) {
         ui.kView->getView()->insertGlobalAction();
         ui.kView->getView()->insertGlobalAction("open");
@@ -67,7 +68,7 @@ SKGScheduledPluginWidget::SKGScheduledPluginWidget(SKGDocumentBank* iDocument)
         ui.kView->getView()->insertGlobalAction();
     }
 
-    //Add Standard KDE Icons to buttons to Operations
+    // Add Standard KDE Icons to buttons to Operations
     ui.kModifyBtn->setIcon(KIcon("dialog-ok-apply"));
     ui.kProcessBtn->setIcon(KIcon("system-run"));
     connect(ui.kProcessBtn, SIGNAL(clicked(bool)), SLOT(onProcess()));
@@ -85,7 +86,7 @@ SKGScheduledPluginWidget::SKGScheduledPluginWidget(SKGDocumentBank* iDocument)
     getDocument()->existObjects("recurrentoperation", "", exist);
     ui.kTitle->setVisible(!exist);
 
-    //Set Event filters to catch CTRL+ENTER or SHIFT+ENTER
+    // Set Event filters to catch CTRL+ENTER or SHIFT+ENTER
     this->installEventFilter(this);
 }
 
@@ -94,11 +95,11 @@ SKGScheduledPluginWidget::~SKGScheduledPluginWidget()
     SKGTRACEIN(1, "SKGScheduledPluginWidget::~SKGScheduledPluginWidget");
 }
 
-bool SKGScheduledPluginWidget::eventFilter(QObject* object, QEvent* event)
+bool SKGScheduledPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 {
-    if (event && event->type() == QEvent::KeyPress) {
-        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
-        if ((keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && object == this) {
+    if (iEvent && iEvent->type() == QEvent::KeyPress) {
+        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(iEvent);
+        if ((keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && iObject == this) {
             if (QApplication::keyboardModifiers() &Qt::ShiftModifier && ui.kModifyBtn->isEnabled()) {
                 ui.kModifyBtn->click();
             }
@@ -130,7 +131,7 @@ void SKGScheduledPluginWidget::setState(const QString& iState)
 
     if (!selection.isEmpty()) {
         QStringList uuids = SKGServices::splitCSVLine(selection);
-        ui.kView->getView()->selectObjects(uuids, true);  //FIXME //TODO
+        ui.kView->getView()->selectObjects(uuids, true);  // FIXME // TODO(Stephane MANKOWSKI)
         onSelectionChanged();
     }
 }
@@ -147,11 +148,10 @@ QWidget* SKGScheduledPluginWidget::mainWidget()
 
 void SKGScheduledPluginWidget::onJumpToTheOperation()
 {
-    //Get selection
+    // Get selection
     SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
     if (selection.count() > 0) {
-
-        //Build where clause and title
+        // Build where clause and title
         QString wc = "id IN (";
         QString title = i18nc("Noun, a list of items", "Operations of the schedule");
         int nb = selection.count();
@@ -166,10 +166,9 @@ void SKGScheduledPluginWidget::onJumpToTheOperation()
         }
         wc += ')';
 
-        //Call operation plugin
+        // Call operation plugin
         SKGMainPanel::getMainPanel()->openPage("skg://skrooge_operation_plugin/?template=Y&title_icon=chronometer&operationTable=v_operation_display_all&title=" %
-                                               SKGServices::encodeForUrl(title) % "&operationWhereClause=" % SKGServices::encodeForUrl(wc)
-                                              );
+                                               SKGServices::encodeForUrl(title) % "&operationWhereClause=" % SKGServices::encodeForUrl(wc));
     }
 }
 
@@ -211,8 +210,8 @@ void SKGScheduledPluginWidget::onNbOccurrenceChanged()
     int p = ui.kOnceEveryVal->value();
 
     if (ui.kLastOccurenceDate == this->sender()) {
-        //End date has been modified.
-        //We must set the number of occurrence
+        // End date has been modified.
+        // We must set the number of occurrence
         QDate lastDate = ui.kLastOccurenceDate->date();
         if (lastDate <= firstDate) {
             ui.kLastOccurenceDate->setDate(firstDate);
@@ -222,7 +221,9 @@ void SKGScheduledPluginWidget::onNbOccurrenceChanged()
             if (punit == SKGRecurrentOperationObject::DAY) nbd = nbd / p;
             else if (punit == SKGRecurrentOperationObject::MONTH) {
                 nbd = (lastDate.day() >= firstDate.day() ? 0 : -1) + (lastDate.year() - firstDate.year()) * 12 + (lastDate.month() - firstDate.month());
-            } else if (punit == SKGRecurrentOperationObject::YEAR) nbd = nbd / (365 * p);
+            } else if (punit == SKGRecurrentOperationObject::YEAR) {
+                nbd = nbd / (365 * p);
+            }
 
             bool previous = ui.kNbTimesVal->blockSignals(true);
             ui.kNbTimesVal->setValue(nbd + 1);
@@ -230,11 +231,14 @@ void SKGScheduledPluginWidget::onNbOccurrenceChanged()
         }
 
     } else {
-        //We must compute the date
+        // We must compute the date
         p *= (ui.kNbTimesVal->value() - 1);
         if (punit == SKGRecurrentOperationObject::DAY) firstDate = firstDate.addDays(p);
-        else if (punit == SKGRecurrentOperationObject::MONTH) firstDate = firstDate.addMonths(p);
-        else if (punit == SKGRecurrentOperationObject::YEAR) firstDate = firstDate.addYears(p);
+        else if (punit == SKGRecurrentOperationObject::MONTH) {
+            firstDate = firstDate.addMonths(p);
+        } else if (punit == SKGRecurrentOperationObject::YEAR) {
+            firstDate = firstDate.addYears(p);
+        }
 
         bool previous = ui.kLastOccurenceDate->blockSignals(true);
         ui.kLastOccurenceDate->setDate(firstDate);
@@ -247,16 +251,16 @@ void SKGScheduledPluginWidget::onUpdate()
     SKGError err;
     SKGTRACEINRC(10, "SKGScheduledPluginWidget::onUpdate", err);
     {
-        //Get Selection
+        // Get Selection
         SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
 
         int nb = selection.count();
         SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Recurrent operation update"), err, nb);
         for (int i = 0; !err && i < nb; ++i) {
-            //Get the real object, not the object from the view
+            // Get the real object, not the object from the view
             SKGRecurrentOperationObject recOp = SKGRecurrentOperationObject(selection.at(i).getDocument(), selection.at(i).getID());
 
-            //Update it
+            // Update it
             if (nb == 1) err = recOp.setDate(ui.kFirstOccurenceDate->date());
             IFOKDO(err, recOp.setPeriodIncrement(ui.kOnceEveryVal->value()))
             IFOKDO(err, recOp.setPeriodUnit(static_cast<SKGRecurrentOperationObject::PeriodUnit>(ui.kOnceEveryUnit->currentIndex())))
@@ -271,11 +275,13 @@ void SKGScheduledPluginWidget::onUpdate()
             IFOKDO(err, getDocument()->stepForward(i + 1))
         }
     }
-    //status bar
+    // status bar
     IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Recurrent operation updated.")))
-    else err.addError(ERR_FAIL, i18nc("Error message",  "Update failed"));
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message",  "Update failed"));
+    }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
@@ -289,26 +295,28 @@ void SKGScheduledPluginWidget::onProcess(bool iImmediately)
     SKGError err;
     SKGTRACEINRC(10, "SKGScheduledPluginWidget::onProcess", err);
     {
-        //Get Selection
+        // Get Selection
         SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
 
         int nb = selection.count();
         SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Insert recurrent operations"), err, nb);
         for (int i = 0; !err && i < nb; ++i) {
-            //Get the real object, not the object from the view
+            // Get the real object, not the object from the view
             SKGRecurrentOperationObject recOp = SKGRecurrentOperationObject(selection.at(i).getDocument(), selection.at(i).getID());
 
-            //Process it
+            // Process it
             int nbi = 0;
             err = recOp.process(nbi, true, (iImmediately ? recOp.getDate() : QDate::currentDate()));
             IFOKDO(err, getDocument()->stepForward(i + 1))
         }
     }
-    //status bar
+    // status bar
     IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Recurrent operation inserted.")))
-    else err.addError(ERR_FAIL, i18nc("Error message",  "Insertion failed"));
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message",  "Insertion failed"));
+    }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
