@@ -20,6 +20,11 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgalarmboardwidget.h"
+
+#include <KAction>
+
+#include <QDomDocument>
+
 #include "skgdocumentbank.h"
 #include "skgtraces.h"
 #include "skgservices.h"
@@ -29,23 +34,19 @@
 #include "skgruleobject.h"
 #include "skgprogressbar.h"
 
-#include <kaction.h>
-
-#include <QDomDocument>
-
 SKGAlarmBoardWidget::SKGAlarmBoardWidget(SKGDocument* iDocument)
     : SKGBoardWidget(iDocument, i18nc("Dashboard widget title", "Alarms"))
 {
     SKGTRACEIN(10, "SKGAlarmBoardWidget::SKGAlarmBoardWidget");
 
-    //Create widget
+    // Create widget
     m_frame = new QFrame();
     m_layout = new QVBoxLayout(m_frame);
     m_layout->setSpacing(2);
     m_layout->setContentsMargins(0, 0, 0, 0);
     setMainWidget(m_frame);
 
-    //Create menu
+    // Create menu
     setContextMenuPolicy(Qt::ActionsContextMenu);
 
     KAction* open = new KAction(KIcon("skg_open"), i18nc("Verb, open a page", "Open..."), this);
@@ -59,7 +60,7 @@ SKGAlarmBoardWidget::SKGAlarmBoardWidget(SKGDocument* iDocument)
     connect(m_menuFavorite, SIGNAL(triggered(bool)), this, SLOT(dataModified()));
     addAction(m_menuFavorite);
 
-    //Refresh
+    // Refresh
     connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
 }
 
@@ -97,7 +98,7 @@ void SKGAlarmBoardWidget::dataModified(const QString& iTableName, int iIdTransac
     Q_UNUSED(iIdTransaction);
 
     if (iTableName == "operation" || iTableName == "rule" || iTableName.isEmpty()) {
-        //Remove all item of the layout
+        // Remove all item of the layout
         QLayoutItem* child = NULL;
         while ((child = m_layout->takeAt(0)) != 0) {
             QWidget* w = child->widget();
@@ -105,13 +106,13 @@ void SKGAlarmBoardWidget::dataModified(const QString& iTableName, int iIdTransac
             delete child;
         }
 
-        //Fill layout
+        // Fill layout
         SKGDocumentBank* doc = qobject_cast<SKGDocumentBank*>(getDocument());
         if (doc) {
             SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
             SKGServices::SKGUnitInfo secondary = doc->getSecondaryUnit();
 
-            //Build where clause
+            // Build where clause
             QString wc = "t_action_type='A'";
             if (m_menuFavorite && m_menuFavorite->isChecked()) {
                 wc = "t_bookmarked='Y' AND (" % wc % ')';
@@ -125,19 +126,19 @@ void SKGAlarmBoardWidget::dataModified(const QString& iTableName, int iIdTransac
                     SKGRuleObject rule(rules.at(i));
                     SKGRuleObject::SKGAlarmInfo alarm = rule.getAlarmInfo();
 
-                    //Create progress bar
+                    // Create progress bar
                     SKGProgressBar* progressBar = new SKGProgressBar(m_frame);
                     progressBar->setObjectName(QString::fromUtf8("progressBar"));
                     progressBar->setMaximum(qMax(alarm.Amount, alarm.Limit));
                     progressBar->setValue(alarm.Amount);
 
-                    QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
-                    sizePolicy.setHorizontalStretch(0);
-                    sizePolicy.setVerticalStretch(0);
-                    sizePolicy.setHeightForWidth(progressBar->sizePolicy().hasHeightForWidth());
-                    progressBar->setSizePolicy(sizePolicy);
+                    QSizePolicy newSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
+                    newSizePolicy.setHorizontalStretch(0);
+                    newSizePolicy.setVerticalStretch(0);
+                    newSizePolicy.setHeightForWidth(progressBar->sizePolicy().hasHeightForWidth());
+                    progressBar->setSizePolicy(newSizePolicy);
 
-                    //Set tooltip
+                    // Set tooltip
                     QString txt = alarm.Message % "<br>";
                     txt += doc->formatMoney(alarm.Amount, primary) % " / " % doc->formatMoney(alarm.Limit, primary);
                     if (!secondary.Symbol.isEmpty() && secondary.Value) {
@@ -145,10 +146,10 @@ void SKGAlarmBoardWidget::dataModified(const QString& iTableName, int iIdTransac
                     }
                     progressBar->setToolTip(txt);
 
-                    //Change color
+                    // Change color
                     progressBar->setLimits(qMax(alarm.Amount, alarm.Limit), 0.9 * alarm.Limit, 0.7 * alarm.Limit);
 
-                    //Add progress bar
+                    // Add progress bar
                     m_layout->addWidget(progressBar);
                 }
             } else {
@@ -157,11 +158,11 @@ void SKGAlarmBoardWidget::dataModified(const QString& iTableName, int iIdTransac
                 lab->setText(i18nc("Message", "No alarm defined<br>on the <a href=\"%1\">\"Search and process\"</a> page.", "skg://Skrooge_search_plugin"));
                 connect(lab, SIGNAL(linkActivated(QString)), SKGMainPanel::getMainPanel(), SLOT(openPage(QString)));
 
-                //Add progress bar
+                // Add progress bar
                 m_layout->addWidget(lab);
             }
 
-            //No widget if no account
+            // No widget if no account
             bool exist = false;
             getDocument()->existObjects("account", "", exist);
             if (parentWidget()) setVisible(exist);
