@@ -20,6 +20,13 @@
  * @author Stephane MANKOWSKI
  */
 #include "skgsearchpluginwidget.h"
+
+#include <KStandardDirs>
+
+#include <QDomDocument>
+#include <QDir>
+#include <QKeyEvent>
+
 #include "skgobjectmodel.h"
 #include "skgmainpanel.h"
 #include "skgtraces.h"
@@ -29,12 +36,6 @@
 #include "skgcategoryobject.h"
 #include "skgruleobject.h"
 
-#include <kstandarddirs.h>
-
-#include <QDomDocument>
-#include <QDir>
-#include <QKeyEvent>
-
 SKGSearchPluginWidget::SKGSearchPluginWidget(SKGDocument* iDocument)
     : SKGTabPage(iDocument)
 {
@@ -50,7 +51,7 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(SKGDocument* iDocument)
     ui.kView->getShowWidget()->addItem("highlighted", i18nc("Adjective, an highlighted item", "Highlighted"), "bookmarks", "t_bookmarked='Y'", "", "", "");
     ui.kView->getShowWidget()->setDefaultState("search;update;alarm;highlighted");
 
-    //Add Standard KDE Icons to buttons
+    // Add Standard KDE Icons to buttons
     ui.kUpdate->setIcon(KIcon("dialog-ok-apply"));
     ui.kAdd->setIcon(KIcon("list-add"));
     ui.kSearch->setIcon(KIcon("edit-find"));
@@ -84,13 +85,13 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(SKGDocument* iDocument)
         ui.kWidgetSelector->addButton(KIcon("dialog-warning"), i18n("Alarm"), i18n("Display the edit panel for alarm"), list);
     }
 
-    //Fill combo boxes
+    // Fill combo boxes
     QStringList attributeForQuery;
     attributeForQuery << "d_date" << "i_number" << "t_mode" << "t_PAYEE" << "t_comment" << "t_REALCOMMENT" << "t_REALCATEGORY" << "t_status" << "t_bookmarked" << "t_imported" << "t_TRANSFER" << "t_UNIT" << "t_ACCOUNT" << "t_TOACCOUNT" << "f_REALCURRENTAMOUNT" << "t_REALREFUND" << "f_BALANCE";
     QStringList attributeForUpdate;
     attributeForUpdate << "d_date" << "i_number" << "t_mode" << "t_PAYEE" << "t_comment" << "t_status" << "t_bookmarked" << "t_imported" << "t_REALCOMMENT" << "t_REALCATEGORY" << "t_ACCOUNT" << "t_REALREFUND" << "t_UNIT";
 
-    //Adding properties
+    // Adding properties
     QStringList properties;
     iDocument->getDistinctValues("parameters", "t_name", "t_uuid_parent like '%-operation' AND t_name NOT LIKE 'SKG_%'", properties);
     int nb = properties.count();
@@ -102,11 +103,11 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(SKGDocument* iDocument)
     ui.kQueryCreator->setParameters(iDocument, "v_operation_consolidated", attributeForQuery);
     ui.kActionCreator->setParameters(iDocument, "v_operation_consolidated", attributeForUpdate, true);
 
-    //Bind operation view
+    // Bind operation view
     ui.kView->setModel(new SKGObjectModel(static_cast<SKGDocumentBank*>(getDocument()), "v_rule_display", "1=1 ORDER BY f_sortorder", this, "", false));
     ui.kView->getView()->sortByColumn(0, Qt::AscendingOrder);
 
-    //Add registered global action in contextual menu
+    // Add registered global action in contextual menu
     if (SKGMainPanel::getMainPanel()) {
         ui.kView->getView()->insertGlobalAction();
         ui.kView->getView()->insertGlobalAction("open");
@@ -137,13 +138,13 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(SKGDocument* iDocument)
     connect(ui.kView->getView(), SIGNAL(doubleClicked(QModelIndex)), SKGMainPanel::getMainPanel()->getGlobalAction("open"), SLOT(trigger()));
     connect(ui.kView->getView(), SIGNAL(selectionChangedDelayed()), this, SLOT(onSelectionChanged()));
 
-    //Refresh
+    // Refresh
     connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
     dataModified("", 0);
 
     onSelectionChanged();
 
-    //Set Event filters to catch CTRL+ENTER or SHIFT+ENTER
+    // Set Event filters to catch CTRL+ENTER or SHIFT+ENTER
     this->installEventFilter(this);
 }
 
@@ -152,11 +153,11 @@ SKGSearchPluginWidget::~SKGSearchPluginWidget()
     SKGTRACEIN(1, "SKGSearchPluginWidget::~SKGSearchPluginWidget");
 }
 
-bool SKGSearchPluginWidget::eventFilter(QObject* object, QEvent* event)
+bool SKGSearchPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 {
-    if (event && event->type() == QEvent::KeyPress) {
-        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
-        if ((keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && object == this) {
+    if (iEvent && iEvent->type() == QEvent::KeyPress) {
+        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(iEvent);
+        if ((keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && iObject == this) {
             if (QApplication::keyboardModifiers() &Qt::ControlModifier && ui.kAdd->isEnabled()) {
                 ui.kAdd->click();
             } else if (QApplication::keyboardModifiers() &Qt::ShiftModifier && ui.kUpdate->isEnabled()) {
@@ -210,7 +211,7 @@ SKGObjectBase::SKGListSKGObjectBase SKGSearchPluginWidget::getSelectedObjects()
 {
     SKGObjectBase::SKGListSKGObjectBase list = ui.kView->getView()->getSelectedObjects();
 
-    //Sort selection by f_sortorder. It's mandatory for reorder functions
+    // Sort selection by f_sortorder. It's mandatory for reorder functions
     qStableSort(list.begin(), list.end());
 
     return list;
@@ -226,7 +227,7 @@ void SKGSearchPluginWidget::dataModified(const QString& iTableName, int iIdTrans
     SKGTRACEIN(1, "SKGSearchPluginWidget::dataModified");
     Q_UNUSED(iIdTransaction);
 
-    //Refresh account list
+    // Refresh account list
     if (iTableName == "unit" || iTableName.isEmpty()) {
         ui.kAlarmUnit->setText(static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit().Symbol);
     }
@@ -250,14 +251,16 @@ void SKGSearchPluginWidget::onAddRule()
             IFOKDO(err, rule.save())
         }
 
-        //status bar
+        // status bar
         IFOK(err) {
             err = SKGError(0, i18nc("Successful message after an user action", "Search and process created"));
             ui.kView->getView()->selectObject(rule.getUniqueID());
-        } else err.addError(ERR_FAIL, i18nc("Error message",  "Search and process creation failed"));
+        } else {
+            err.addError(ERR_FAIL, i18nc("Error message",  "Search and process creation failed"));
+        }
     }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
@@ -277,7 +280,7 @@ void SKGSearchPluginWidget::onOpen()
     IFOK(err) open(rule, (sender() == ui.kSearch ? SKGSearchPluginWidget::TABLE : SKGSearchPluginWidget::REPORT));
     QApplication::restoreOverrideCursor();
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
@@ -298,11 +301,13 @@ void SKGSearchPluginWidget::onModifyRule()
         }
     }
 
-    //status bar
+    // status bar
     IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Search and process updated")))
-    else err.addError(ERR_FAIL, i18nc("Error message",  "Search and process update failed"));
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message",  "Search and process update failed"));
+    }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
@@ -325,10 +330,10 @@ void SKGSearchPluginWidget::onSelectionChanged()
         int index = qMax(0, static_cast<int>(rule.getActionType()));
         if (ui.kWidgetSelector->getSelectedMode() != -1) ui.kWidgetSelector->setSelectedMode(index);
         if (index == 1) {
-            //Set update mode
+            // Set update mode
             ui.kActionCreator->setXMLCondition(rule.getXMLActionDefinition());
         } else if (index == 2) {
-            //Set alarm mode
+            // Set alarm mode
             QDomDocument doc("SKGML");
             doc.setContent(rule.getXMLActionDefinition());
 
@@ -350,7 +355,7 @@ void SKGSearchPluginWidget::onTop()
     SKGError err;
     SKGTRACEINRC(1, "SKGSearchPluginWidget::onTop", err);
 
-    //Get rules
+    // Get rules
     SKGObjectBase::SKGListSKGObjectBase  rules = getSelectedObjects();
     int nb = rules.count();
     {
@@ -366,15 +371,16 @@ void SKGSearchPluginWidget::onTop()
             IFOKDO(err, rule.setOrder(order))
             IFOKDO(err, rule.save())
             IFOKDO(err, getDocument()->stepForward(i + 1))
-
         }
     }
 
-    //status bar
+    // status bar
     IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Search updated")))
-    else err.addError(ERR_FAIL, i18nc("Error message",  "Search update failed"));
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message",  "Search update failed"));
+    }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
@@ -383,7 +389,7 @@ void SKGSearchPluginWidget::onUp()
     SKGError err;
     SKGTRACEINRC(1, "SKGSearchPluginWidget::onUp", err);
 
-    //Get rules
+    // Get rules
     SKGObjectBase::SKGListSKGObjectBase  rules = getSelectedObjects();
     int nb = rules.count();
     {
@@ -405,15 +411,16 @@ void SKGSearchPluginWidget::onUp()
             IFOKDO(err, rule.setOrder(order))
             IFOKDO(err, rule.save())
             IFOKDO(err, getDocument()->stepForward(i + 1))
-
         }
     }
 
-    //status bar
+    // status bar
     IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Search updated")))
-    else err.addError(ERR_FAIL, i18nc("Error message",  "Search update failed"));
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message",  "Search update failed"));
+    }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
@@ -422,7 +429,7 @@ void SKGSearchPluginWidget::onDown()
     SKGError err;
     SKGTRACEINRC(1, "SKGSearchPluginWidget::onDown", err);
 
-    //Get rules
+    // Get rules
     SKGObjectBase::SKGListSKGObjectBase  rules = getSelectedObjects();
     int nb = rules.count();
     {
@@ -444,15 +451,16 @@ void SKGSearchPluginWidget::onDown()
             IFOKDO(err, rule.setOrder(order))
             IFOKDO(err, rule.save())
             IFOKDO(err, getDocument()->stepForward(i + 1))
-
         }
     }
 
-    //status bar
+    // status bar
     IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Search updated")))
-    else err.addError(ERR_FAIL, i18nc("Error message",  "Search update failed"));
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message",  "Search update failed"));
+    }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
@@ -461,7 +469,7 @@ void SKGSearchPluginWidget::onBottom()
     SKGError err;
     SKGTRACEINRC(1, "SKGSearchPluginWidget::onBottom", err);
 
-    //Get rules
+    // Get rules
     SKGObjectBase::SKGListSKGObjectBase  rules = getSelectedObjects();
     int nb = rules.count();
     {
@@ -477,15 +485,16 @@ void SKGSearchPluginWidget::onBottom()
             IFOKDO(err, rule.setOrder(order))
             IFOKDO(err, rule.save())
             IFOKDO(err, getDocument()->stepForward(i + 1))
-
         }
     }
 
-    //status bar
+    // status bar
     IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Search updated")))
-    else err.addError(ERR_FAIL, i18nc("Error message",  "Search update failed"));
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message",  "Search update failed"));
+    }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
@@ -493,11 +502,11 @@ void SKGSearchPluginWidget::open(const SKGRuleObject& iRule, OpenMode iMode)
 {
     _SKGTRACEIN(10, "SKGSearchPluginWidget::open");
 
-    //Build where clause and title
+    // Build where clause and title
     QString wc = "i_SUBOPID in (SELECT i_SUBOPID FROM v_operation_prop WHERE " % iRule.getSelectSqlOrder() % ')';
     QString title = i18nc("Noun, a list of items", "Sub operations corresponding to rule '%1'",  iRule.getSearchDescription());
 
-    //Call operation plugin
+    // Call operation plugin
     QDomDocument doc("SKGML");
     doc.setContent(SKGMainPanel::getMainPanel()->getDocument()->getParameter(iMode == TABLE ? "SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS" : "SKGREPORT_DEFAULT_PARAMETERS"));
     QDomElement root = doc.documentElement();
@@ -530,7 +539,7 @@ void SKGSearchPluginWidget::onEditorModified()
     if (nbSelect == 1) {
         SKGRuleObject rule(selection.at(0));
 
-        //Build where clause and title
+        // Build where clause and title
         QString wc = rule.getSelectSqlOrder();
 
         SKGStringListList result;
@@ -562,10 +571,10 @@ QString SKGSearchPluginWidget::getXMLActionDefinition()
 {
     QString output;
     if (ui.kWidgetSelector->getSelectedMode() == 1) {
-        //Mode update
+        // Mode update
         output = ui.kActionCreator->getXMLCondition();
     } else if (ui.kWidgetSelector->getSelectedMode() == 2) {
-        //Mode alarm
+        // Mode alarm
         QDomDocument doc("SKGML");
         QDomElement element = doc.createElement("element");
         doc.appendChild(element);
