@@ -20,6 +20,10 @@
  * @author Stephane MANKOWSKI
  */
 #include "skgtrackerpluginwidget.h"
+
+#include <QDomDocument>
+#include <QKeyEvent>
+
 #include "skgmainpanel.h"
 #include "skgtraces.h"
 #include "skgobjectmodel.h"
@@ -27,9 +31,6 @@
 #include "skgtrackerobject.h"
 #include "skgtransactionmng.h"
 
-#include <QDomDocument>
-#include <QKeyEvent>
-
 SKGTrackerPluginWidget::SKGTrackerPluginWidget(SKGDocument* iDocument)
     : SKGTabPage(iDocument)
 {
@@ -38,7 +39,7 @@ SKGTrackerPluginWidget::SKGTrackerPluginWidget(SKGDocument* iDocument)
 
     ui.setupUi(this);
 
-    //Set show widget
+    // Set show widget
     ui.kView->getShowWidget()->addGroupedItem("all", i18n("All"));
     ui.kView->getShowWidget()->addGroupedItem("opened", i18n("Opened"), "task-ongoing", "t_close='N'");
     ui.kView->getShowWidget()->addGroupedItem("closed", i18n("Closed"), "dialog-close", "t_close='Y'");
@@ -52,7 +53,7 @@ SKGTrackerPluginWidget::SKGTrackerPluginWidget(SKGDocument* iDocument)
 
     ui.kView->setModel(new SKGObjectModel(static_cast<SKGDocumentBank*>(getDocument()), "v_refund_display", "1=0", this, "", false));
 
-    //Add registered global action in contextual menu
+    // Add registered global action in contextual menu
     if (SKGMainPanel::getMainPanel()) {
         ui.kView->getView()->insertGlobalAction();
         ui.kView->getView()->insertGlobalAction("open");
@@ -69,7 +70,7 @@ SKGTrackerPluginWidget::SKGTrackerPluginWidget(SKGDocument* iDocument)
     connect(ui.kView->getView(), SIGNAL(doubleClicked(QModelIndex)), SKGMainPanel::getMainPanel()->getGlobalAction("open"), SLOT(trigger()));
     connect(ui.kView->getView(), SIGNAL(selectionChangedDelayed()), this, SLOT(onSelectionChanged()));
 
-    //Set Event filters to catch CTRL+ENTER or SHIFT+ENTER
+    // Set Event filters to catch CTRL+ENTER or SHIFT+ENTER
     this->installEventFilter(this);
 
     dataModified("", 0);
@@ -80,11 +81,11 @@ SKGTrackerPluginWidget::~SKGTrackerPluginWidget()
     SKGTRACEIN(1, "SKGTrackerPluginWidget::~SKGTrackerPluginWidget");
 }
 
-bool SKGTrackerPluginWidget::eventFilter(QObject* object, QEvent* event)
+bool SKGTrackerPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 {
-    if (event && event->type() == QEvent::KeyPress) {
-        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
-        if ((keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && object == this) {
+    if (iEvent && iEvent->type() == QEvent::KeyPress) {
+        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(iEvent);
+        if ((keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && iObject == this) {
             if (QApplication::keyboardModifiers() &Qt::ControlModifier && ui.kAddButton->isEnabled()) {
                 ui.kAddButton->click();
             } else if (QApplication::keyboardModifiers() &Qt::ShiftModifier && ui.kModifyButton->isEnabled()) {
@@ -158,7 +159,7 @@ void SKGTrackerPluginWidget::dataModified(const QString& iTableName, int iIdTran
     Q_UNUSED(iIdTransaction);
 
     if (iTableName == "refund" || iTableName.isEmpty()) {
-        //Set completions
+        // Set completions
         SKGMainPanel::fillWithDistinctValue(ui.kNameInput, getDocument(), "refund", "t_name", "", true);
         SKGMainPanel::fillWithDistinctValue(ui.kCommentEdit, getDocument(), "refund", "t_comment", "", true);
     }
@@ -179,13 +180,15 @@ void SKGTrackerPluginWidget::onAddTracker()
         IFOKDO(err, tracker.save())
     }
 
-    //status bar
+    // status bar
     IFOK(err) {
         err = SKGError(0, i18nc("Successful message after an user action", "Tracker '%1' created", name));
         ui.kView->getView()->selectObject(tracker.getUniqueID());
-    } else err.addError(ERR_FAIL, i18nc("Error message", "Tracker creation failed"));
+    } else {
+        err.addError(ERR_FAIL, i18nc("Error message", "Tracker creation failed"));
+    }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
@@ -193,15 +196,14 @@ void SKGTrackerPluginWidget::onModifyTracker()
 {
     SKGError err;
     _SKGTRACEINRC(10, "SKGTrackerPluginWidget::onModifyTracker", err);
-    //Get Selection
+    // Get Selection
     SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
 
     int nb = selection.count();
     {
         SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Tracker update")  , err, nb);
         for (int i = 0; !err && i < nb; ++i) {
-
-            //Modification of object
+            // Modification of object
             SKGTrackerObject tracker(selection[i]);
             err = tracker.setName(ui.kNameInput->text());
             IFOKDO(err, tracker.setComment(ui.kCommentEdit->text()))
@@ -209,11 +211,13 @@ void SKGTrackerPluginWidget::onModifyTracker()
             IFOKDO(err, getDocument()->stepForward(i + 1))
         }
     }
-    //status bar
+    // status bar
     IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Tracker updated")))
-    else err.addError(ERR_FAIL, i18nc("Error message", "Tracker update failed"));
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message", "Tracker update failed"));
+    }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
