@@ -20,19 +20,20 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgunitboardwidget.h"
+
+#include <QDomDocument>
+
 #include "skgdocumentbank.h"
 #include "skgtraces.h"
 #include "skgunitobject.h"
 #include "skgmainpanel.h"
 
-#include <QDomDocument>
-
 SKGUnitBoardWidget::SKGUnitBoardWidget(SKGDocument* iDocument)
     : SKGBoardWidget(iDocument, i18nc("Title of a dashboard widget", "Quotes"))
 {
     SKGTRACEIN(10, "SKGUnitBoardWidget::SKGUnitBoardWidget");
 
-    //Create menu
+    // Create menu
     setContextMenuPolicy(Qt::ActionsContextMenu);
 
     m_menuFavorite = new KAction(KIcon("bookmarks"), i18nc("Display only favorite accounts", "Highlighted only"), this);
@@ -80,7 +81,7 @@ SKGUnitBoardWidget::SKGUnitBoardWidget(SKGDocument* iDocument)
     m_label = new QLabel();
     setMainWidget(m_label);
 
-    //Refresh
+    // Refresh
     connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
     connect(m_label, SIGNAL(linkActivated(QString)), SKGMainPanel::getMainPanel(), SLOT(openPage(QString)));
 }
@@ -138,7 +139,7 @@ void SKGUnitBoardWidget::dataModified(const QString& iTableName, int iIdTransact
         if (doc && loc) {
             SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
 
-            //Build where clause
+            // Build where clause
             QString wc;
             if (m_menuSharesOwnedOnly && m_menuShares && m_menuIndexes) {
                 m_menuSharesOwnedOnly->setEnabled(m_menuShares->isChecked());
@@ -151,7 +152,9 @@ void SKGUnitBoardWidget::dataModified(const QString& iTableName, int iIdTransact
                 if (m_menuShares->isChecked()) {
                     if (!wc.isEmpty()) wc += " OR ";
                     if (m_menuSharesOwnedOnly->isChecked()) wc += "(t_type='S' AND f_QUANTITYOWNED>0)";
-                    else wc += "t_type='S'";
+                    else {
+                        wc += "t_type='S'";
+                    }
                 }
                 if (m_menuCurrencies->isChecked()) {
                     if (!wc.isEmpty()) wc += " OR ";
@@ -202,7 +205,7 @@ void SKGUnitBoardWidget::dataModified(const QString& iTableName, int iIdTransact
                 m_label->setText(html);
             }
 
-            //No widget if no account
+            // No widget if no account
             bool exist = false;
             getDocument()->existObjects("account", "", exist);
             if (parentWidget()) setVisible(exist);
