@@ -20,21 +20,15 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgunitpluginwidget.h"
-#include "skgmainpanel.h"
-#include "skgobjectmodel.h"
-#include "skgbankincludes.h"
-#include "skgservices.h"
-#include "skgtraces.h"
-#include "skgunit_settings.h"
 
-#include <kstandarddirs.h>
-#include <kio/netaccess.h>
-#include <klocale.h>
-#include <krun.h>
+#include <KStandardDirs>
+#include <KIO/NetAccess>
+#include <KLocale>
+#include <KRun>
 #include <KUrl>
 #include <knewstuff3/downloaddialog.h>
 #include <knewstuff3/uploaddialog.h>
-#include <kzip.h>
+#include <KZip>
 
 #include <QtGui/QSortFilterProxyModel>
 #include <QDomDocument>
@@ -42,6 +36,13 @@
 #include <QKeyEvent>
 #include <QDir>
 
+#include "skgmainpanel.h"
+#include "skgobjectmodel.h"
+#include "skgbankincludes.h"
+#include "skgservices.h"
+#include "skgtraces.h"
+#include "skgunit_settings.h"
+
 SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
     : SKGTabPage(iDocument)
 {
@@ -65,38 +66,34 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
 
     ui.kUnitTableViewEdition->getShowWidget()->addItem("all", i18nc("Noun, items to display", "All"), "",
             "",
-            "currency;share;index;object",//Check when checked
-            "highlighted");//Uncheck when checked
+            "currency;share;index;object",  // Check when checked
+            "highlighted");  // Uncheck when checked
     ui.kUnitTableViewEdition->getShowWidget()->addItem("highlighted", i18n("Highlighted only"), "bookmarks", "t_bookmarked='Y'", "", "all;currency;share;index;object", "all");
     ui.kUnitTableViewEdition->getShowWidget()->addSeparator();
     ui.kUnitTableViewEdition->getShowWidget()->addItem("currency", i18nc("Noun, a country's currency", "Currency"), "",
             "t_type IN ('1','2','C')",
-            "",  //Check when checked
-            "highlighted",       //Uncheck when checked
-            "",       //Check when unchecked
-            "all"     //Uncheck when unchecked
-                                                      );
+            "",  // Check when checked
+            "highlighted",       // Uncheck when checked
+            "",       // Check when unchecked
+            "all");     // Uncheck when unchecked
     ui.kUnitTableViewEdition->getShowWidget()->addItem("share", i18nc("Noun, a financial share, as in a stock market", "Share"), "",
             "t_type='S'",
             "",
             "highlighted",
             "",
-            "all"
-                                                      );
+            "all");
     ui.kUnitTableViewEdition->getShowWidget()->addItem("index", i18nc("Noun, a financial index like the Dow Jones, NASDAQ, CAC40...", "Index"), "",
             "t_type='I'",
             "",
             "highlighted",
             "",
-            "all;current"
-                                                      );
+            "all;current");
     ui.kUnitTableViewEdition->getShowWidget()->addItem("object", i18nc("Noun, a physical object like a house or a car", "Object"), "",
             "t_type='O'",
             "",
             "highlighted",
             "",
-            "all"
-                                                      );
+            "all");
 
     ui.kUnitTableViewEdition->getShowWidget()->setDefaultState("all;currency;share;index;object");
 
@@ -106,7 +103,7 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
     ui.kUnitCreatorUnit->setDocument(iDocument);
     ui.kUnitCreatorUnit->setWhereClauseCondition("t_type IN ('1','2','C')");
 
-    //Add Standard KDE Icons to buttons to Accounts
+    // Add Standard KDE Icons to buttons to Accounts
     ui.kUnitAdd->setIcon(KIcon("list-add"));
     ui.kUnitUpdate->setIcon(KIcon("dialog-ok-apply"));
     ui.kUnitValueDownload->setIcon(KIcon("download"));
@@ -189,7 +186,7 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
     }
     connect(ui.kWidgetSelector, SIGNAL(selectedModeChanged(int)), this, SLOT(onUnitCreatorModified()));
 
-    //Fill combo box for type
+    // Fill combo box for type
     ui.kTypeCreatorUnit->addItem(i18nc("Noun", "Primary currency"), SKGUnitObject::PRIMARY);
     ui.kTypeCreatorUnit->addItem(i18nc("Noun", "Secondary currency"), SKGUnitObject::SECONDARY);
     ui.kTypeCreatorUnit->addItem(i18nc("Noun, a country's currency", "Currency"), SKGUnitObject::CURRENCY);
@@ -201,14 +198,18 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
     iDocument->existObjects("unit", "t_type='2'", secondaryUnit);
     if (primaryUnit) {
         if (secondaryUnit) ui.kTypeCreatorUnit->setCurrentIndex(2);
-        else ui.kTypeCreatorUnit->setCurrentIndex(1);
-    } else ui.kTypeCreatorUnit->setCurrentIndex(0);
+        else {
+            ui.kTypeCreatorUnit->setCurrentIndex(1);
+        }
+    } else {
+        ui.kTypeCreatorUnit->setCurrentIndex(0);
+    }
 
-    //Bind unit creation view
+    // Bind unit creation view
     {
         ui.kUnitTableViewEdition->setModel(new SKGObjectModel(static_cast<SKGDocumentBank*>(getDocument()), "v_unit_display", "", this, "", false));
 
-        //Add registered global action in contextual menu
+        // Add registered global action in contextual menu
         if (SKGMainPanel::getMainPanel()) {
             ui.kUnitTableViewEdition->getView()->insertGlobalAction();
             ui.kUnitTableViewEdition->getView()->insertGlobalAction("open");
@@ -225,34 +226,34 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
         connect(ui.kUnitTableViewEdition->getView(), SIGNAL(selectionChangedDelayed()), this, SLOT(onSelectionChanged()));
     }
 
-    //Bind unit creation view
+    // Bind unit creation view
     {
         SKGObjectModel* objectModel2 = new SKGObjectModel(static_cast<SKGDocumentBank*>(getDocument()), "v_unitvalue_display", "1=0", this, "", false);
 
         ui.kUnitValueTableViewEdition->setModel(objectModel2);
 
-        //Add registered global action in contextual menu
+        // Add registered global action in contextual menu
         ui.kUnitValueTableViewEdition->insertGlobalAction("edit_delete");
 
         connect(ui.kUnitValueTableViewEdition, SIGNAL(selectionChangedDelayed()), this, SLOT(onSelectionValueChanged()));
     }
 
-    //Refresh
+    // Refresh
     connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
     ui.kWidgetSelector->setSelectedMode(0);
 
-    //Fill combo box for reference currency
+    // Fill combo box for reference currency
     fillSourceList();
     dataModified("", 0);
 
-    //Set Event filters to catch CTRL+ENTER or SHIFT+ENTER
+    // Set Event filters to catch CTRL+ENTER or SHIFT+ENTER
     this->installEventFilter(this);
 
-    //Synchronize zooms of both tables
+    // Synchronize zooms of both tables
     connect(ui.kUnitTableViewEdition->getView(), SIGNAL(zoomChanged(int)), ui.kUnitValueTableViewEdition, SLOT(setZoomPosition(int)));
     connect(ui.kUnitValueTableViewEdition, SIGNAL(zoomChanged(int)), ui.kUnitTableViewEdition->getView(), SLOT(setZoomPosition(int)));
 
-    //Fill combo box for currency
+    // Fill combo box for currency
     m_timer.setSingleShot(true);
     connect(&m_timer, SIGNAL(timeout()), this, SLOT(refreshUnitList()), Qt::QueuedConnection);
     m_timer.start(500);;
@@ -263,11 +264,11 @@ SKGUnitPluginWidget::~SKGUnitPluginWidget()
     SKGTRACEIN(10, "SKGUnitPluginWidget::~SKGUnitPluginWidget");
 }
 
-bool SKGUnitPluginWidget::eventFilter(QObject* object, QEvent* event)
+bool SKGUnitPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 {
-    if (event && event->type() == QEvent::KeyPress) {
-        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
-        if ((keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && object == this) {
+    if (iEvent && iEvent->type() == QEvent::KeyPress) {
+        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(iEvent);
+        if ((keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && iObject == this) {
             if (QApplication::keyboardModifiers() &Qt::ControlModifier && ui.kUnitAdd->isEnabled()) {
                 ui.kUnitAdd->click();
             } else if (QApplication::keyboardModifiers() &Qt::ShiftModifier && ui.kUnitUpdate->isEnabled()) {
@@ -281,23 +282,23 @@ bool SKGUnitPluginWidget::eventFilter(QObject* object, QEvent* event)
 
 void SKGUnitPluginWidget::fillSourceList()
 {
-    //Get previous selected item
+    // Get previous selected item
     QString current = ui.kDownloadSource->text();
 
-    //Fill
+    // Fill
     ui.kDownloadSource->clear();
     ui.kDownloadSource->addItem(i18nc("Native download source (Yahoo)", "Yahoo"));
     ui.kDownloadSource->addItems(SKGUnitObject::downloadSources());
     ui.kDeleteSource->hide();
 
-    //Set previous selected itemData
+    // Set previous selected itemData
     if (!current.isEmpty() && ui.kDownloadSource->contains(current)) ui.kDownloadSource->setCurrentItem(current);
 }
 
 void SKGUnitPluginWidget::onSelectionChanged()
 {
     SKGTRACEIN(10, "SKGUnitPluginWidget::onSelectionChanged");
-    //Mapping
+    // Mapping
     SKGUnitObject unit;
 
     int nbSelect = ui.kUnitTableViewEdition->getView()->getNbSelectedObjects();
@@ -324,18 +325,18 @@ void SKGUnitPluginWidget::onSelectionChanged()
     ui.kUnitValueDownload->setEnabled(nbSelect > 0);
     ui.kUnitOpen->setEnabled(nbSelect > 0);
 
-    //Fill values
+    // Fill values
     QString wc = "rd_unit_id=(select id from unit where t_name='" % SKGServices::stringToSqlString(ui.kNameCreatorUnit->text()) % "')";
     SKGObjectModel* objectModel = static_cast<SKGObjectModel*>(ui.kUnitValueTableViewEdition->model());
     if (objectModel) {
-        objectModel->setFilter("");    //Correction 2299600: to be sure that refresh will be done
+        objectModel->setFilter("");    // Correction 2299600: to be sure that refresh will be done
         objectModel->setFilter(wc % " order by d_date desc");
         objectModel->refresh();
     }
 
     ui.kUnitOfUnitLbl->setText(ui.kUnitCreatorUnit->text());
 
-    //Draw plot
+    // Draw plot
     SKGStringListList table;
     getDocument()->getConsolidatedView("v_unitvalue_display", "d_date", "t_UNIT", "f_quantity", "TOTAL", wc % " AND d_date>(SELECT date('now', '-50 year'))" , table , "");
 
@@ -345,9 +346,9 @@ void SKGUnitPluginWidget::onSelectionChanged()
         primaryUnit.Symbol = "";
         secondaryUnit.Symbol = "";
     } else {
-        SKGUnitObject parent;
-        unit.getUnit(parent);
-        SKGServices::SKGUnitInfo parentUnit = parent.getUnitInfo();
+        SKGUnitObject parentUnitObject;
+        unit.getUnit(parentUnitObject);
+        SKGServices::SKGUnitInfo parentUnit = parentUnitObject.getUnitInfo();
         if (primaryUnit.Symbol != parentUnit.Symbol) {
             secondaryUnit = primaryUnit;
             primaryUnit = parentUnit;
@@ -358,9 +359,9 @@ void SKGUnitPluginWidget::onSelectionChanged()
     }
     ui.kGraph->setData(table, primaryUnit, secondaryUnit, SKGTableWithGraph::LIMITS);
 
-    //Correction bug 2299394 vvv
+    // Correction bug 2299394 vvv
     if (ui.kUnitValueTableViewEdition->isAutoResized()) ui.kUnitValueTableViewEdition->resizeColumnsToContentsDelayed();
-    //Correction bug 2299394 ^^^
+    // Correction bug 2299394 ^^^
 
     onUnitCreatorModified();
     Q_EMIT selectionChanged();
@@ -369,7 +370,7 @@ void SKGUnitPluginWidget::onSelectionChanged()
 void SKGUnitPluginWidget::onSelectionValueChanged()
 {
     SKGTRACEIN(10, "SKGUnitPluginWidget::onSelectionValueChanged");
-    //Mapping
+    // Mapping
     QItemSelectionModel* selModel = ui.kUnitValueTableViewEdition->selectionModel();
     if (selModel) {
         QModelIndexList indexes = selModel->selectedRows();
@@ -430,7 +431,7 @@ void SKGUnitPluginWidget::onAddUnit()
         {
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Unit creation '%1'", untiname), err);
 
-            //Create unit object
+            // Create unit object
             IFOKDO(err, unitObj.setName(untiname))
             IFOKDO(err, unitObj.setSymbol(ui.kSymbolCreatorUnit->text()))
             IFOKDO(err, unitObj.setCountry(ui.kCountryCreatorUnit->text()))
@@ -442,11 +443,13 @@ void SKGUnitPluginWidget::onAddUnit()
             IFOKDO(err, unitObj.save())
         }
 
-        //status bar
+        // status bar
         IFOK(err) {
             err = SKGError(0, i18nc("Successful message after an user action", "Unit '%1' created", untiname));
             ui.kUnitTableViewEdition->getView()->selectObject(unitObj.getUniqueID());
-        } else err.addError(ERR_FAIL, i18nc("Error message", "Unit creation failed"));
+        } else {
+            err.addError(ERR_FAIL, i18nc("Error message", "Unit creation failed"));
+        }
     } else if (mode == 2) {
         QString untiname = ui.kNameCreatorUnit->text();
         SKGUnitValueObject unitValueObject;
@@ -454,15 +457,17 @@ void SKGUnitPluginWidget::onAddUnit()
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Unit value creation for '%1'", untiname), err);
             err = static_cast<SKGDocumentBank*>(getDocument())->addOrModifyUnitValue(untiname, ui.kDateEdit->date(), ui.kAmountEdit->value(), &unitValueObject);
         }
-        //status bar
+        // status bar
         IFOK(err) {
             err = SKGError(0, i18nc("Successful message after an user action", "Unit value created for '%1'", untiname));
-            //TODO doesn't work because of unit table is modified an refreshed
+            // TODO(Stephane MANKOWSKI) doesn't work because of unit table is modified an refreshed
             ui.kUnitValueTableViewEdition->selectObject(unitValueObject.getUniqueID());
-        } else err.addError(ERR_FAIL, i18nc("Error message", "Unit value creation failed"));
+        } else {
+            err.addError(ERR_FAIL, i18nc("Error message", "Unit value creation failed"));
+        }
     }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
@@ -470,7 +475,7 @@ void SKGUnitPluginWidget::onModifyUnit()
 {
     SKGError err;
     SKGTRACEINRC(10, "SKGUnitPluginWidget::onModifyUnit", err);
-    //Get Selection
+    // Get Selection
     SKGObjectBase::SKGListSKGObjectBase selection = ui.kUnitTableViewEdition->getView()->getSelectedObjects();
 
     int nb = selection.count();
@@ -478,25 +483,25 @@ void SKGUnitPluginWidget::onModifyUnit()
     {
         SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Unit update")  , err, nb);
 
-        //Is it a massive modification of payees to merge them ?
+        // Is it a massive modification of payees to merge them ?
         if (nb > 1 && ui.kNameCreatorUnit->text() != NOUPDATE && !ui.kNameCreatorUnit->text().startsWith(QLatin1String("="))) {
             getDocument()->sendMessage(i18nc("Information message", "You tried to modify all names of selected units. Units have been merged."));
 
-            //Do the merge
+            // Do the merge
             SKGUnitObject unitObj1(selection[0]);
             for (int i = 1; !err && i < nb; ++i) {
                 SKGUnitObject unitObj(selection[i]);
                 err = unitObj1.merge(unitObj);
             }
 
-            //Change selection for the rest of the operation
+            // Change selection for the rest of the operation
             selection.clear();
             selection.push_back(unitObj1);
             nb = 1;
         }
 
         for (int i = 0; !err && i < nb; ++i) {
-            //Modification of unit object
+            // Modification of unit object
             SKGUnitObject unitObj(selection[i]);
             IFOKDO(err, unitObj.setName(ui.kNameCreatorUnit->text()))
             IFOKDO(err, unitObj.setSymbol(ui.kSymbolCreatorUnit->text()))
@@ -511,11 +516,13 @@ void SKGUnitPluginWidget::onModifyUnit()
         }
     }
 
-    //status bar
+    // status bar
     IFOKDO(err, SKGError(0, i18nc("Message for successful user action", "Unit updated")))
-    else err.addError(ERR_FAIL, i18nc("Error message", "Unit update failed"));
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message", "Unit update failed"));
+    }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
@@ -523,12 +530,19 @@ SKGUnitObject::UnitDownloadMode SKGUnitPluginWidget::getDownloadModeFromSettings
 {
     SKGUnitObject::UnitDownloadMode mode = SKGUnitObject::LAST;
     if (skgunit_settings::last()) mode = SKGUnitObject::LAST;
-    else if (skgunit_settings::last_monthly()) mode = SKGUnitObject::LAST_MONTHLY;
-    else if (skgunit_settings::last_weekly())  mode = SKGUnitObject::LAST_WEEKLY;
-    else if (skgunit_settings::last_daily())   mode = SKGUnitObject::LAST_DAILY;
-    else if (skgunit_settings::all_monthly())  mode = SKGUnitObject::ALL_MONTHLY;
-    else if (skgunit_settings::all_weekly())   mode = SKGUnitObject::ALL_WEEKLY;
-    else if (skgunit_settings::all_daily())    mode = SKGUnitObject::ALL_DAILY;
+    else if (skgunit_settings::last_monthly()) {
+        mode = SKGUnitObject::LAST_MONTHLY;
+    } else if (skgunit_settings::last_weekly()) {
+        mode = SKGUnitObject::LAST_WEEKLY;
+    } else if (skgunit_settings::last_daily()) {
+        mode = SKGUnitObject::LAST_DAILY;
+    } else if (skgunit_settings::all_monthly()) {
+        mode = SKGUnitObject::ALL_MONTHLY;
+    } else if (skgunit_settings::all_weekly()) {
+        mode = SKGUnitObject::ALL_WEEKLY;
+    } else if (skgunit_settings::all_daily()) {
+        mode = SKGUnitObject::ALL_DAILY;
+    }
     return mode;
 }
 
@@ -556,7 +570,9 @@ void SKGUnitPluginWidget::onDownloadUnitValue()
     SKGUnitObject::UnitDownloadMode mode = SKGUnitObject::LAST;
     KAction* act = qobject_cast<KAction*>(sender());
     if (act) mode = static_cast<SKGUnitObject::UnitDownloadMode>(act->data().toInt());
-    else mode = SKGUnitPluginWidget::getDownloadModeFromSettings();
+    else {
+        mode = SKGUnitPluginWidget::getDownloadModeFromSettings();
+    }
 
     SKGObjectBase::SKGListSKGObjectBase selection = ui.kUnitTableViewEdition->getView()->getSelectedObjects();
     int nb = selection.count();
@@ -571,9 +587,11 @@ void SKGUnitPluginWidget::onDownloadUnitValue()
     }
 
     IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Download done")))
-    else err.addError(ERR_FAIL, i18nc("Error message", "Download failed"));
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message", "Download failed"));
+    }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
@@ -595,9 +613,11 @@ void SKGUnitPluginWidget::onSimplify()
     }
 
     IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Simplification done")))
-    else err.addError(ERR_FAIL, i18nc("Error message", "Simplification failed"));
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message", "Simplification failed"));
+    }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
@@ -632,7 +652,7 @@ QString SKGUnitPluginWidget::getState()
     root.setAttribute("splitter1State", QString(ui.kMainSplitter->saveState().toHex()));
     root.setAttribute("splitter2State", QString(ui.kValuesSplitter->saveState().toHex()));
 
-    //Memorize table settings
+    // Memorize table settings
     root.setAttribute("unitview", ui.kUnitTableViewEdition->getState());
     root.setAttribute("unitvalueview", ui.kUnitValueTableViewEdition->getState());
     root.setAttribute("currentPage", SKGServices::intToString(ui.kWidgetSelector->getSelectedMode()));
@@ -678,9 +698,9 @@ void SKGUnitPluginWidget::dataModified(const QString& iTableName, int iIdTransac
     Q_UNUSED(iIdTransaction);
 
     if (iTableName == "unitvalue" || iTableName.isEmpty()) {
-        //Correction bug 2299394 vvv
+        // Correction bug 2299394 vvv
         if (ui.kUnitValueTableViewEdition->isAutoResized()) ui.kUnitValueTableViewEdition->resizeColumnsToContentsDelayed();
-        //Correction bug 2299394 ^^^
+        // Correction bug 2299394 ^^^
     }
 }
 
@@ -709,14 +729,14 @@ void SKGUnitPluginWidget::activateEditor()
 void SKGUnitPluginWidget::refreshUnitList()
 {
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-    //Clean list
+    // Clean list
     ui.kCurrencyList->clear();
 
-    //Add items
+    // Add items
     QStringList list = SKGUnitObject::getListofKnownCurrencies(ui.kObsolete->isChecked());
     ui.kCurrencyList->addItems(list);
 
-    //Completion
+    // Completion
     KCompletion* comp = ui.kCurrencyList->completionObject();
     if (comp) {
         comp->setIgnoreCase(true);
@@ -739,11 +759,11 @@ void SKGUnitPluginWidget::onAddSource()
     QString source = ui.kDownloadSource->text().trimmed();
     if (!source.isEmpty() && source != i18nc("Native download source (Yahoo)", "Yahoo") &&
             (!SKGUnitObject::downloadSources().contains(source) || SKGUnitObject::isWritable(source))) {
-        //This is a new source
+        // This is a new source
         SKGError err = SKGUnitObject::addSource(source);
         onSourceChanged();
 
-        //Display error
+        // Display error
         SKGMainPanel::displayErrorMessage(err);
     }
 }
@@ -752,11 +772,11 @@ void SKGUnitPluginWidget::onDeleteSource()
 {
     QString source = ui.kDownloadSource->text();
     if (!source.isEmpty() && source != i18nc("Native download source (Yahoo)", "Yahoo") && SKGUnitObject::downloadSources().contains(source)) {
-        //This is a new source
+        // This is a new source
         SKGError err = SKGUnitObject::deleteSource(source);
         IFOK(err) ui.kDownloadSource->removeItem(ui.kDownloadSource->findText(source));
 
-        //Display error
+        // Display error
         SKGMainPanel::displayErrorMessage(err);
     }
 }
@@ -782,7 +802,7 @@ void SKGUnitPluginWidget::onPutNewHotStuff()
 {
     QString source = ui.kDownloadSource->text().trimmed();
 
-    //Create zip file
+    // Create zip file
     QString sourceFileName = KStandardDirs::locateLocal("data", QString::fromLatin1("skrooge/quotes/")) % source % ".txt";
     QString zipFileName = QDir::tempPath() % "/" % source % ".zip";
     KZip zip(zipFileName);
@@ -790,7 +810,7 @@ void SKGUnitPluginWidget::onPutNewHotStuff()
         zip.addLocalFile(sourceFileName, source % ".txt");
         zip.close();
 
-        //Open dialog
+        // Open dialog
         QPointer<KNS3::UploadDialog> dialog = new KNS3::UploadDialog("skrooge_unit.knsrc", this);
 
         dialog->setUploadFile(zipFileName);
@@ -799,7 +819,7 @@ void SKGUnitPluginWidget::onPutNewHotStuff()
         dialog->exec();
         delete dialog;
 
-        //Delete temporary files
+        // Delete temporary files
         QFile(zipFileName).remove();
     }
 }
@@ -818,7 +838,7 @@ void SKGUnitPluginWidget::onOpenURL()
         }
     }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
