@@ -64,7 +64,9 @@ SKGUnitObject SKGUnitComboBox::getUnit()
             IFOKDO(err, unitVal.save())
 
             IFOK(err) m_document->sendMessage(i18nc("An information message",  "Unit '%1' has been created" , text()), SKGDocument::Positive);
-        } else err = unit.load();
+        } else {
+            err = unit.load();
+        }
     }
     return unit;
 }
@@ -76,7 +78,7 @@ void SKGUnitComboBox::setUnit(const SKGUnitObject& iUnit)
 
 void SKGUnitComboBox::refershList()
 {
-    //Fill comboboxes
+    // Fill comboboxes
     if (m_document) {
         SKGMainPanel::fillWithDistinctValue(this, m_document, "unit", "ifnull(t_symbol,t_name)", m_fillWhereClause);
         SKGServices::SKGUnitInfo primary = m_document->getPrimaryUnit();
@@ -88,7 +90,7 @@ void SKGUnitComboBox::dataModified(const QString& iTableName, int iIdTransaction
 {
     Q_UNUSED(iIdTransaction);
 
-    //Refresh widgets
+    // Refresh widgets
     if (m_document) {
         QSqlDatabase* db = m_document->getDatabase();
         setEnabled(db != NULL);
