@@ -20,6 +20,9 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgaccountobject.h"
+
+#include <KLocale>
+
 #include "skgbankobject.h"
 #include "skgoperationobject.h"
 #include "skgsuboperationobject.h"
@@ -28,8 +31,6 @@
 #include "skgdocumentbank.h"
 #include "skgtraces.h"
 
-#include <klocale.h>
-
 SKGAccountObject::SKGAccountObject(SKGDocument* iDocument, int iID) : SKGNamedObject(iDocument, "v_account", iID) {}
 
 SKGAccountObject::~SKGAccountObject() {}
@@ -68,10 +69,10 @@ SKGError SKGAccountObject::setInitialBalance(double iBalance, const SKGUnitObjec
     SKGError err;
     SKGTRACEINRC(10, "SKGAccountObject::setInitialBalance", err);
     if (getDocument()) {
-        //Delete previous initial balance for this account
+        // Delete previous initial balance for this account
         err = getDocument()->executeSqliteOrder("DELETE FROM operation  WHERE d_date='0000-00-00' AND rd_account_id=" % SKGServices::intToString(getID()));
 
-        //Creation of new initial balance
+        // Creation of new initial balance
         IFOK(err) {
             SKGOperationObject initialBalanceOp;
             err = addOperation(initialBalanceOp, true);
@@ -93,12 +94,12 @@ SKGError SKGAccountObject::getInitialBalance(double& oBalance, SKGUnitObject& oU
 {
     SKGError err;
     SKGTRACEINRC(10, "SKGAccountObject::getInitialBalance", err);
-    //Initialisation
+    // Initialisation
     oBalance = 0;
     oUnit = SKGUnitObject();
     QString unitName = static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit().Symbol;
 
-    //Get initial balance
+    // Get initial balance
     SKGStringListList listTmp;
     err = getDocument()->executeSelectSqliteOrder("SELECT f_QUANTITY, t_UNIT FROM  v_operation_tmp1  WHERE d_date='0000-00-00' AND rd_account_id=" % SKGServices::intToString(getID()), listTmp);
     if (!err && listTmp.count() > 1) {
@@ -197,12 +198,12 @@ double SKGAccountObject::getCurrentAmount() const
     return SKGServices::stringToDouble(getAttributeFromView("v_account_amount", "f_CURRENTAMOUNT"));
 }
 
-double SKGAccountObject::getAmount(const QDate& iDate) const
+double SKGAccountObject::getAmount(const QDate& iDate, bool iOnlyCurrencies) const
 {
     SKGTRACEIN(10, "SKGAccountObject::getAmount");
     double output = 0;
     if (getDocument()) {
-        //Search result in cache
+        // Search result in cache
         QString ids = SKGServices::intToString(getID());
         QString dates = SKGServices::dateToSqlString(QDateTime(iDate));
         QString key = "getamount-" % ids % '-' % dates;
@@ -211,6 +212,7 @@ double SKGAccountObject::getAmount(const QDate& iDate) const
             SKGStringListList listTmp;
             SKGError err = getDocument()->executeSelectSqliteOrder("SELECT TOTAL(f_QUANTITY), rc_unit_id FROM v_operation_tmp1  WHERE "
                            "d_date<='" % dates % "' AND t_template='N' AND rd_account_id=" % ids %
+                           (iOnlyCurrencies ? " AND t_TYPEUNIT IN ('1', '2', 'C')" : "") %
                            " GROUP BY rc_unit_id",
                            listTmp);
             int nb = listTmp.count();
@@ -221,10 +223,10 @@ double SKGAccountObject::getAmount(const QDate& iDate) const
                 double coef = 1;
                 QString val2 = getDocument()->getCachedValue("unitvalue-" % unitid);
                 if (!val2.isEmpty()) {
-                    //Yes
+                    // Yes
                     coef = SKGServices::stringToDouble(val2);
                 } else {
-                    //No
+                    // No
                     SKGUnitObject unit(getDocument(), SKGServices::stringToInt(unitid));
                     if (unit.getType() != SKGUnitObject::PRIMARY) coef = unit.getAmount(iDate);
                 }
@@ -246,9 +248,10 @@ SKGError SKGAccountObject::setType(SKGAccountObject::AccountType iType)
                                     (iType == ASSETS ? "A" :
                                      (iType == INVESTMENT ? "I" :
                                       (iType == WALLET ? "W" :
-                                       (iType == LOAN ? "L" :
-                                        (iType == SAVING ? "S" :
-                                         "O"))))))));
+                                       (iType == PENSION ? "P" :
+                                        (iType == LOAN ? "L" :
+                                         (iType == SAVING ? "S" :
+                                          "O")))))))));
 }
 
 SKGAccountObject::AccountType SKGAccountObject::getType() const
@@ -259,8 +262,9 @@ SKGAccountObject::AccountType SKGAccountObject::getType() const
              (typeString == "A" ? ASSETS :
               (typeString == "I" ? INVESTMENT :
                (typeString == "W" ? WALLET :
-                (typeString == "L" ? LOAN :
-                 (typeString == "S" ? SAVING : OTHER)))))));
+                (typeString == "P" ? PENSION :
+                 (typeString == "L" ? LOAN :
+                  (typeString == "S" ? SAVING : OTHER))))))));
 }
 
 SKGError SKGAccountObject::setClosed(bool iClosed)
@@ -276,7 +280,6 @@ bool SKGAccountObject::isClosed() const
 SKGError SKGAccountObject::bookmark(bool iBookmark)
 {
     return setAttribute("t_bookmarked", iBookmark ? "Y" : "N");
-
 }
 
 bool SKGAccountObject::isBookmarked() const
@@ -287,7 +290,6 @@ bool SKGAccountObject::isBookmarked() const
 SKGError SKGAccountObject::maxLimitAmountEnabled(bool iEnabled)
 {
     return setAttribute("t_maxamount_enabled", iEnabled ? "Y" : "N");
-
 }
 
 bool SKGAccountObject::isMaxLimitAmountEnabled() const
@@ -329,20 +331,30 @@ double SKGAccountObject::getMinLimitAmount() const
     return SKGServices::stringToDouble(getAttribute("f_minamount"));
 }
 
+SKGError SKGAccountObject::setReconciliationDate(const QDate& iDate)
+{
+    return setAttribute("d_reconciliationdate", SKGServices::dateToSqlString(QDateTime(iDate)));
+}
+
+QDate SKGAccountObject::getReconciliationDate() const
+{
+    return SKGServices::stringToTime(getAttribute("d_reconciliationdate")).date();
+}
+
 SKGError SKGAccountObject::getUnit(SKGUnitObject& oUnit) const
 {
-    //Get initial amount
+    // Get initial amount
     SKGStringListList listTmp;
     SKGError err = getDocument()->executeSelectSqliteOrder("SELECT t_UNIT FROM  v_operation_consolidated  WHERE d_date='0000-00-00' AND rd_account_id=" % SKGServices::intToString(getID()), listTmp);
     IFOK(err) {
-        //Is initial amount existing ?
+        // Is initial amount existing ?
         if (listTmp.count() > 1) {
-            //Yes ==> then the amount is the amount of the initial value
+            // Yes ==> then the amount is the amount of the initial value
             oUnit = SKGUnitObject(getDocument());
             err = oUnit.setSymbol(listTmp.at(1).at(0));
             IFOKDO(err, oUnit.load())
         } else {
-            //No ==> we get the preferred unit
+            // No ==> we get the preferred unit
             SKGObjectBase::SKGListSKGObjectBase units;
             err = getDocument()->getObjects("v_unit",
                                             "t_type IN ('1', '2', 'C') AND EXISTS(SELECT 1 FROM operation WHERE rc_unit_id=v_unit.id AND rd_account_id=" % SKGServices::intToString(getID()) % ") ORDER BY t_type", units);
@@ -384,7 +396,7 @@ SKGError SKGAccountObject::getInterest(const QDate& iDate, SKGInterestObject& oI
                    " AND u2.d_date<='" % dates % "')",
                    oInterest);
 
-    //If not found then get first
+    // If not found then get first
     IFKO(err) err = SKGObjectBase::getDocument()->getObject("v_interest",
                     "rd_account_id=" % SKGServices::intToString(getID()) % " AND d_date=(SELECT MIN(d_date) FROM interest WHERE rd_account_id=" %
                     SKGServices::intToString(getID()) % ')',
@@ -397,7 +409,7 @@ SKGError SKGAccountObject::getInterestItems(QList<SKGAccountObject::SKGInterestI
     oInterestList.clear();
     SKGError err;
 
-    //Initial date
+    // Initial date
     int y = iYear;
     if (y == 0) y = QDate::currentDate().year();
     QDate initialDate = QDate(y, 1, 1);
@@ -406,9 +418,10 @@ SKGError SKGAccountObject::getInterestItems(QList<SKGAccountObject::SKGInterestI
     oInterests = 0;
     bool computationNeeded = false;
 
-    //Add operations
+    // Add operations
     SKGObjectBase::SKGListSKGObjectBase items;
     err = getDocument()->getObjects("v_operation", "rd_account_id=" % SKGServices::intToString(getID()) %
+                                    " AND t_template='N' AND t_TYPEUNIT IN ('1', '2', 'C')"
                                     " AND d_date>='" % SKGServices::dateToSqlString(QDateTime(initialDate)) % "' "
                                     " AND d_date<='" % SKGServices::dateToSqlString(QDateTime(lastDate)) % "' ORDER BY d_date", items);
     int nb = items.count();
@@ -429,7 +442,7 @@ SKGError SKGAccountObject::getInterestItems(QList<SKGAccountObject::SKGInterestI
         oInterestList.push_back(itemI);
     }
 
-    //Add interest
+    // Add interest
     IFOK(err) {
         err = getDocument()->getObjects("v_interest", "rd_account_id=" % SKGServices::intToString(getID()) %
                                         " AND d_date>='" % SKGServices::dateToSqlString(QDateTime(initialDate)) % "' "
@@ -465,7 +478,7 @@ SKGError SKGAccountObject::getInterestItems(QList<SKGAccountObject::SKGInterestI
         }
     }
 
-    //Get first interest
+    // Get first interest
     IFOK(err) {
         SKGInterestObject firstInterest;
         if (getInterest(initialDate, firstInterest).isSucceeded()) {
@@ -487,15 +500,14 @@ SKGError SKGAccountObject::getInterestItems(QList<SKGAccountObject::SKGInterestI
         }
     }
 
-    //Launch computation
+    // Launch computation
     IFOK(err) {
         if (computationNeeded) {
-
             err = computeInterestItems(oInterestList, oInterests, y);
         } else {
-            //Drop temporary table
+            // Drop temporary table
             IFOKDO(err, getDocument()->executeSqliteOrder("DROP TABLE IF EXISTS interest_result"))
-            //Create fake table
+            // Create fake table
             IFOKDO(err, getDocument()->executeSqliteOrder("CREATE TEMP TABLE interest_result(a)"))
         }
     }
@@ -506,15 +518,15 @@ SKGError SKGAccountObject::computeInterestItems(QList<SKGAccountObject::SKGInter
 {
     SKGError err;
 
-    //Sum annual interest
+    // Sum annual interest
     oInterests = 0;
 
-    //Initial date
+    // Initial date
     int y = iYear;
     if (y == 0) y = QDate::currentDate().year();
     QDate initialDate = QDate(y, 1, 1);
 
-    //Default interest item
+    // Default interest item
     SKGInterestItem currentInterest;
     currentInterest.date = initialDate;
     currentInterest.valueDate = currentInterest.date;
@@ -528,13 +540,13 @@ SKGError SKGAccountObject::computeInterestItems(QList<SKGAccountObject::SKGInter
         SKGInterestItem tmp = ioInterestList.at(i);
         SKGObjectBase object = tmp.object;
         if (object.getRealTable() == "operation") {
-            //Get operations
+            // Get operations
             SKGOperationObject op(object);
 
-            //Get current amount
+            // Get current amount
             tmp.amount = op.getCurrentAmount();
 
-            //Get value date computation mode
+            // Get value date computation mode
             SKGInterestObject::ValueDateMode valueMode = SKGInterestObject::FIFTEEN;
             SKGInterestObject::InterestMode baseMode = SKGInterestObject::FIFTEEN24;
             if (currentInterest.object.getRealTable() == "interest") {
@@ -545,29 +557,33 @@ SKGError SKGAccountObject::computeInterestItems(QList<SKGAccountObject::SKGInter
                 tmp.rate = interestObj.getRate();
             }
 
-            //Compute value date
+            // Compute value date
             if (object.getRealTable() == "operation") {
                 if (valueMode == SKGInterestObject::FIFTEEN) {
                     if (tmp.amount >= 0) {
                         if (tmp.date.day() <= 15) tmp.valueDate = tmp.date.addDays(16 - tmp.date.day());
-                        else tmp.valueDate = tmp.date.addMonths(1).addDays(1 - tmp.date.day());
+                        else {
+                            tmp.valueDate = tmp.date.addMonths(1).addDays(1 - tmp.date.day());
+                        }
                     } else {
                         if (tmp.date.day() <= 15) tmp.valueDate = tmp.date.addDays(1 - tmp.date.day());
-                        else tmp.valueDate = tmp.date.addDays(16 - tmp.date.day());
+                        else {
+                            tmp.valueDate = tmp.date.addDays(16 - tmp.date.day());
+                        }
                     }
                 } else {
                     tmp.valueDate = tmp.date.addDays(tmp.amount >= 0 ? (static_cast<int>(valueMode)) - 1 : - (static_cast<int>(valueMode)) + 1);
                 }
             }
 
-            //Compute coef
+            // Compute coef
             if (baseMode == SKGInterestObject::DAYS365) {
                 QDate last(tmp.date.year(), 12, 31);
                 tmp.coef = tmp.valueDate.daysTo(last) + 1;
                 tmp.coef /= 365;
             } else if (baseMode == SKGInterestObject::DAYS360) {
                 QDate last(tmp.date.year(), 12, 31);
-                tmp.coef = 360 * (last.year() - tmp.valueDate.year()) + 30 * (last.month() - tmp.valueDate.month()) + (last.day() - tmp.valueDate.day()); //TODO must be confirmed
+                tmp.coef = 360 * (last.year() - tmp.valueDate.year()) + 30 * (last.month() - tmp.valueDate.month()) + (last.day() - tmp.valueDate.day());  // TODO(Stephane MANKOWSKI) must be confirmed
                 tmp.coef /= 360;
             } else {
                 tmp.coef = 2 * (12 - tmp.valueDate.month()) + (tmp.valueDate.day() <= 15 ? 2 : 1);
@@ -575,18 +591,18 @@ SKGError SKGAccountObject::computeInterestItems(QList<SKGAccountObject::SKGInter
             }
             if (tmp.valueDate.year() != iYear) tmp.coef = 0;
 
-            //Compute annual interest
+            // Compute annual interest
             tmp.annualInterest = tmp.amount * tmp.coef * tmp.rate / 100;
 
         } else if (object.getRealTable() == "interest") {
-            //Compute coef
+            // Compute coef
             if (tmp.base == 365) {
                 QDate last(tmp.date.year(), 12, 31);
                 tmp.coef = tmp.valueDate.daysTo(last) + 1;
                 tmp.coef /= 365;
             } else if (tmp.base == 360) {
                 QDate last(tmp.date.year(), 12, 31);
-                tmp.coef = 360 * (last.year() - tmp.valueDate.year()) + 30 * (last.month() - tmp.valueDate.month()) + (last.day() - tmp.valueDate.day()); //TODO must be confirmed
+                tmp.coef = 360 * (last.year() - tmp.valueDate.year()) + 30 * (last.month() - tmp.valueDate.month()) + (last.day() - tmp.valueDate.day());  // TODO(Stephane MANKOWSKI) must be confirmed
                 tmp.coef /= 360;
             } else {
                 tmp.coef = 2 * (12 - tmp.valueDate.month()) + (tmp.valueDate.day() <= 15 ? 2 : 1);
@@ -594,24 +610,23 @@ SKGError SKGAccountObject::computeInterestItems(QList<SKGAccountObject::SKGInter
             }
             if (tmp.valueDate.year() != iYear) tmp.coef = 0;
 
-            //Compute annual interest
-            tmp.amount = getAmount(tmp.valueDate);
+            // Compute annual interest
+            tmp.amount = getAmount(tmp.valueDate, true);
             tmp.annualInterest = tmp.amount * tmp.coef * (tmp.rate - currentInterest.rate) / 100;
 
             currentInterest = tmp;
         }
 
-        //Compute sum
+        // Compute sum
         oInterests += tmp.annualInterest;
 
-        //Compute accrued interest
-        tmp.accruedInterest = oInterests - getAmount(tmp.date) * tmp.coef * tmp.rate / 100;
+        // Compute accrued interest
+        tmp.accruedInterest = oInterests - getAmount(tmp.date, true) * tmp.coef * tmp.rate / 100;
 
         ioInterestList[i] = tmp;
-
     }
 
-    //Create temporary table
+    // Create temporary table
     IFOK(err) {
         QStringList sqlOrders;
         sqlOrders << "DROP TABLE IF EXISTS interest_result"
@@ -628,7 +643,7 @@ SKGError SKGAccountObject::computeInterestItems(QList<SKGAccountObject::SKGInter
                   ")";
         err = getDocument()->executeSqliteOrders(sqlOrders);
 
-        //Fill table
+        // Fill table
         int nb2 = ioInterestList.count();
         for (int i = 0; !err && i < nb2; ++i) {
             SKGInterestItem interest = ioInterestList.at(i);
@@ -646,7 +661,6 @@ SKGError SKGAccountObject::computeInterestItems(QList<SKGAccountObject::SKGInter
                 ")";
 
             err = getDocument()->executeSqliteOrder(sqlinsert);
-
         }
     }
     return err;
@@ -659,7 +673,7 @@ SKGError SKGAccountObject::autoReconcile(double iBalance)
     //
     SKGDocumentBank* doc = qobject_cast<SKGDocumentBank*>(getDocument());
     if (doc) {
-        //Get unit
+        // Get unit
         SKGServices::SKGUnitInfo unit1 = doc->getPrimaryUnit();
         SKGUnitObject unitAccount;
         if (getUnit(unitAccount).isSucceeded()) {
@@ -669,7 +683,7 @@ SKGError SKGAccountObject::autoReconcile(double iBalance)
             }
         }
 
-        //Get balance of checked operations
+        // Get balance of checked operations
         double balance = 0;
         SKGStringListList listTmp2;
         err = getDocument()->executeSelectSqliteOrder(
@@ -678,17 +692,17 @@ SKGError SKGAccountObject::autoReconcile(double iBalance)
         if (listTmp2.count() == 2) balance = SKGServices::stringToDouble(listTmp2.at(1).at(0)) / unit1.Value;
 
 
-        //Get all imported operation
+        // Get all imported operation
         double diff = balance - iBalance;
         SKGObjectBase::SKGListSKGObjectBase operations;
         IFOKDO(err, getDocument()->getObjects("v_operation", "rd_account_id=" % SKGServices::intToString(getID()) % " AND t_status='N' AND t_template='N' AND t_imported IN ('Y','P') ORDER BY d_date, id", operations))
 
 
-        //Comparison
+        // Comparison
         QString zero = doc->formatMoney(0, unit1);
         QString negativezero = doc->formatMoney(-EPSILON, unit1);
 
-        //Try to find the soluce
+        // Try to find the soluce
         int nb = operations.count();
 
         QString sdiff = doc->formatMoney(diff, unit1);
@@ -704,11 +718,13 @@ SKGError SKGAccountObject::autoReconcile(double iBalance)
                 if (limit != -1) {
                     err = getDocument()->sendMessage(i18nc("An information message",  "More than one solution is possible for this auto reconciliation."));
                     moreThanOneSoluceFound = true;
-                } else limit = i;
+                } else {
+                    limit = i;
+                }
             }
         }
 
-        //Check all
+        // Check all
         if (limit != -1) {
             for (int i = 0; !err && i <= limit; ++i) {
                 SKGOperationObject op(operations.at(i));
@@ -728,7 +744,7 @@ SKGError SKGAccountObject::merge(const SKGAccountObject& iAccount)
     SKGError err;
     SKGTRACEINRC(10, "SKGAccountObject::merge", err);
 
-    //Get initial balances
+    // Get initial balances
     double balance1;
     SKGUnitObject unit1;
     err = getInitialBalance(balance1, unit1);
@@ -737,7 +753,7 @@ SKGError SKGAccountObject::merge(const SKGAccountObject& iAccount)
     SKGUnitObject unit2;
     IFOKDO(err, const_cast<SKGAccountObject*>(&iAccount)->getInitialBalance(balance2, unit2))
 
-    //Transfert operations
+    // Transfert operations
     SKGObjectBase::SKGListSKGObjectBase ops;
     IFOKDO(err, iAccount.getOperations(ops))
     int nb = ops.count();
@@ -747,14 +763,14 @@ SKGError SKGAccountObject::merge(const SKGAccountObject& iAccount)
         IFOKDO(err, op.save(true, false))
     }
 
-    //Set initial balance
+    // Set initial balance
     SKGUnitObject unit = unit1;
     if (!unit1.exist()) unit = unit2;
     if (unit.exist()) {
         double balance = balance1 + SKGUnitObject::convert(balance2, unit2, unit);
         IFOKDO(err, setInitialBalance(balance, unit))
     }
-    //Remove account
+    // Remove account
     IFOKDO(err, iAccount.remove())
     return err;
 }
