@@ -20,12 +20,13 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgtrackerobject.h"
+
+#include <KLocale>
+
 #include "skgsuboperationobject.h"
 #include "skgdocumentbank.h"
 #include "skgtraces.h"
 
-#include <klocale.h>
-
 SKGTrackerObject::SKGTrackerObject(SKGDocument* iDocument, int iID): SKGNamedObject(iDocument, "v_refund", iID)
 {
 }
@@ -63,13 +64,13 @@ SKGError SKGTrackerObject::createTracker(SKGDocumentBank* iDocument,
     SKGError err;
     SKGTRACEINRC(10, "SKGTrackerObject::createTracker", err);
 
-    //Check if refund is already existing
+    // Check if refund is already existing
     if (iName.isEmpty()) {
         oTracker = SKGTrackerObject(NULL, 0);
     } else if (iDocument) {
         iDocument->getObject("v_refund", "t_name='" % SKGServices::stringToSqlString(iName) % '\'', oTracker);
         if (oTracker.getID() == 0) {
-            //No, we have to create it
+            // No, we have to create it
             oTracker = SKGTrackerObject(iDocument);
             err = oTracker.setName(iName);
             IFOKDO(err, oTracker.save())
