@@ -20,7 +20,12 @@
 * This file defines a main panel.
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
- */
+*/
+#include <KParts/MainWindow>
+#include <KUrl>
+#include <Plasma/Applet>
+#include <QSystemTrayIcon>
+
 #include "skgobjectbase.h"
 #include "skgtabwidget.h"
 #include "skgbasegui_export.h"
@@ -31,11 +36,6 @@
 #include "ui_skgmainpanel_base.h"
 #include "ui_skgmainpanel_pref.h"
 
-#include <kparts/mainwindow.h>
-#include <kurl.h>
-#include <Plasma/Applet>
-
-#include <qsystemtrayicon.h>
 
 class SKGDocument;
 class SKGMainPanelPrivate;
@@ -145,8 +145,9 @@ public Q_SLOTS:
     /**
      * This function is called when the application is launched again with new arguments
      * @param iArgument the arguments
+     * @return true if the arguments have been processed
      */
-    virtual void processArguments(const QStringList& iArgument);
+    virtual bool processArguments(const QStringList& iArgument);
 
     /**
      * Get the current selection
@@ -407,14 +408,14 @@ protected:
     virtual void changeEvent(QEvent* e);
     /**
      * Event filtering
-     * @param object object
-     * @param event event
+     * @param iObject object
+     * @param iEvent event
      * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
      */
-    virtual bool eventFilter(QObject* object, QEvent* event);
+    virtual bool eventFilter(QObject* iObject, QEvent* iEvent);
 
 private Q_SLOTS:
-    void showMenu(const QPoint& pos);
+    void showMenu(const QPoint& iPos);
 
     void onSettingsChanged();
     void onCancelCurrentAction();
@@ -448,6 +449,8 @@ private Q_SLOTS:
     void onLockDocks();
     void onUnlockDocks();
 
+    void onConfigureNotifications();
+
 private:
     Q_DISABLE_COPY(SKGMainPanel)
     void setupActions();
@@ -455,4 +458,4 @@ private:
     SKGMainPanelPrivate* const d;
 };
 
-#endif // SKGMAINPANEL_H
+#endif  // SKGMAINPANEL_H
