@@ -20,23 +20,24 @@
 * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgobjectmodelbase.h"
-#include "skgtraces.h"
-#include "skgdocument.h"
-#include "skgnodeobject.h"
-#include "skgtransactionmng.h"
-#include "skgmainpanel.h"
 
-#include <kstandarddirs.h>
-#include <klocalizedstring.h>
-#include <klocale.h>
-#include <kicon.h>
-#include <kcolorscheme.h>
+#include <KStandardDirs>
+#include <KLocalizedString>
+#include <KLocale>
+#include <KIcon>
+#include <KColorScheme>
 
 #include <QApplication>
 #include <QMimeData>
 #include <QDir>
 #include <QColor>
 
+#include "skgtraces.h"
+#include "skgdocument.h"
+#include "skgnodeobject.h"
+#include "skgtransactionmng.h"
+#include "skgmainpanel.h"
+
 SKGObjectModelBase::SKGObjectModelBase(SKGDocument* iDocument,
                                        const QString& iTable,
                                        const QString& iWhereClause,
@@ -118,10 +119,12 @@ void SKGObjectModelBase::setSupportedAttributes(const QStringList& iListAttribut
         if (nbValues > 0 && !m_listSupported.contains(att) && attributesAvailables.contains(att)) {
             m_listSupported.push_back(att);
             bool visible = true;
-            if (nbValues > 1) visible = (i == 0 || values.at(1) == "Y"); //First column is always visible to support grouping
+            if (nbValues > 1) visible = (i == 0 || values.at(1) == "Y");  // First column is always visible to support grouping
             m_listVisibility.push_back(visible);
             if (nbValues > 2) m_listSize.push_back(SKGServices::stringToInt(values.at(2)));
-            else m_listSize.push_back(-1);
+            else {
+                m_listSize.push_back(-1);
+            }
         }
     }
 
@@ -189,7 +192,7 @@ void SKGObjectModelBase::buidCache()
     m_doctransactionTable = (getRealTable() == "doctransaction");
     m_nodeTable = (getRealTable() == "node");
 
-    //Get std colors
+    // Get std colors
     KColorScheme scheme(QPalette::Normal);
     m_fontNegativeColor = qVariantFromValue(scheme.foreground(KColorScheme::NegativeText).color());
 }
@@ -228,28 +231,33 @@ void SKGObjectModelBase::refresh()
         if (m_document && m_document->getAttributesList(m_table, listAttibutesTmp).isSucceeded()) {
             m_isResetRealyNeeded = false;
             if (listAttibutesTmp.count()) {
-                //Filter attributes
+                // Filter attributes
                 int nb = m_listSupported.count();
                 if (nb == 0) {
                     setSupportedAttributes(QStringList());
                     nb = m_listSupported.count();
                 }
                 for (int i = 0 ; i < nb ; ++i) {
-                    QString att = m_listSupported[i];
+                    QString att = m_listSupported.at(i);
                     if (listAttibutesTmp.contains(att) || att.startsWith(QLatin1String("p_"))) {
                         m_listAttibutes.push_back(att);
                         if (att.startsWith(QLatin1String("t_")) || att.startsWith(QLatin1String("p_"))) m_listAttributeTypes.push_back(SKGServices::TEXT);
-                        else if (att.startsWith(QLatin1String("f_"))) m_listAttributeTypes.push_back(SKGServices::FLOAT);
-                        else if (att.startsWith(QLatin1String("i_"))) m_listAttributeTypes.push_back(SKGServices::INTEGER);
-                        else if (att.startsWith(QLatin1String("d_"))) m_listAttributeTypes.push_back(SKGServices::DATE);
-                        else m_listAttributeTypes.push_back(SKGServices::OTHER);
+                        else if (att.startsWith(QLatin1String("f_"))) {
+                            m_listAttributeTypes.push_back(SKGServices::FLOAT);
+                        } else if (att.startsWith(QLatin1String("i_"))) {
+                            m_listAttributeTypes.push_back(SKGServices::INTEGER);
+                        } else if (att.startsWith(QLatin1String("d_"))) {
+                            m_listAttributeTypes.push_back(SKGServices::DATE);
+                        } else {
+                            m_listAttributeTypes.push_back(SKGServices::OTHER);
+                        }
                     }
                 }
 
-                //Remove double
+                // Remove double
                 nb = m_listAttibutes.count();
                 for (int i = nb - 1 ; i >= 0 ; --i) {
-                    QString att = m_listAttibutes[i];
+                    QString att = m_listAttibutes.at(i);
                     if (att.contains("_REAL")) {
                         att.replace("_REAL", "_");
                         int p = m_listAttibutes.indexOf(att);
@@ -258,7 +266,6 @@ void SKGObjectModelBase::refresh()
                             p = m_listAttibutes.indexOf(att);
                         }
                         if (p != -1) {
-                            ;
                             m_listAttibutes.removeAt(p);
                             m_listAttributeTypes.removeAt(p);
                             if (p < i) --i;
@@ -267,17 +274,19 @@ void SKGObjectModelBase::refresh()
                 }
             }
 
-            //Get objects
+            // Get objects
             QString wc = m_whereClause;
             if (!m_groupby.isEmpty()) {
                 if (wc.isEmpty()) wc = "1=1";
                 if (m_groupby.startsWith(QLatin1String("p_")))
                     wc += " ORDER BY (SELECT t_value FROM parameters WHERE t_uuid_parent=" % getTable() % ".id||'-" % getRealTable() % "' AND t_name='" % m_groupby % "')";
-                else wc += " ORDER BY " % m_groupby;
+                else {
+                    wc += " ORDER BY " % m_groupby;
+                }
             }
             if (m_document) m_document->getObjects(m_table, wc , m_listObjects);
 
-            //Initialize object to treat
+            // Initialize object to treat
             QString currentGroup;
             int currentGoupId = 0;
             bool groupByDate = (m_groupby.startsWith(QLatin1String("d_")));
@@ -290,56 +299,83 @@ void SKGObjectModelBase::refresh()
 
                 int idparent = 0;
                 if (m_groupby.isEmpty()) {
-                    //Grouping by tree
+                    // Grouping by tree
                     if (!m_parentAttribute.isEmpty()) {
                         int idp = SKGServices::stringToInt(c->getAttribute(m_parentAttribute));
                         if (idp > 0) idparent = idp;
                     }
                 } else {
-                    //Grouping on specified attribute
+                    // Grouping on specified attribute
                     QString att = getAttributeForGrouping(*c, m_groupby);
                     if (groupByDate) {
                         QDate date = SKGServices::stringToTime(att).date();
                         if (date == QDate::currentDate()) att = i18nc("A group name for grouping by date attibute", "Today");
                         else if (date > QDate::currentDate()) {
-                            //In future
+                            // In future
                             if (date < QDate::currentDate().addDays(7)) att = i18nc("A group name for grouping by date attibute", "Next 7 days");
-                            else if (date < QDate::currentDate().addDays(15)) att = i18nc("A group name for grouping by date attibute", "Next 15 days");
-                            else if (date < QDate::currentDate().addMonths(1)) att = i18nc("A group name for grouping by date attibute", "Next month");
-                            else if (date < QDate::currentDate().addMonths(3)) att = i18nc("A group name for grouping by date attibute", "Next 3 months");
-                            else if (date < QDate::currentDate().addMonths(6)) att = i18nc("A group name for grouping by date attibute", "Next 6 months");
-                            else if (date < QDate::currentDate().addYears(1)) att = i18nc("A group name for grouping by date attibute", "Next year");
-                            else if (date < QDate::currentDate().addYears(3)) att = i18nc("A group name for grouping by date attibute", "Next 3 years");
-                            else att = i18nc("A group name for grouping by date attibute", "Far away in the future");
+                            else if (date < QDate::currentDate().addDays(15)) {
+                                att = i18nc("A group name for grouping by date attibute", "Next 15 days");
+                            } else if (date < QDate::currentDate().addMonths(1)) {
+                                att = i18nc("A group name for grouping by date attibute", "Next month");
+                            } else if (date < QDate::currentDate().addMonths(3)) {
+                                att = i18nc("A group name for grouping by date attibute", "Next 3 months");
+                            } else if (date < QDate::currentDate().addMonths(6)) {
+                                att = i18nc("A group name for grouping by date attibute", "Next 6 months");
+                            } else if (date < QDate::currentDate().addYears(1)) {
+                                att = i18nc("A group name for grouping by date attibute", "Next year");
+                            } else if (date < QDate::currentDate().addYears(3)) {
+                                att = i18nc("A group name for grouping by date attibute", "Next 3 years");
+                            } else {
+                                att = i18nc("A group name for grouping by date attibute", "Far away in the future");
+                            }
                         } else {
-                            //In the past
+                            // In the past
                             if (date > QDate::currentDate().addDays(-7)) att = i18nc("A group name for grouping by date attibute", "Last 7 days");
-                            else if (date > QDate::currentDate().addDays(-15)) att = i18nc("A group name for grouping by date attibute", "Last 15 days");
-                            else if (date > QDate::currentDate().addMonths(-1)) att = i18nc("A group name for grouping by date attibute", "Last month");
-                            else if (date > QDate::currentDate().addMonths(-3)) att = i18nc("A group name for grouping by date attibute", "Last 3 months");
-                            else if (date > QDate::currentDate().addMonths(-6)) att = i18nc("A group name for grouping by date attibute", "Last 6 months");
-                            else if (date > QDate::currentDate().addYears(-1)) att = i18nc("A group name for grouping by date attibute", "Last year");
-                            else if (date > QDate::currentDate().addYears(-3)) att = i18nc("A group name for grouping by date attibute", "Last 3 years");
-                            else att = i18nc("A group name for grouping by date attibute", "Far away in the past");
+                            else if (date > QDate::currentDate().addDays(-15)) {
+                                att = i18nc("A group name for grouping by date attibute", "Last 15 days");
+                            } else if (date > QDate::currentDate().addMonths(-1)) {
+                                att = i18nc("A group name for grouping by date attibute", "Last month");
+                            } else if (date > QDate::currentDate().addMonths(-3)) {
+                                att = i18nc("A group name for grouping by date attibute", "Last 3 months");
+                            } else if (date > QDate::currentDate().addMonths(-6)) {
+                                att = i18nc("A group name for grouping by date attibute", "Last 6 months");
+                            } else if (date > QDate::currentDate().addYears(-1)) {
+                                att = i18nc("A group name for grouping by date attibute", "Last year");
+                            } else if (date > QDate::currentDate().addYears(-3)) {
+                                att = i18nc("A group name for grouping by date attibute", "Last 3 years");
+                            } else {
+                                att = i18nc("A group name for grouping by date attibute", "Far away in the past");
+                            }
                         }
                     } else if (groupByNum) {
                         if (att != QChar(8734)) {
                             double d = SKGServices::stringToDouble(att);
                             if (d > 10000.0) att = i18nc("A group name for grouping by numerical attibute", "> 10000");
-                            else if (d > 1000.0) att = i18nc("A group name for grouping by numerical attibute", "> 1000");
-                            else if (d > 100.0) att = i18nc("A group name for grouping by numerical attibute", "> 100");
-                            else if (d > 10.0) att = i18nc("A group name for grouping by numerical attibute", "> 10");
-                            else if (d > 0.0) att = i18nc("A group name for grouping by numerical attibute", "> 0");
-                            else if (d < -10000.0) att = i18nc("A group name for grouping by numerical attibute", "< -10000");
-                            else if (d < -1000.0) att = i18nc("A group name for grouping by numerical attibute", "< -1000");
-                            else if (d < -100.0) att = i18nc("A group name for grouping by numerical attibute", "< -100");
-                            else if (d < -10.0) att = i18nc("A group name for grouping by numerical attibute", "< -10");
-                            else if (d < 0.0) att = i18nc("A group name for grouping by numerical attibute", "< 0");
-                            else att = i18nc("A group name for grouping by numerical attibute", "= 0");
+                            else if (d > 1000.0) {
+                                att = i18nc("A group name for grouping by numerical attibute", "> 1000");
+                            } else if (d > 100.0) {
+                                att = i18nc("A group name for grouping by numerical attibute", "> 100");
+                            } else if (d > 10.0) {
+                                att = i18nc("A group name for grouping by numerical attibute", "> 10");
+                            } else if (d > 0.0) {
+                                att = i18nc("A group name for grouping by numerical attibute", "> 0");
+                            } else if (d < -10000.0) {
+                                att = i18nc("A group name for grouping by numerical attibute", "< -10000");
+                            } else if (d < -1000.0) {
+                                att = i18nc("A group name for grouping by numerical attibute", "< -1000");
+                            } else if (d < -100.0) {
+                                att = i18nc("A group name for grouping by numerical attibute", "< -100");
+                            } else if (d < -10.0) {
+                                att = i18nc("A group name for grouping by numerical attibute", "< -10");
+                            } else if (d < 0.0) {
+                                att = i18nc("A group name for grouping by numerical attibute", "< 0");
+                            } else {
+                                att = i18nc("A group name for grouping by numerical attibute", "= 0");
+                            }
                         }
                     }
                     if (att != currentGroup || currentGoupId == 0) {
-                        //Addition of a new group
+                        // Addition of a new group
                         currentGroup = att;
                         currentGoupId--;
                         SKGObjectBase* group = new SKGObjectBase(m_document, "", currentGoupId);
@@ -369,7 +405,7 @@ void SKGObjectModelBase::refresh()
             }
         }
 
-        //Build cache
+        // Build cache
         buidCache();
 
         {
@@ -398,10 +434,7 @@ int SKGObjectModelBase::rowCount(const QModelIndex& iParent) const
     int idParent = 0;
     if (iParent.isValid()) idParent = iParent.internalId();
 
-    QList<int> children = m_parentChildRelations.value(idParent);
-    //SKGTRACE << table << "-rowCount(" << idParent << " )=" << children.count() << endl;
-    return children.count();
-
+    return m_parentChildRelations.value(idParent).count();
 }
 
 int SKGObjectModelBase::columnCount(const QModelIndex& iParent) const
@@ -420,21 +453,21 @@ QModelIndex SKGObjectModelBase::index(int row, int column, const QModelIndex& iP
 
     int idChild = m_parentChildRelations.value(idParent).at(row);
 
-    //SKGTRACE << table << "-" << idParent << "(" << row << ") ==> " << idChild << endl;
+    // SKGTRACE << table << "-" << idParent << "(" << row << ") ==> " << idChild << endl;
     return (idChild ? createIndex(row, column, idChild) : QModelIndex());
 }
 
-QModelIndex SKGObjectModelBase::parent(const QModelIndex& index) const
+QModelIndex SKGObjectModelBase::parent(const QModelIndex& iIndex) const
 {
-    if (!index.isValid()) return QModelIndex();
+    if (!iIndex.isValid()) return QModelIndex();
     _SKGTRACEIN(10, "SKGObjectModelBase::parent");
 
     int idChild = 0;
-    if (index.isValid()) idChild = index.internalId();
+    if (iIndex.isValid()) idChild = iIndex.internalId();
 
     int idParent = m_childParentRelations.value(idChild);
     int row = m_objectsHashTableRows.value(idParent);
-    //SKGTRACE << table << "-" << idChild << "(" << row << ") <== " << idParent << endl;
+    // SKGTRACE << table << "-" << idChild << "(" << row << ") <== " << idParent << endl;
     return idParent ? createIndex(row, 0, idParent) : QModelIndex();
 }
 
@@ -464,14 +497,18 @@ QVariant SKGObjectModelBase::headerData(int section, Qt::Orientation orientation
     if (orientation == Qt::Horizontal) {
         if (role == Qt::DisplayRole) {
             QString att;
-            if (section >= 0 && section < m_listAttibutes.count()) att = m_listAttibutes[section];
-            else att = SKGServices::intToString(section);
+            if (section >= 0 && section < m_listAttibutes.count()) att = m_listAttibutes.at(section);
+            else {
+                att = SKGServices::intToString(section);
+            }
 
             return getDocument()->getDisplay(getTable() % '.' % att);
         } else if (role == Qt::UserRole) {
             QString att;
             if (section >= 0 && section < m_listAttibutes.count()) att = m_listAttibutes.at(section);
-            else att = SKGServices::intToString(section);
+            else {
+                att = SKGServices::intToString(section);
+            }
 
             int indexAtt = m_listSupported.indexOf(att);
 
@@ -486,8 +523,10 @@ QVariant SKGObjectModelBase::headerData(int section, Qt::Orientation orientation
             return att;
         } else if (role == Qt::DecorationRole) {
             QString att;
-            if (section >= 0 && section < m_listAttibutes.count()) att = m_listAttibutes[section];
-            else att = SKGServices::intToString(section);
+            if (section >= 0 && section < m_listAttibutes.count()) att = m_listAttibutes.at(section);
+            else {
+                att = SKGServices::intToString(section);
+            }
 
             return getDocument()->getIcon(getTable() % '.' % att);
         }
@@ -495,31 +534,31 @@ QVariant SKGObjectModelBase::headerData(int section, Qt::Orientation orientation
     return QVariant();
 }
 
-SKGObjectBase SKGObjectModelBase::getObject(const QModelIndex& index) const
+SKGObjectBase SKGObjectModelBase::getObject(const QModelIndex& iIndex) const
 {
-    SKGObjectBase* obj = getObjectPointer(index);
+    SKGObjectBase* obj = getObjectPointer(iIndex);
     SKGObjectBase output;
     if (obj != NULL) output = *obj;
     return output;
 }
 
-SKGObjectBase* SKGObjectModelBase::getObjectPointer(const QModelIndex& index) const
+SKGObjectBase* SKGObjectModelBase::getObjectPointer(const QModelIndex& iIndex) const
 {
     _SKGTRACEIN(10, "SKGObjectModelBase::getObject");
-    //SKGTRACE << "getObject:" << index.internalId() << endl;
-    return m_objectsHashTable.value(index.internalId());
+    // SKGTRACE << "getObject:" << index.internalId() << endl;
+    return m_objectsHashTable.value(iIndex.internalId());
 }
 
-QVariant SKGObjectModelBase::data(const QModelIndex& index, int role) const
+QVariant SKGObjectModelBase::data(const QModelIndex& iIndex, int iRole) const
 {
-    if (!index.isValid()) return QVariant();
+    if (!iIndex.isValid()) return QVariant();
     _SKGTRACEIN(10, "SKGObjectModelBase::data");
 
-    switch (role) {
+    switch (iRole) {
     case Qt::BackgroundRole: {
-        SKGObjectBase* obj = getObjectPointer(index);
+        SKGObjectBase* obj = getObjectPointer(iIndex);
         if (obj->getTable().isEmpty()) {
-            //This is a group
+            // This is a group
             return QApplication::palette().brush(QPalette::Button);
         }
         break;
@@ -527,29 +566,32 @@ QVariant SKGObjectModelBase::data(const QModelIndex& index, int role) const
     case Qt::DisplayRole:
     case Qt::EditRole:
     case Qt::UserRole: {
-        SKGObjectBase* obj = getObjectPointer(index);
-        QString att = m_listAttibutes[index.column()];
+        SKGObjectBase* obj = getObjectPointer(iIndex);
+        QString att = m_listAttibutes.at(iIndex.column());
         if (obj->getTable().isEmpty()) {
-            //This is a group
-            if (index.column() == 0) {
-                if (role == Qt::UserRole) return -obj->getID(); //For sorting
-                else return i18nc("How to display a grouping title. Here \"title (count)\"", "%1: %2 (%3)",
-                                      getDocument()->getDisplay(m_groupby),
-                                      obj->getAttribute("t_title"),
-                                      rowCount(SKGObjectModelBase::index(index.row(), 0)));
+            // This is a group
+            if (iIndex.column() == 0) {
+                if (iRole == Qt::UserRole) {
+                    return -obj->getID();   // For sorting
+                } else {
+                    return i18nc("How to display a grouping title. Here \"title (count)\"", "%1: %2 (%3)",
+                                 getDocument()->getDisplay(m_groupby),
+                                 obj->getAttribute("t_title"),
+                                 rowCount(SKGObjectModelBase::index(iIndex.row(), 0)));
+                }
             }
             return "";
         } else {
             QString val;
             if (att.startsWith(QLatin1String("p_"))) {
-                //This is a property
+                // This is a property
                 val = obj->getProperty(att.right(att.count() - 2));
             } else {
-                //This is a real attribute
+                // This is a real attribute
                 val = obj->getAttribute(att);
             }
 
-            switch (getAttributeType(index.column())) {
+            switch (getAttributeType(iIndex.column())) {
             case SKGServices::FLOAT: {
                 double dval = SKGServices::stringToDouble(val);
                 return dval;
@@ -559,7 +601,7 @@ QVariant SKGObjectModelBase::data(const QModelIndex& index, int role) const
             }
             case SKGServices::DATE: {
                 QDate dval = SKGServices::stringToTime(val).date();
-                if (role == Qt::DisplayRole) {
+                if (iRole == Qt::DisplayRole) {
                     return KGlobal::locale()->formatDate(dval, static_cast<KLocale::DateFormat>(skgbasegui_settings::date_format()));
                 } else {
                     return dval;
@@ -571,17 +613,17 @@ QVariant SKGObjectModelBase::data(const QModelIndex& index, int role) const
 
             if (m_doctransactionTable && att == "t_savestep") return "";
 
-            //return val+"("+SKGServices::intToString(rowCount(index))+")";
+            // return val+"("+SKGServices::intToString(rowCount(index))+")";
             return val;
         }
     }
 
     case Qt::FontRole: {
-        SKGObjectBase* obj = getObjectPointer(index);
-        //Text color
+        SKGObjectBase* obj = getObjectPointer(iIndex);
+        // Text color
         if (obj->getTable().isEmpty()) {
-            //This is a group
-            if (index.column() == 0) {
+            // This is a group
+            if (iIndex.column() == 0) {
                 QFont f;
                 f.setBold(true);
 
@@ -592,9 +634,9 @@ QVariant SKGObjectModelBase::data(const QModelIndex& index, int role) const
         break;
     }
     case Qt::TextColorRole: {
-        //Text color
-        if (getAttributeType(index.column()) == SKGServices::FLOAT) {
-            QVariant value_displayed = SKGObjectModelBase::data(index, Qt::UserRole);
+        // Text color
+        if (getAttributeType(iIndex.column()) == SKGServices::FLOAT) {
+            QVariant value_displayed = SKGObjectModelBase::data(iIndex, Qt::UserRole);
             bool ok = false;
             double value_double = value_displayed.toDouble(&ok);
             if (ok && value_double < 0) return m_fontNegativeColor;
@@ -602,23 +644,23 @@ QVariant SKGObjectModelBase::data(const QModelIndex& index, int role) const
         break;
     }
     case Qt::TextAlignmentRole: {
-        //Text alignment
-        SKGServices::AttributeType attType = getAttributeType(index.column());
+        // Text alignment
+        SKGServices::AttributeType attType = getAttributeType(iIndex.column());
         return static_cast<int>(Qt::AlignVCenter | (attType == SKGServices::FLOAT || attType == SKGServices::INTEGER ? Qt::AlignRight : Qt::AlignLeft));
     }
     case Qt::DecorationRole: {
-        //Decoration
-        SKGObjectBase* obj = getObjectPointer(index);
-        QString att = m_listAttibutes[index.column()];
+        // Decoration
+        SKGObjectBase* obj = getObjectPointer(iIndex);
+        QString att = m_listAttibutes.at(iIndex.column());
         if (obj->getTable().isEmpty()) {
-            //This is a group
-            if (index.column() == 0) return qVariantFromValue(static_cast<QIcon>(KIcon("arrow-right")));;
+            // This is a group
+            if (iIndex.column() == 0) return qVariantFromValue(static_cast<QIcon>(KIcon("arrow-right")));;
             return "";
         } else {
-            if (index.column() == 0 && m_nodeTable) {
+            if (iIndex.column() == 0 && m_nodeTable) {
                 SKGNodeObject node(*obj);
                 return qVariantFromValue(node.getIcon());
-            } else if (index.column() == 0 && m_doctransactionTable) {
+            } else if (iIndex.column() == 0 && m_doctransactionTable) {
                 return qVariantFromValue(static_cast<QIcon>(KIcon(obj->getAttribute("t_mode") == "U" ? "edit-undo" : "edit-redo")));
             } else if (m_doctransactionTable && att == "t_savestep") {
                 if (obj->getAttribute("t_savestep") == "Y") return qVariantFromValue(static_cast<QIcon>(KIcon("document-save")));
@@ -627,9 +669,9 @@ QVariant SKGObjectModelBase::data(const QModelIndex& index, int role) const
         break;
     }
     case Qt::ToolTipRole: {
-        //Tooltip
+        // Tooltip
         QString toolTipString;
-        SKGObjectBase* obj = getObjectPointer(index);
+        SKGObjectBase* obj = getObjectPointer(iIndex);
 
         if (obj && m_document) {
             if (m_doctransactionTable) {
@@ -643,8 +685,8 @@ QVariant SKGObjectModelBase::data(const QModelIndex& index, int role) const
                         toolTipString += msg.at(i);
                     }
                 }
-            } else if (getAttributeType(index.column()) == SKGServices::DATE) {
-                QString att = m_listAttibutes[index.column()];
+            } else if (getAttributeType(iIndex.column()) == SKGServices::DATE) {
+                QString att = m_listAttibutes.at(iIndex.column());
                 QString val = obj->getAttribute(att);
 
                 QDate dval = SKGServices::stringToTime(val).date();
@@ -655,7 +697,7 @@ QVariant SKGObjectModelBase::data(const QModelIndex& index, int role) const
                 if (shortDate != fancyDate) toolTipString = shortDate;
             }
 
-            //Add properties
+            // Add properties
             QStringList props = obj->getProperties();
             if (props.count() > 0 && !toolTipString.isEmpty()) toolTipString += '\n';
             foreach(const QString & prop, props) {
@@ -663,7 +705,7 @@ QVariant SKGObjectModelBase::data(const QModelIndex& index, int role) const
                 toolTipString += i18nc("To display a property and its value", "%1=%2", prop, obj->getProperty(prop));
             }
 
-            //Add UUID
+            // Add UUID
             IFSKGTRACEL(1) {
                 toolTipString += '\n' % obj->getUniqueID();
             }
@@ -671,7 +713,7 @@ QVariant SKGObjectModelBase::data(const QModelIndex& index, int role) const
         return toolTipString;
     }
     case 99: {
-        SKGObjectBase* obj = getObjectPointer(index);
+        SKGObjectBase* obj = getObjectPointer(iIndex);
         if (obj) return SKGServices::stringToDouble(obj->getAttribute("f_sortorder"));
 
         break;
@@ -683,53 +725,52 @@ QVariant SKGObjectModelBase::data(const QModelIndex& index, int role) const
     return QVariant();
 }
 
-Qt::ItemFlags SKGObjectModelBase::flags(const QModelIndex& index) const
+Qt::ItemFlags SKGObjectModelBase::flags(const QModelIndex& iIndex) const
 {
     _SKGTRACEIN(10, "SKGObjectModelBase::flags");
 
-    Qt::ItemFlags flags = QAbstractItemModel::flags(index) | Qt::ItemIsDropEnabled;
+    Qt::ItemFlags f = QAbstractItemModel::flags(iIndex) | Qt::ItemIsDropEnabled;
 
-    if (index.isValid()) flags |= Qt::ItemIsUserCheckable;
+    if (iIndex.isValid()) f |= Qt::ItemIsUserCheckable;
 
-    if (m_nodeTable && index.isValid()) flags |= Qt::ItemIsEditable | Qt::ItemIsDragEnabled;
+    if (m_nodeTable && iIndex.isValid()) f |= Qt::ItemIsEditable | Qt::ItemIsDragEnabled;
 
-    if (index.isValid()) {
-        QString att = m_listAttibutes[index.column()];
-        if (att.toLower() == att || !getDocument()->getRealAttribute(att).isEmpty()) flags |= Qt::ItemIsEditable;
-        SKGObjectBase* obj = getObjectPointer(index);
-        if (obj->getTable().isEmpty()) flags = Qt::ItemIsEnabled;
+    if (iIndex.isValid()) {
+        QString att = m_listAttibutes.at(iIndex.column());
+        if (att.toLower() == att || !getDocument()->getRealAttribute(att).isEmpty()) f |= Qt::ItemIsEditable;
+        SKGObjectBase* obj = getObjectPointer(iIndex);
+        if (obj->getTable().isEmpty()) f = Qt::ItemIsEnabled;
     }
 
-    return flags;
-
+    return f;
 }
 
-bool SKGObjectModelBase::setData(const QModelIndex& index, const QVariant& value, int role)
+bool SKGObjectModelBase::setData(const QModelIndex& iIndex, const QVariant& iValue, int iRole)
 {
-    if (!index.isValid()) return false;
+    if (!iIndex.isValid()) return false;
 
-    if (role == Qt::EditRole) {
+    if (iRole == Qt::EditRole) {
         SKGError err;
         if (m_nodeTable) {
-            SKGNodeObject obj(getObject(index));
-            QString name = value.toString();
+            SKGNodeObject obj(getObject(iIndex));
+            QString name = iValue.toString();
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Bookmark update '%1'", name), err);
             err = obj.setName(name);
             IFOKDO(err, obj.save())
         } else {
-            SKGObjectBase obj(getObject(index));
+            SKGObjectBase obj(getObject(iIndex));
 
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Update object"), err);
-            SKGObjectBase obj2(obj.getDocument(), obj.getRealTable(), obj.getID()); //To be sure this is not a complex object
-            QString att = m_listAttibutes[index.column()];
-            err = obj2.setAttribute(att, att.startsWith(QLatin1String("d_")) && value.canConvert<QDateTime>() ? SKGServices::dateToSqlString(value.toDateTime()) : value.toString());
+            SKGObjectBase obj2(obj.getDocument(), obj.getRealTable(), obj.getID());  // To be sure this is not a complex object
+            QString att = m_listAttibutes.at(iIndex.column());
+            err = obj2.setAttribute(att, att.startsWith(QLatin1String("d_")) && iValue.canConvert<QDateTime>() ? SKGServices::dateToSqlString(iValue.toDateTime()) : iValue.toString());
             IFOKDO(err, obj2.save())
         }
 
         SKGMainPanel::displayErrorMessage(err);
         return !err;
     }
-    return QAbstractItemModel::setData(index, value, role);
+    return QAbstractItemModel::setData(iIndex, iValue, iRole);
 }
 
 Qt::DropActions SKGObjectModelBase::supportedDragActions() const
@@ -751,41 +792,41 @@ QStringList SKGObjectModelBase::mimeTypes() const
     return types;
 }
 
-QMimeData* SKGObjectModelBase::mimeData(const QModelIndexList& indexes) const
+QMimeData* SKGObjectModelBase::mimeData(const QModelIndexList& iIndexes) const
 {
-    QMimeData* mimeData = new QMimeData();
+    QMimeData* md = new QMimeData();
     QByteArray encodedData;
 
     QDataStream stream(&encodedData, QIODevice::WriteOnly);
 
     QString t = getTable();
-    foreach(const QModelIndex & index, indexes) {
-        if (index.isValid() && index.column() == 0) {
-            SKGObjectBase obj = getObject(index);
+    foreach(const QModelIndex & idx, iIndexes) {
+        if (idx.isValid() && idx.column() == 0) {
+            SKGObjectBase obj = getObject(idx);
             t = obj.getRealTable();
             stream << t;
             stream << obj.getID();
         }
     }
 
-    mimeData->setData("application/skg." % t % ".ids", encodedData);
-    return mimeData;
+    md->setData("application/skg." % t % ".ids", encodedData);
+    return md;
 }
 
-bool SKGObjectModelBase::dropMimeData(const QMimeData* data,
-                                      Qt::DropAction action,
-                                      int row, int column,
+bool SKGObjectModelBase::dropMimeData(const QMimeData* iData,
+                                      Qt::DropAction iAction,
+                                      int iRow, int iColumn,
                                       const QModelIndex& iParent)
 {
-    Q_UNUSED(row);
-    if (action == Qt::IgnoreAction) return true;
-    if (!data || !(data->hasFormat("application/skg.node.ids") || data->hasUrls())) return false; //TODO: accept all
-    if (column > 0) return false;
+    Q_UNUSED(iRow);
+    if (iAction == Qt::IgnoreAction) return true;
+    if (!iData || !(iData->hasFormat("application/skg.node.ids") || iData->hasUrls())) return false;  // TODO(Stephane MANKOWSKI): accept all
+    if (iColumn > 0) return false;
 
     SKGError err;
-    //Drop files
-    if (data->hasUrls() && iParent.isValid() && getRealTable() != "node") {
-        QList<QUrl> urls = data->urls();
+    // Drop files
+    if (iData->hasUrls() && iParent.isValid() && getRealTable() != "node") {
+        QList<QUrl> urls = iData->urls();
         int nb = urls.count();
         {
             SKGObjectBase obj(getObject(iParent));
@@ -793,19 +834,18 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData* data,
             SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Property creation"), err, nb);
             for (int i = 0; !err && i < nb; ++i) {
                 QString name = i18n("File");
-                int index = 1;
+                int idx = 1;
                 while (!err && !obj.getProperty(name).isEmpty()) {
-                    index++;
-                    name = i18n("File") % " (" % SKGServices::intToString(index) % ')';
+                    idx++;
+                    name = i18n("File") % " (" % SKGServices::intToString(idx) % ')';
                 }
-                err = obj.setProperty(name, urls.at(i).toLocalFile(), action == Qt::LinkAction ? "" : urls.at(i).toLocalFile());
+                err = obj.setProperty(name, urls.at(i).toLocalFile(), iAction == Qt::LinkAction ? "" : urls.at(i).toLocalFile());
                 IFOKDO(err, getDocument()->stepForward(i + 1))
             }
         }
-    }
-    //Drop nodes
-    else if (data->hasFormat("application/skg.node.ids")) {
-        QByteArray encodedData = data->data("application/skg.node.ids");
+    } else if (iData->hasFormat("application/skg.node.ids")) {
+        // Drop nodes
+        QByteArray encodedData = iData->data("application/skg.node.ids");
         QDataStream stream(&encodedData, QIODevice::ReadOnly);
         QStringList newItems;
 
@@ -814,7 +854,7 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData* data,
         if (parentIndex.isValid()) {
             parentNode = getObject(parentIndex);
             if (!parentNode.isFolder()) {
-                //The parent is not a directory
+                // The parent is not a directory
                 parentNode.getParentNode(parentNode);
                 parentIndex = parentIndex.parent();
             }
@@ -824,15 +864,15 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData* data,
 
             double min = 0;
             double max = 0;
-            if (row >= 1) {
-                QModelIndex previousIndex = SKGObjectModelBase::index(row - 1, 0, parentIndex);
+            if (iRow >= 1) {
+                QModelIndex previousIndex = SKGObjectModelBase::index(iRow - 1, 0, parentIndex);
                 SKGNodeObject previousObject(getObject(previousIndex));
                 min = previousObject.getOrder();
             }
 
-            if (row >= rowCount(parentIndex)) max = min + 1;
+            if (iRow >= rowCount(parentIndex)) max = min + 1;
             else {
-                QModelIndex nextIndex = SKGObjectModelBase::index(row, 0, parentIndex);
+                QModelIndex nextIndex = SKGObjectModelBase::index(iRow, 0, parentIndex);
                 SKGNodeObject nextObject(getObject(nextIndex));
                 max = nextObject.getOrder();
             }
@@ -844,18 +884,20 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData* data,
                 stream >> o_table;
                 stream >> o_id;
 
-                //Set parent
+                // Set parent
                 SKGNodeObject child(getDocument(), o_id);
                 err = child.load();
                 IFOK(err) {
                     if (parentIndex.isValid()) err = child.setParentNode(parentNode);
-                    else err = child.removeParentNode();
+                    else {
+                        err = child.removeParentNode();
+                    }
                 }
 
-                //Set order
+                // Set order
                 IFOKDO(err, child.setOrder((min + max) / 2.0))
 
-                //Save
+                // Save
                 IFOKDO(err, child.save())
             }
         }
@@ -882,10 +924,10 @@ void SKGObjectModelBase::dataModified(const QString& iTableName, int iIdTransact
             return;
         }
 
-        //Full refresh
+        // Full refresh
         m_isResetRealyNeeded = true;
 
-        //Refresh model
+        // Refresh model
         refresh();
     }
 }
@@ -893,10 +935,10 @@ void SKGObjectModelBase::dataModified(const QString& iTableName, int iIdTransact
 QString SKGObjectModelBase::getAttributeForGrouping(const SKGObjectBase& iObject, const QString& iAttribute) const
 {
     if (iAttribute.startsWith(QLatin1String("p_"))) {
-        //This is a property
+        // This is a property
         return iObject.getProperty(iAttribute.right(iAttribute.count() - 2));
     } else {
-        //This is a real attribute
+        // This is a real attribute
         return iObject.getAttribute(iAttribute);
     }
 }
