@@ -20,11 +20,12 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgshow.h"
-#include "skgservices.h"
 
-#include <klocale.h>
-#include <kmenu.h>
-#include <kicon.h>
+#include <KLocale>
+#include <KMenu>
+#include <KIcon>
+
+#include "skgservices.h"
 
 SKGShow::SKGShow(QWidget* iParent)
     : QToolButton(iParent), m_mode(OR), m_inTrigger(false), m_displayTitle(true)
@@ -36,7 +37,7 @@ SKGShow::SKGShow(QWidget* iParent)
     m_menu = new KMenu(this);
     setMenu(m_menu);
 
-    //Time to emit stateChanged
+    // Time to emit stateChanged
     m_timer.setSingleShot(true);
     connect(&m_timer, SIGNAL(timeout()), this, SIGNAL(stateChanged()), Qt::QueuedConnection);
 
@@ -62,10 +63,10 @@ QString SKGShow::getState()
 {
     QStringList itemsChecked;
     if (m_menu) {
-        QList<QAction*> actions = m_menu->actions();
-        int nb = actions.count();
+        QList<QAction*> actionsList = m_menu->actions();
+        int nb = actionsList.count();
         for (int i = 0; i < nb; ++i) {
-            QAction* act = actions.at(i);
+            QAction* act = actionsList.at(i);
             if (act && act->isChecked()) itemsChecked.push_back(act->data().toString());
         }
     }
@@ -76,11 +77,11 @@ QString SKGShow::getWhereClause() const
 {
     QString wc;
     if (m_menu) {
-        QList<QAction*> actions = m_menu->actions();
-        int nb = actions.count();
+        QList<QAction*> actionsList = m_menu->actions();
+        int nb = actionsList.count();
         bool noCheck = true;
         for (int i = 0; i < nb; ++i) {
-            QAction* act = actions.at(i);
+            QAction* act = actionsList.at(i);
             if (act && act->isChecked()) {
                 if (!wc.isEmpty()) wc += (m_mode == OR ? " OR " : " AND ");
                 wc += '(' % m_whereclause[act] % ')';
@@ -129,10 +130,10 @@ void SKGShow::setState(const QString& iState)
             m_actions.at(i)->setChecked(itemsChecked.contains(m_actions.at(i)->data().toString()));
         }
 
-        //Change tooltip
+        // Change tooltip
         setToolTip(getTitle());
 
-        //Emit event
+        // Emit event
         emit stateChanged();
     }
 }
@@ -158,10 +159,10 @@ int SKGShow::count()
 int SKGShow::addGroupedItem(const QString& iIdentifier, const QString& iText, const QString& iIcon, const QString& iWhereClose, const QString& iGroup)
 {
     if (m_menu) {
-        QActionGroup* group = m_groups[iGroup];
-        if (!group) {
-            group = new QActionGroup(this);
-            m_groups[iGroup] = group;
+        QActionGroup* groupAction = m_groups[iGroup];
+        if (!groupAction) {
+            groupAction = new QActionGroup(this);
+            m_groups[iGroup] = groupAction;
         }
 
         QString name = iText;
@@ -184,7 +185,7 @@ int SKGShow::addGroupedItem(const QString& iIdentifier, const QString& iText, co
 
             connect(act, SIGNAL(toggled(bool)), this, SLOT(trigger()));
 
-            group->addAction(act);
+            groupAction->addAction(act);
         }
 
         show();
@@ -262,11 +263,11 @@ void SKGShow::trigger()
     if (act && !m_inTrigger) {
         m_inTrigger = true;
 
-        //Apply rules
+        // Apply rules
         QStringList over;
         if (act->isChecked()) {
             {
-                //Check items
+                // Check items
                 QStringList items = SKGServices::splitCSVLine(m_check_to_check[act]);
                 int nb = items.count();
                 for (int i = 0; i < nb; ++i) {
@@ -276,7 +277,7 @@ void SKGShow::trigger()
             }
 
             {
-                //Uncheck items
+                // Uncheck items
                 QStringList items = SKGServices::splitCSVLine(m_check_to_uncheck[act]);
                 int nb = items.count();
                 for (int i = 0; i < nb; ++i) {
@@ -286,7 +287,7 @@ void SKGShow::trigger()
             }
         } else {
             {
-                //Check items
+                // Check items
                 QStringList items = SKGServices::splitCSVLine(m_uncheck_to_check[act]);
                 int nb = items.count();
                 for (int i = 0; i < nb; ++i) {
@@ -296,7 +297,7 @@ void SKGShow::trigger()
             }
 
             {
-                //Uncheck items
+                // Uncheck items
                 QStringList items = SKGServices::splitCSVLine(m_uncheck_to_uncheck[act]);
                 int nb = items.count();
                 for (int i = 0; i < nb; ++i) {
@@ -306,20 +307,22 @@ void SKGShow::trigger()
             }
         }
 
-        //Change tooltip
+        // Change tooltip
         setToolTip(getTitle());
 
-        //Change icon
+        // Change icon
         QStringList icons;
         QString mainIcon;
         if (m_menu) {
             int nb = m_actions.count();
             for (int i = 0; i < nb; ++i) {
-                QAction* act = m_actions.at(i);
-                if (act && act->isChecked()) {
+                QAction* act2 = m_actions.at(i);
+                if (act2 && act2->isChecked()) {
                     if (!m_icons.at(i).isEmpty()) {
                         if (mainIcon.isEmpty()) mainIcon = m_icons.at(i);
-                        else icons.push_back(m_icons.at(i));
+                        else {
+                            icons.push_back(m_icons.at(i));
+                        }
                     } else {
                         if (mainIcon.isEmpty()) mainIcon = "show-menu";
                     }
@@ -329,10 +332,10 @@ void SKGShow::trigger()
         if (mainIcon.isEmpty()) mainIcon = "show-menu";
         setIcon(KIcon(mainIcon, NULL, icons));
 
-        //Emit event
+        // Emit event
         m_timer.start(300);
 
-        //Change title
+        // Change title
         refreshTitle();
 
         m_inTrigger = false;
@@ -353,17 +356,19 @@ void SKGShow::setDisplayTitle(bool iDisplay)
 void SKGShow::refreshTitle()
 {
     if (m_displayTitle) setText(i18n("Show: %1", getTitle()));
-    else setText(i18n("Show"));
+    else {
+        setText(i18n("Show"));
+    }
 }
 
 QAction* SKGShow::getAction(const QString& iIdentifier) const
 {
     QAction* output = NULL;
     if (m_menu) {
-        QList<QAction*> actions = m_menu->actions();
-        int nb = actions.count();
+        QList<QAction*> actionsList = m_menu->actions();
+        int nb = actionsList.count();
         for (int i = 0; !output && i < nb; ++i) {
-            QAction* act = actions.at(i);
+            QAction* act = actionsList.at(i);
             if (act && act->data().toString() == iIdentifier) output = act;
         }
     }
