@@ -20,21 +20,13 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgtreeview.h"
-#include "skgtraces.h"
-#include "skgobjectmodelbase.h"
-#include "skgservices.h"
-#include "skgdocument.h"
-#include "skgerror.h"
-#include "skgtransactionmng.h"
-#include "skgobjectbase.h"
-#include "skgmainpanel.h"
-#include "skgtableview.h"
 
-#include <ksavefile.h>
-#include <kicon.h>
-#include <kmenu.h>
-#include <klocale.h>
-#include <kfiledialog.h>
+#include <KSaveFile>
+#include <KIcon>
+#include <KMenu>
+#include <KLocale>
+#include <KFileDialog>
+#include <KStandardAction>
 
 #include <QDomDocument>
 #include <QHeaderView>
@@ -50,9 +42,18 @@
 #include <QTimer>
 #include <QSvgGenerator>
 #include <QClipboard>
-#include <qtextcodec.h>
+#include <QTextCodec>
 #include <QPushButton>
-#include <kstandardaction.h>
+
+#include "skgtraces.h"
+#include "skgobjectmodelbase.h"
+#include "skgservices.h"
+#include "skgdocument.h"
+#include "skgerror.h"
+#include "skgtransactionmng.h"
+#include "skgobjectbase.h"
+#include "skgmainpanel.h"
+#include "skgtableview.h"
 
 SKGTreeView::SKGTreeView(QWidget* iParent)
     : QTreeView(iParent),
@@ -61,7 +62,7 @@ SKGTreeView::SKGTreeView(QWidget* iParent)
       m_model(NULL), m_proxyModel(NULL),
       stickH(false), stickV(false)
 {
-    //Initialize
+    // Initialize
     setTextElideMode(Qt::ElideMiddle);
     setAutoExpandDelay(300);
     setAnimated(true);
@@ -75,7 +76,7 @@ SKGTreeView::SKGTreeView(QWidget* iParent)
     m_timerScrollSelection.setSingleShot(true);
     connect(&m_timerScrollSelection, SIGNAL(timeout()), this, SLOT(scroolOnSelection()), Qt::QueuedConnection);
 
-    //Menu
+    // Menu
     QHeaderView* hori = header();
     hori->setContextMenuPolicy(Qt::CustomContextMenu);
     m_headerMenu = new KMenu(this);
@@ -104,7 +105,7 @@ SKGTreeView::SKGTreeView(QWidget* iParent)
     connect(horizontalScrollBar(), SIGNAL(rangeChanged(int,int)), this, SLOT(onRangeChanged()));
     connect(verticalScrollBar(), SIGNAL(rangeChanged(int,int)), this, SLOT(onRangeChanged()));
 
-    //Headers
+    // Headers
     hori->setMovable(true);
     hori->setResizeMode(QHeaderView::Fixed);
     setWordWrap(false);
@@ -125,7 +126,7 @@ SKGTreeView::SKGTreeView(QWidget* iParent)
         }
     }
 
-    //Save original size
+    // Save original size
     m_fontOriginalPointSize = this->font().pointSize();
     m_iconOriginalSize = this->iconSize().height();
     if (m_iconOriginalSize <= 0) m_iconOriginalSize = 16;
@@ -161,7 +162,7 @@ QString SKGTreeView::getState()
         }
         root.setAttribute("groupBy", m_groupby);
 
-        //Memorize order
+        // Memorize order
         int nb = hHeader->count();
         if (nb) {
             QString columns;
@@ -184,7 +185,7 @@ QString SKGTreeView::getState()
             root.setAttribute("columnsAutoResize", m_autoResize ? "Y" : "N");
         }
 
-        //Memorize expanded groups
+        // Memorize expanded groups
         if (!m_groupby.isEmpty()) {
             root.setAttribute("expandedGroups", SKGServices::stringsToCsv(m_expandedNodes));
         }
@@ -208,7 +209,7 @@ void SKGTreeView::setState(const QString& iState)
 
     QString viewState = iState;
     if (viewState.isEmpty() && m_document) {
-        //Get default state
+        // Get default state
         viewState = m_document->getParameter(m_parameterName);
     }
 
@@ -224,12 +225,12 @@ void SKGTreeView::setState(const QString& iState)
         QString columnsVisibility = root.attribute("columnsVisibility");
         QString columnsAutoResize = root.attribute("columnsAutoResize");
         QString alternatingRowColors2 = root.attribute("alternatingRowColors");
-        QString zoomPosition = root.attribute("zoomPosition");
+        QString zoomPositionString = root.attribute("zoomPosition");
         QString expandedGroups = root.attribute("expandedGroups");
         stickH = (root.attribute("stickH") == "Y");
         stickV = (root.attribute("stickV") == "Y");
 
-        //Set column order
+        // Set column order
         QStringList listAtt;
         if (!columns.isEmpty()) {
             listAtt = SKGServices::splitCSVLine(columns, ';');
@@ -252,7 +253,7 @@ void SKGTreeView::setState(const QString& iState)
             m_model->setSupportedAttributes(listAtt);
         }
 
-        //Set autoResize
+        // Set autoResize
         if (!columnsAutoResize.isEmpty()) {
             m_autoResize = (columnsAutoResize == "Y");
             header()->setResizeMode(m_autoResize ? QHeaderView::Fixed : QHeaderView::Interactive);
@@ -262,7 +263,7 @@ void SKGTreeView::setState(const QString& iState)
             }
         }
 
-        //Set sort
+        // Set sort
         if (m_model && isSortingEnabled() && !sortOrder.isEmpty() && !sortColumn.isEmpty()) {
             int index = SKGServices::splitCSVLine(columns, ';').indexOf(sortColumn);
             if (index == -1) index = m_model->getIndexAttribute(sortColumn);
@@ -283,11 +284,11 @@ void SKGTreeView::setState(const QString& iState)
             if (m_actCollapseAll) m_actCollapseAll->setVisible(treeMode || !m_groupby.isEmpty());
         }
 
-        //Set alternatingRowColors
+        // Set alternatingRowColors
         if (!alternatingRowColors2.isEmpty()) setAlternatingRowColors(alternatingRowColors2 == "Y");
-        if (!zoomPosition.isEmpty()) setZoomPosition(SKGServices::stringToInt(zoomPosition));
+        if (!zoomPositionString.isEmpty()) setZoomPosition(SKGServices::stringToInt(zoomPositionString));
 
-        //Set expanded groups
+        // Set expanded groups
         m_expandedNodes = SKGServices::splitCSVLine(expandedGroups);
         resetSelection();
     } else {
@@ -358,9 +359,9 @@ void SKGTreeView::showHeaderMenu()
     showHeaderMenu(header()->mapFromGlobal(QCursor::pos()));
 }
 
-void SKGTreeView::showHeaderMenu(const QPoint& pos)
+void SKGTreeView::showHeaderMenu(const QPoint& iPos)
 {
-    if (m_headerMenu) m_headerMenu->popup(header()->mapToGlobal(pos));
+    if (m_headerMenu) m_headerMenu->popup(header()->mapToGlobal(iPos));
 }
 
 void SKGTreeView::setDefaultSaveParameters(SKGDocument* iDocument, const QString& iParameterName)
@@ -376,7 +377,7 @@ void SKGTreeView::setupHeaderMenu()
 
     setCornerWidget(NULL);
     if (m_model && m_headerMenu) {
-        //Corner button on tables to show the contextual menu
+        // Corner button on tables to show the contextual menu
         QPushButton* btn = new QPushButton(this);
         btn->setIcon(KIcon("configure"));
         connect(btn, SIGNAL(clicked()), this, SLOT(showHeaderMenu()));
@@ -384,10 +385,10 @@ void SKGTreeView::setupHeaderMenu()
 
         m_headerMenu->clear();
 
-        //Processing
+        // Processing
         QMenu* columns = m_headerMenu->addMenu(i18nc("Noun, Menu name", "Columns"));
 
-        //Get current groupby column
+        // Get current groupby column
         QMenu* groupbymenu = NULL;
         QActionGroup* groupby = NULL;
         if (!m_model->getWhereClause().contains("ORDER BY")) {
@@ -455,7 +456,7 @@ void SKGTreeView::setupHeaderMenu()
         columns->addSeparator();
 
         if (m_model) {
-            //Build menus for columns
+            // Build menus for columns
             QHeaderView* hHeader = header();
             int nbcol = hHeader->count();
             for (int i = 0; i < nbcol; ++i) {
@@ -471,7 +472,7 @@ void SKGTreeView::setupHeaderMenu()
                     }
                 }
 
-                //Column menu
+                // Column menu
                 QAction* act = columns->addAction(values.at(0));
                 if (act) {
                     act->setCheckable(true);
@@ -482,7 +483,7 @@ void SKGTreeView::setupHeaderMenu()
 
                     connect(act, SIGNAL(triggered(bool)), this, SLOT(showHideColumn()));
 
-                    //Group by menu
+                    // Group by menu
                     QString att = m_model->getAttribute(idx);
                     if (groupbymenu && groupby) {
                         QAction* act2 = groupbymenu->addAction(values.at(0));
@@ -508,11 +509,11 @@ void SKGTreeView::setupHeaderMenu()
     }
 }
 
-void SKGTreeView::setSelectionModel(QItemSelectionModel* selectionModel)
+void SKGTreeView::setSelectionModel(QItemSelectionModel* iSelectionModel)
 {
     if (this->selectionModel()) disconnect(this->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT(onSelectionChanged()));
-    QTreeView::setSelectionModel(selectionModel);
-    if (selectionModel) connect(selectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT(onSelectionChanged()));
+    QTreeView::setSelectionModel(iSelectionModel);
+    if (iSelectionModel) connect(iSelectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT(onSelectionChanged()));
 }
 
 void SKGTreeView::onSelectionChanged()
@@ -587,11 +588,11 @@ void SKGTreeView::onSortChanged(int iIndex, Qt::SortOrder iOrder)
 
 void SKGTreeView::showHideColumn()
 {
-    QAction* sender = static_cast<QAction*>(this->sender());
-    if (sender && m_model) {
+    QAction* send = static_cast<QAction*>(this->sender());
+    if (send && m_model) {
         QHeaderView* hHeader = header();
 
-        int idx = sender->data().toInt();
+        int idx = send->data().toInt();
         bool hidden = !hHeader->isSectionHidden(idx);
         hHeader->setSectionHidden(idx, hidden);
 
@@ -616,11 +617,11 @@ void SKGTreeView::changeSchema()
 {
     QStringList list;
 
-    QAction* sender = static_cast<QAction*>(this->sender());
-    if (sender)  list = SKGServices::splitCSVLine(sender->data().toString(), ';');
+    QAction* send = static_cast<QAction*>(this->sender());
+    if (send)  list = SKGServices::splitCSVLine(send->data().toString(), ';');
 
     if (m_model) {
-        //Reset column oder
+        // Reset column oder
         resetColumnsOrder();
 
         m_model->setSupportedAttributes(list);
@@ -680,7 +681,7 @@ void SKGTreeView::saveSelection()
 
     SKGObjectBase::SKGListSKGObjectBase objs = getSelectedObjects();
     int nb = objs.count();
-    //We save the selection only if not too big
+    // We save the selection only if not too big
     if (nb <= 100) {
         for (int i = 0; i < nb; ++i) {
             QString id = objs.at(i).getUniqueID();
@@ -710,10 +711,10 @@ void SKGTreeView::selectObjects(const QStringList& iUniqueIDs, bool iFocusOnFirs
         selModel->clearSelection();
 
         if (m_model) {
-            //Get all indexes
+            // Get all indexes
             QList<QModelIndex> items;
             items.push_back(QModelIndex());
-            for (int i = 0; i < items.count(); ++i) { //Dynamic size because the list is modified
+            for (int i = 0; i < items.count(); ++i) {  // Dynamic size because the list is modified
                 QModelIndex mi = items.at(i);
                 int nbRows = m_model->rowCount(mi);
                 for (int j = 0; j < nbRows; ++j) {
@@ -724,7 +725,7 @@ void SKGTreeView::selectObjects(const QStringList& iUniqueIDs, bool iFocusOnFirs
 
             int nbRows = items.count();
             if (nbRows) {
-                //Expand nodes
+                // Expand nodes
                 bool previousForThis = this->blockSignals(true);
                 foreach(const QString & exp, m_expandedNodes) {
                     for (int i = 0; i < nbRows; ++i) {
@@ -739,7 +740,7 @@ void SKGTreeView::selectObjects(const QStringList& iUniqueIDs, bool iFocusOnFirs
                 }
                 this->blockSignals(previousForThis);
 
-                //Set selection
+                // Set selection
                 bool focusDone = false;
                 foreach(const QString & sel, iUniqueIDs) {
                     for (int i = 0; i < nbRows; ++i) {
@@ -826,7 +827,7 @@ void SKGTreeView::onCollapse(const QModelIndex& index)
 void SKGTreeView::onClick(const QModelIndex& index)
 {
     SKGTRACEIN(10, "SKGTreeView::onClick");
-    if (index.isValid()) {
+    if (index.isValid() && m_actExpandAll && m_actExpandAll->isVisible()) {
         this->setExpanded(index, !this->isExpanded(index));
     }
 }
@@ -871,13 +872,13 @@ void SKGTreeView::setZoomPosition(int iZoomPosition)
 {
     int newZoomPos = qMax(qMin(iZoomPosition, 10), -10);
     if (newZoomPos != zoomPosition() && m_fontOriginalPointSize + newZoomPos > 1) {
-        QFont font = this->font();
-        font.setPointSize(m_fontOriginalPointSize + newZoomPos);
-        int iconSize = qMax(m_iconOriginalSize + newZoomPos, 1);
+        QFont newFont = this->font();
+        newFont.setPointSize(m_fontOriginalPointSize + newZoomPos);
+        int newIconSize = qMax(m_iconOriginalSize + newZoomPos, 1);
 
-        this->setFont(font);
-        this->setIconSize(QSize(iconSize, iconSize));
-        header()->setIconSize(QSize(iconSize, iconSize));
+        this->setFont(newFont);
+        this->setIconSize(QSize(newIconSize, newIconSize));
+        header()->setIconSize(QSize(newIconSize, newIconSize));
 
         if (m_autoResize) resizeColumnsToContentsDelayed();
 
@@ -890,43 +891,39 @@ int SKGTreeView::zoomPosition()
     return this->font().pointSize() - m_fontOriginalPointSize;
 }
 
-/**
- * Event filter
- * @param object object
- * @param event event
- * @return traited or not
- */
-bool SKGTreeView::eventFilter(QObject* object, QEvent* event)
+bool SKGTreeView::eventFilter(QObject* object, QEvent* iEvent)
 {
-    QWheelEvent* e = dynamic_cast<QWheelEvent*>(event);
-    if (m_textResizable && e && e->orientation() == Qt::Vertical && QApplication::keyboardModifiers() &Qt::ControlModifier) {
-        int numDegrees = e->delta() / 8;
-        int numTicks = numDegrees / 15;
+    if (object == this && iEvent != NULL && iEvent->type() == QEvent::Wheel) {
+        QWheelEvent* e = static_cast<QWheelEvent*>(iEvent);
+        if (m_textResizable && e && e->orientation() == Qt::Vertical && QApplication::keyboardModifiers() &Qt::ControlModifier) {
+            int numDegrees = e->delta() / 8;
+            int numTicks = numDegrees / 15;
 
-        setZoomPosition(zoomPosition() + (numTicks > 0 ? 1 : -1));
-        e->setAccepted(true);
-        return true;
+            setZoomPosition(zoomPosition() + (numTicks > 0 ? 1 : -1));
+            e->setAccepted(true);
+            return true;
+        }
     }
-    if (object == this) {
-        QKeyEvent* kevent = dynamic_cast<QKeyEvent*>(event);
+    if (object == this && iEvent != NULL && iEvent->type() == QEvent::KeyPress) {
+        QKeyEvent* kevent = static_cast<QKeyEvent*>(iEvent);
         if (kevent) {
             if (kevent->matches(QKeySequence::Copy) && this->state() != QAbstractItemView::EditingState) {
                 copy();
-                if (event) event->accept();
-                return true; //stop the process
+                if (iEvent) iEvent->accept();
+                return true;  // stop the process
             }
         }
     }
-    return QTreeView::eventFilter(object, event);
+    return QTreeView::eventFilter(object, iEvent);
 }
 
-void SKGTreeView::mousePressEvent(QMouseEvent* event)
+void SKGTreeView::mousePressEvent(QMouseEvent* iEvent)
 {
-    if (event && event->button() == Qt::LeftButton && !(this->indexAt(event->pos()).isValid())) {
+    if (iEvent && iEvent->button() == Qt::LeftButton && !(this->indexAt(iEvent->pos()).isValid())) {
         Q_EMIT clickEmptyArea();
         clearSelection();
     }
-    QTreeView::mousePressEvent(event);
+    QTreeView::mousePressEvent(iEvent);
 }
 
 bool SKGTreeView::isTextResizable() const
@@ -941,10 +938,10 @@ void SKGTreeView::setTextResizable(bool resizable)
 
 SKGStringListList SKGTreeView::getTable() const
 {
-    //Build table
+    // Build table
     SKGStringListList table;
 
-    //Get header names
+    // Get header names
     if (m_model) {
         int nb = m_model->columnCount();
         QStringList cols;
@@ -953,7 +950,7 @@ SKGStringListList SKGTreeView::getTable() const
         }
         table.append(cols);
 
-        //Get content
+        // Get content
         table.append(getTableContent());
     }
     return table;
@@ -961,7 +958,7 @@ SKGStringListList SKGTreeView::getTable() const
 
 SKGStringListList SKGTreeView::getTableContent(const QModelIndex& iIndex) const
 {
-    //Build table
+    // Build table
     SKGStringListList table;
 
     int nb = m_model->columnCount();
@@ -969,7 +966,7 @@ SKGStringListList SKGTreeView::getTableContent(const QModelIndex& iIndex) const
     for (int i = 0; i < nb2; ++i) {
         QStringList row;
         for (int j = 0; j < nb; j++) {
-            //We have to check the type for 214849
+            // We have to check the type for 214849
             QModelIndex idx = m_model->index(i, j, iIndex);
 
             SKGServices::AttributeType type = m_model->getAttributeType(j);
@@ -997,7 +994,7 @@ SKGError SKGTreeView::exportInFile(const QString& iFileName)
     QString lastCodecUsed = QTextCodec::codecForLocale()->name();
     QString extension = QFileInfo(iFileName).suffix().toUpper();
     if (extension == "CSV") {
-        //Write file
+        // Write file
         KSaveFile file(iFileName);
         if (!file.open()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed" , iFileName));
         else {
@@ -1010,7 +1007,7 @@ SKGError SKGTreeView::exportInFile(const QString& iFileName)
             }
         }
 
-        //Close file
+        // Close file
         file.finalize();
         file.close();
     } else if (extension == "PDF") {
@@ -1022,15 +1019,15 @@ SKGError SKGTreeView::exportInFile(const QString& iFileName)
         {
             QPrinter printer(QPrinter::HighResolution);
             printer.setOutputFileName(iFileName);
-            QPainter painter(&printer);
+            QPainter newPainter(&printer);
 
-            QRect rect = painter.viewport();
-            QSize size = image.size();
-            size.scale(rect.size(), Qt::KeepAspectRatio);
-            painter.setViewport(rect.x(), rect.y(), size.width(), size.height());
-            painter.setWindow(image.rect());
-            painter.drawImage(0, 0, image);
-            painter.end();
+            QRect painterRect = newPainter.viewport();
+            QSize imageSize = image.size();
+            imageSize.scale(painterRect.size(), Qt::KeepAspectRatio);
+            newPainter.setViewport(painterRect.x(), painterRect.y(), imageSize.width(), imageSize.height());
+            newPainter.setWindow(image.rect());
+            newPainter.drawImage(0, 0, image);
+            newPainter.end();
         }
     } else if (extension == "SVG") {
         QSvgGenerator generator;
@@ -1046,7 +1043,7 @@ SKGError SKGTreeView::exportInFile(const QString& iFileName)
 
         painter.end();
     } else {
-        //Write file
+        // Write file
         KSaveFile file(iFileName);
         if (!file.open()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed" , iFileName));
         else {
@@ -1059,7 +1056,7 @@ SKGError SKGTreeView::exportInFile(const QString& iFileName)
             }
         }
 
-        //Close file
+        // Close file
         file.finalize();
         file.close();
     }
@@ -1074,7 +1071,6 @@ void SKGTreeView::onExport()
     QString lastCodecUsed = QTextCodec::codecForLocale()->name();
     QString fileName = SKGMainPanel::getSaveFileName("kfiledialog:///IMPEXP", "text/csv text/plain image/svg+xml application/pdf" , this, QString(), &lastCodecUsed);
     if (!fileName.isEmpty()) {
-
         SKGError err = exportInFile(fileName);
         SKGMainPanel::displayErrorMessage(err);
         QDesktopServices::openUrl(QUrl(fileName));
@@ -1084,9 +1080,9 @@ void SKGTreeView::onExport()
 void SKGTreeView::setModel(QAbstractItemModel* iModel)
 {
     if (iModel != this->model()) {
-        m_model = qobject_cast<SKGObjectModelBase*> (iModel);
+        m_model = static_cast<SKGObjectModelBase*>(iModel);
         m_proxyModel = qobject_cast<QSortFilterProxyModel*> (iModel);
-        if (m_proxyModel) m_model = qobject_cast<SKGObjectModelBase*>(m_proxyModel->sourceModel());
+        if (m_proxyModel) m_model = static_cast<SKGObjectModelBase*>(m_proxyModel->sourceModel());
 
         if (m_model) {
             connect(m_model, SIGNAL(afterReset()), this, SLOT(setupHeaderMenu()));
