@@ -20,8 +20,6 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgwebview.h"
-#include "skgtraces.h"
-#include "skgmainpanel.h"
 
 #include <QPrinter>
 #include <QPrintDialog>
@@ -38,14 +36,17 @@
 #include <QFileInfo>
 #include <qmath.h>
 
-#include <kmenu.h>
-#include <kicon.h>
-#include <kstandardaction.h>
-#include <klocale.h>
-#include <ksavefile.h>
+#include <KMenu>
+#include <KIcon>
+#include <KStandardAction>
+#include <KLocale>
+#include <KSaveFile>
 
 #include "math.h"
 
+#include "skgtraces.h"
+#include "skgmainpanel.h"
+
 SKGWebView::SKGWebView(QWidget* iParent, const char* name)
     : QWebView(iParent)
 {
@@ -80,9 +81,9 @@ void SKGWebView::setState(const QString& iState)
     emit zoomChanged(z);
 }
 
-void SKGWebView::contextMenuEvent(QContextMenuEvent* event)
+void SKGWebView::contextMenuEvent(QContextMenuEvent* iEvent)
 {
-    if (event) {
+    if (iEvent) {
         KMenu* menu = new KMenu(this);
 
         menu->addAction(pageAction(QWebPage::Copy));
@@ -95,31 +96,33 @@ void SKGWebView::contextMenuEvent(QContextMenuEvent* event)
         QAction* actExport = menu->addAction(KIcon("document-export"), i18nc("Noun, user action", "Export..."));
         connect(actExport, SIGNAL(triggered(bool)), this, SLOT(onExport()));
 
-        menu->popup(this->mapToGlobal(event->pos()));
+        menu->popup(this->mapToGlobal(iEvent->pos()));
 
-        event->accept();
+        iEvent->accept();
     }
 }
 
-bool SKGWebView::eventFilter(QObject* object, QEvent* event)
+bool SKGWebView::eventFilter(QObject* iObject, QEvent* iEvent)
 {
     SKGTRACEIN(10, "SKGWebView::eventFilter");
-    QWheelEvent* e = dynamic_cast<QWheelEvent*>(event);
-    if (e) {
-        if (e->orientation() == Qt::Vertical && QApplication::keyboardModifiers() &Qt::ControlModifier) {
-            int numDegrees = e->delta() / 8;
-            int numTicks = numDegrees / 15;
+    if (iEvent && iEvent->type() == QEvent::Wheel) {
+        QWheelEvent* e = static_cast<QWheelEvent*>(iEvent);
+        if (e) {
+            if (e->orientation() == Qt::Vertical && QApplication::keyboardModifiers() &Qt::ControlModifier) {
+                int numDegrees = e->delta() / 8;
+                int numTicks = numDegrees / 15;
 
-            if (numTicks > 0) {
-                onZoomIn();
-            } else {
-                onZoomOut();
+                if (numTicks > 0) {
+                    onZoomIn();
+                } else {
+                    onZoomOut();
+                }
+                e->setAccepted(true);
+                return true;
             }
-            e->setAccepted(true);
-            return true;
         }
     }
-    return QWidget::eventFilter(object, event);
+    return QWidget::eventFilter(iObject, iEvent);
 }
 
 void SKGWebView::onZoomIn()
@@ -170,7 +173,7 @@ void SKGWebView::exportInFile(const QString& iFileName)
             out << page()->mainFrame()->toHtml();
         }
 
-        //Close file
+        // Close file
         file.finalize();
         file.close();
     } else {
