@@ -21,10 +21,8 @@
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
-
-#include "skgbasegui_export.h"
-
 #include <QWebView>
+#include "skgbasegui_export.h"
 
 class QPrinter;
 
@@ -36,7 +34,6 @@ class SKGBASEGUI_EXPORT SKGWebView : public QWebView
     Q_OBJECT
 
 public:
-
     /**
      * Constructor
      * @param iParent the parent
@@ -110,17 +107,17 @@ public Q_SLOTS:
 protected:
     /**
      * Contextual event
-     * @param event the event
+     * @param iEvent the event
      */
-    virtual void contextMenuEvent(QContextMenuEvent* event);
+    virtual void contextMenuEvent(QContextMenuEvent* iEvent);
 
     /**
      * Event filtering
-     * @param object object
-     * @param event event
+     * @param iObject object
+     * @param iEvent event
      * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
      */
-    virtual bool eventFilter(QObject* object, QEvent* event);
+    virtual bool eventFilter(QObject* iObject, QEvent* iEvent);
 
 private:
     Q_DISABLE_COPY(SKGWebView)
