@@ -20,11 +20,12 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgwidget.h"
-#include "skgtreeview.h"
-#include "skgtraces.h"
 
 #include <QtGui/QWidget>
 
+#include "skgtreeview.h"
+#include "skgtraces.h"
+
 SKGWidget::SKGWidget(SKGDocument* iDocument)
     : QWidget(), m_document(iDocument)
 {
@@ -79,7 +80,9 @@ int SKGWidget::getNbSelectedObjects()
     int output = 0;
     SKGTreeView* treeView = qobject_cast<SKGTreeView*>(mainWidget());
     if (treeView) output = treeView->getNbSelectedObjects();
-    else output = getSelectedObjects().count();
+    else {
+        output = getSelectedObjects().count();
+    }
 
     return output;
 }
