@@ -22,12 +22,13 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include <QString>
-#include <qstringbuilder.h>
-#include "skgbasemodeler_export.h"
+#include <QStringBuilder>
 
 #ifdef KDE4_FOUND
-#include <kglobal.h>
+#include <KGlobal>
 #endif
+
+#include "skgbasemodeler_export.h"
 /**
  * @var OBJECTSEPARATOR
  * Define the separator between object and subobject
