@@ -21,16 +21,16 @@
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
-#include "skgservices.h"
-#include "skgobjectbase.h"
-#include "skgbasemodeler_export.h"
-
 #include <QStringList>
 #include <QDateTime>
 #include <QHash>
 #include <QVariant>
 #include <QIcon>
 
+#include "skgservices.h"
+#include "skgobjectbase.h"
+#include "skgbasemodeler_export.h"
+
 class QSqlDatabase;
 class SKGObjectBase;
 class SKGError;
@@ -115,7 +115,7 @@ public:
         int id;                 /**< The id of the object */
         QString table;              /**< The table of the object */
         ModificationType type;          /**< The type of modification */
-    } ;
+    };
 
     /**
      * This structure represents a template to display data
@@ -206,8 +206,7 @@ public Q_SLOTS:
     virtual SKGError beginTransaction(const QString& iName,
                                       int iNbStep = 0,
                                       const QDateTime& iDate = QDateTime::currentDateTime(),
-                                      bool iRefreshViews = true
-                                     );
+                                      bool iRefreshViews = true);
 
     /**
      * Close the current transaction.
