@@ -38,9 +38,9 @@ SKGError SKGDocument::refreshViewsIndexesAndTriggers()
     DELETECASCADEPARAMETER("parameters")
     DELETECASCADEPARAMETER("node")
 
-    //Compute fullname
+    // Compute fullname
             << "DROP TRIGGER IF EXISTS cpt_node_fullname3"
-            /*<< "CREATE TRIGGER cpt_node_fullname1 " //This trigger must be the first
+            /*<< "CREATE TRIGGER cpt_node_fullname1 " // This trigger must be the first
             "AFTER UPDATE OF t_fullname ON node BEGIN "
             "UPDATE node SET t_name=t_name WHERE rd_node_id=new.id;"
             "END"*/
@@ -62,8 +62,7 @@ SKGError SKGDocument::refreshViewsIndexesAndTriggers()
             "UPDATE node SET t_name=t_name WHERE " % rd_node_id % "=new.id;"
             "END"
 
-            << "DROP TRIGGER IF EXISTS fkdc_node_parent_id_node_id"
-            ;
+            << "DROP TRIGGER IF EXISTS fkdc_node_parent_id_node_id";
 
     /**
     * This constant is used to initialized the data model (index creation)
@@ -79,8 +78,7 @@ SKGError SKGDocument::refreshViewsIndexesAndTriggers()
                           << "CREATE INDEX idx_doctransactionitem_t_object_table ON doctransactionitem (t_object_table)"
                           << "CREATE INDEX idx_doctransactionitem_t_action ON doctransactionitem (t_action)"
                           << "CREATE INDEX idx_doctransactionitem_rd_doctransaction_id ON doctransactionitem (rd_doctransaction_id)"
-                          << "CREATE INDEX idx_doctransactionitem_optimization ON doctransactionitem (rd_doctransaction_id, i_object_id, t_object_table, t_action, t_sqlorder, id)"
-                          ;
+                          << "CREATE INDEX idx_doctransactionitem_optimization ON doctransactionitem (rd_doctransaction_id, i_object_id, t_object_table, t_action, t_sqlorder, id)";
 
     /**
     * This constant is used to initialized the data model (view creation)
@@ -88,52 +86,49 @@ SKGError SKGDocument::refreshViewsIndexesAndTriggers()
     QStringList InitialDataModelView;
     InitialDataModelView << "CREATE VIEW  v_node AS SELECT * from node"
                          << "CREATE VIEW v_node_displayname AS SELECT *, t_fullname AS t_displayname from node"
-                         << "CREATE VIEW v_parameters_displayname AS SELECT *, t_name AS t_displayname from parameters"
-                         ;
+                         << "CREATE VIEW v_parameters_displayname AS SELECT *, t_name AS t_displayname from parameters";
 
-    QStringList tables;
-    tables << "node" << "parameters" << "doctransactionitem" << "doctransaction";
-    IFOKDO(err, dropViewsAndIndexes(tables))
+    IFOKDO(err, dropViewsAndIndexes(QStringList() << "node" << "parameters" << "doctransactionitem" << "doctransaction"))
     IFOKDO(err, executeSqliteOrders(InitialDataModelIndex))
     IFOKDO(err, executeSqliteOrders(InitialDataModelView))
     IFOKDO(err, executeSqliteOrders(InitialDataModelTrigger))
     IFOK(err) {
-        //Refresh dynamic triggers
+        // Refresh dynamic triggers
         QRegExp rx_rd("rd_([^_]+)_([^_]+).*");
         QRegExp rx_rc("rc_([^_]+)_([^_]+).*");
         QRegExp rx_r("r_([^_]+)_([^_]+).*");
-        QStringList tables;
-        err = this->getDistinctValues("sqlite_master", "name", "type='table'", tables);
-        int nb = tables.count();
+        QStringList dbTables;
+        err = this->getDistinctValues("sqlite_master", "name", "type='table'", dbTables);
+        int nb = dbTables.count();
         for (int i = 0; !err && i < nb; ++i) {
-            QString table = tables[i];
+            QString table = dbTables[i];
             SKGStringListList attributes;
             err = executeSelectSqliteOrder("PRAGMA table_info(" % table % ");", attributes);
             int nb2 = attributes.count();
-            for (int j = 1; !err && j < nb2; ++j) { //Header is ignored
+            for (int j = 1; !err && j < nb2; ++j) {  // Header is ignored
                 QString att = attributes.at(j).at(1);
                 if (rx_rd.indexIn(att) != -1) {
-                    //Get parameters
+                    // Get parameters
                     QString tab2 = rx_rd.cap(1);
                     QString att2 = rx_rd.cap(2);
                     QStringList sqlOrders;
                     sqlOrders FOREIGNCONSTRAINTCASCADE(tab2, att2, table, att);
                     err = executeSqliteOrders(sqlOrders);
                 } else if (rx_rc.indexIn(att) != -1) {
-                    //Get parameters
+                    // Get parameters
                     QString tab2 = rx_rc.cap(1);
                     QString att2 = rx_rc.cap(2);
                     QStringList sqlOrders;
                     sqlOrders FOREIGNCONSTRAINT(tab2, att2, table, att);
                     err = executeSqliteOrders(sqlOrders);
                 } else if (rx_r.indexIn(att) != -1) {
-                    //Get parameters
+                    // Get parameters
                     QString tab2 = rx_r.cap(1);
                     QString att2 = rx_r.cap(2);
                     QStringList sqlOrders;
                     sqlOrders FOREIGNCONSTRAINTUPDATE(tab2, att2, table, att);
                     err = executeSqliteOrders(sqlOrders);
-                    //The following sql order error is not caught because this repair order is not mandatory
+                    // The following sql order error is not caught because this repair order is not mandatory
                     executeSqliteOrder("UPDATE " % table % " SET " % att % "=0 WHERE " % att % "!=0 AND " % att % " NOT IN (SELECT DISTINCT(" % att2 % ") FROM " % tab2 % ')');
                 }
             }
