@@ -20,14 +20,12 @@
 * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgservices.h"
-#include "skgtraces.h"
-#include "skgdocument.h"
 
-#include <klocale.h>
-#include <kglobal.h>
-#include <ksavefile.h>
-#include <kio/netaccess.h>
-#include <kio/job.h>
+#include <KLocale>
+#include <KGlobal>
+#include <KSaveFile>
+#include <KIO/NetAccess>
+#include <KIO/Job>
 
 #include <sys/time.h>
 
@@ -44,7 +42,10 @@
 #include <QDomDocument>
 #include <QScriptEngine>
 
-int SKGServices::SKGSqlTraces = (SKGServices::getenv("SKGTRACESQL").isEmpty() ? -1 : SKGServices::stringToInt(SKGServices::getenv("SKGTRACESQL")));
+#include "skgtraces.h"
+#include "skgdocument.h"
+
+int SKGServices::SKGSqlTraces = (SKGServices::getEnvVariable("SKGTRACESQL").isEmpty() ? -1 : SKGServices::stringToInt(SKGServices::getEnvVariable("SKGTRACESQL")));
 
 SKGError SKGServices::m_lastCallbackError;
 
@@ -87,7 +88,7 @@ QList< SKGServices::SKGSearchCriteria > SKGServices::stringToSearchCriterias(con
     }
 
     if (!atLeastOnePlus) {
-        //Add a '+' always true
+        // Add a '+' always true
         SKGServices::SKGSearchCriteria criteria2;
         criteria2.mode = '+';
         criteria2.words.push_back("");
@@ -97,7 +98,7 @@ QList< SKGServices::SKGSearchCriteria > SKGServices::stringToSearchCriterias(con
     return output;
 }
 
-QString SKGServices::getenv(const QString& iAttribute)
+QString SKGServices::getEnvVariable(const QString& iAttribute)
 {
     return QString::fromUtf8(qgetenv(iAttribute.toUtf8().constData()));
 }
@@ -132,7 +133,7 @@ QString SKGServices::stringToSqlString(const QString& iString)
 QString SKGServices::stringToHtml(const QString& iString)
 {
     QString output = iString;
-    output.replace('&', "&amp;"); //Must be done first
+    output.replace('&', "&amp;");  // Must be done first
     output.replace('<', "&lt;");
     output.replace('>', "&gt;");
     output.replace('"', "&quot;");
@@ -156,7 +157,7 @@ QString SKGServices::stringsToCsv(const QStringList& iList, const QChar& iSepara
     QString output;
     int nb = iList.count();
     for (int i = 0; i < nb; ++i) {
-        output.append(SKGServices::stringToCsv(iList[i]));
+        output.append(SKGServices::stringToCsv(iList.at(i)));
         if (Q_LIKELY(i < nb - 1)) output.append(iSeparator);
     }
 
@@ -175,12 +176,15 @@ QString SKGServices::stringToCsv(const QString& iNumber)
 double SKGServices::stringToDouble(const QString& iNumber)
 {
     if (Q_UNLIKELY(iNumber.isEmpty() || iNumber == "nan")) return 0;
-    else if (Q_UNLIKELY(iNumber == "inf")) return 1e300;
-    else if (Q_UNLIKELY(iNumber == "-inf")) return -1e300;
+    else if (Q_UNLIKELY(iNumber == "inf")) {
+        return 1e300;
+    } else if (Q_UNLIKELY(iNumber == "-inf")) {
+        return -1e300;
+    }
     QString number = iNumber;
     number.remove(QRegExp("[^0-9-+/eE,.]"));
     if (number.contains("/")) {
-        //Use script engine
+        // Use script engine
         QScriptEngine myEngine;
         QScriptValue result = myEngine.evaluate(number);
         if (result.isNumber()) return result.toNumber();
@@ -263,7 +267,7 @@ QStringList SKGServices::splitCSVLine(const QString& iString, const QChar& iSepa
     bool isInBlock = false;
     QChar realSeparator = iSeparator;
 
-    QChar cote = ' '; //Not yet defined
+    QChar cote = ' ';  // Not yet defined
     int nb = iString.length();
     for (int pos = 0; pos < nb; ++pos) {
         QChar c = iString.at(pos);
@@ -274,28 +278,28 @@ QStringList SKGServices::splitCSVLine(const QString& iString, const QChar& iSepa
                     items.push_back(item);
                     item = "";
                     isInBlock = false;
-                    //320112 vvvv
-                    //Reset the block character to autorize mix
+                    // 320112 vvvv
+                    // Reset the block character to autorize mix
                     cote = ' ';
-                    //320112 ^^^^
+                    // 320112 ^^^^
 
-                    ++pos; //To ignore next separator
-                    if (pos < nb) realSeparator = iString.at(pos); //To get the real separator
+                    ++pos;  // To ignore next separator
+                    if (pos < nb) realSeparator = iString.at(pos);  // To get the real separator
                 }
             }
 
             if (isInBlock) item += c;
         } else  if ((c == '\"' || c == '\'') && item.count() == 0 &&  iCoteDefineBlock) {
-            if (cote == ' ') cote = c; //Set the real cote char
+            if (cote == ' ') cote = c;  // Set the real cote char
             isInBlock = true;
         } else  if (QString(c) == realSeparator) {
             items.push_back(item);
             item = "";
             isInBlock = false;
-            //320112 vvvv
-            //Reset the block character to autorize mix
+            // 320112 vvvv
+            // Reset the block character to autorize mix
             cote = ' ';
-            //320112 ^^^^
+            // 320112 ^^^^
         } else {
             item += c;
         }
@@ -322,13 +326,12 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
     bool f_MM_DD_YYYY = true;
     bool f_DD_MM_YYYY = true;
 
-    //Build regexp
+    // Build regexp
     QRegExp rx("(.+)-(.+)-(.+)");
 
-    //Check all dates
+    // Check all dates
     int nb = iDates.count();
     for (int i = 0; i < nb; ++i) {
-
         QString val = iDates.at(i).trimmed();
         if (!val.isEmpty()) {
             val = val.replace(' ', '0');
@@ -418,7 +421,7 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
                     f_MM_DD_YYYY = false;
                     f_DD_MM_YYYY = false;
                 } else {
-                    //To be more permissive and support mix of date: f_YYYY_MM_DD = false;
+                    // To be more permissive and support mix of date: f_YYYY_MM_DD = false;
                 }
 
                 if (v3.length() == 4) {
@@ -426,35 +429,43 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
                     f_MM_DD_YY = false;
                     f_DD_MM_YY = false;
                 } else {
-                    //To be more permissive and support mix of date: f_MM_DD_YYYY = false;
-                    //To be more permissive and support mix of date: f_DD_MM_YYYY = false;
+                    // To be more permissive and support mix of date: f_MM_DD_YYYY = false;
+                    // To be more permissive and support mix of date: f_DD_MM_YYYY = false;
                 }
             }
         }
     }
 
     if (f_YYYYMMDD) return "YYYYMMDD";
-    else if (f_MMDDYYYY) return "MMDDYYYY";
-    else if (f_DDMMYYYY) return "DDMMYYYY";
-    else if (f_DD_MM_YY && f_MM_DD_YY) {
+    else if (f_MMDDYYYY) {
+        return "MMDDYYYY";
+    } else if (f_DDMMYYYY) {
+        return "DDMMYYYY";
+    } else if (f_DD_MM_YY && f_MM_DD_YY) {
         KLocale* loc = KGlobal::locale();
         if (loc) {
             QString sFormat = loc->dateFormatShort();
             if (sFormat.startsWith(QLatin1String("%m")) || sFormat.startsWith(QLatin1String("%n"))) return "MM-DD-YY";
         }
         return "DD-MM-YY";
-    } else if (f_MM_DD_YY) return "MM-DD-YY";
-    else if (f_DD_MM_YY) return "DD-MM-YY";
-    else if (f_DD_MM_YYYY && f_MM_DD_YYYY) {
+    } else if (f_MM_DD_YY) {
+        return "MM-DD-YY";
+    } else if (f_DD_MM_YY) {
+        return "DD-MM-YY";
+    } else if (f_DD_MM_YYYY && f_MM_DD_YYYY) {
         KLocale* loc = KGlobal::locale();
         if (loc) {
             QString sFormat = loc->dateFormatShort();
             if (sFormat.startsWith(QLatin1String("%m")) || sFormat.startsWith(QLatin1String("%n"))) return "MM-DD-YYYY";
         }
         return "DD-MM-YYYY";
-    } else if (f_MM_DD_YYYY) return "MM-DD-YYYY";
-    else if (f_DD_MM_YYYY) return "DD-MM-YYYY";
-    else if (f_YYYY_MM_DD) return "YYYY-MM-DD";
+    } else if (f_MM_DD_YYYY) {
+        return "MM-DD-YYYY";
+    } else if (f_DD_MM_YYYY) {
+        return "DD-MM-YYYY";
+    } else if (f_YYYY_MM_DD) {
+        return "YYYY-MM-DD";
+    }
 
     return "";
 }
@@ -470,13 +481,11 @@ QString SKGServices::dateToSqlString(const QString& iDate, const QString& iForma
         YYYY = input.mid(0, 4);
         MM = input.mid(4, 2);
         DD = input.mid(6, 2);
-
     }
     if (iFormat == "DDMMYYYY" || iFormat == "DDMMYY") {
         YYYY = input.mid(4, 4);
         MM = input.mid(2, 2);
         DD = input.mid(0, 2);
-
     }
     if (iFormat == "MMDDYYYY" || iFormat == "MMDDYY") {
         YYYY = input.mid(4, 4);
@@ -528,7 +537,9 @@ QString SKGServices::dateToSqlString(const QString& iDate, const QString& iForma
     if (YYYY.length() == 1) YYYY = '0' % YYYY;
     if (YYYY.length() == 2) {
         if (stringToInt(YYYY) > 70) YYYY = "19" % YYYY;
-        else YYYY = "20" % YYYY;
+        else {
+            YYYY = "20" % YYYY;
+        }
     }
 
     QString date = YYYY % '-' % MM % '-' % DD;
@@ -539,10 +550,10 @@ QString SKGServices::dateToSqlString(const QString& iDate, const QString& iForma
 QStringList SKGServices::tableToDump(const SKGStringListList& iTable, SKGServices::DumpMode iMode)
 {
     SKGTRACEIN(10, "SKGServices::tableToDump");
-    //initialisation
+    // initialisation
     QStringList oResult;
 
-    //Compute max size of each column
+    // Compute max size of each column
     int* maxSizes = NULL;
     if (iMode == DUMP_TEXT) {
         int nb = iTable.count();
@@ -567,7 +578,7 @@ QStringList SKGServices::tableToDump(const SKGStringListList& iTable, SKGService
         }
     }
 
-    //dump
+    // dump
     int nb = iTable.count();
     for (int i = 0; i < nb; ++i) {
         QString lineFormated;
@@ -592,7 +603,7 @@ QStringList SKGServices::tableToDump(const SKGStringListList& iTable, SKGService
         oResult.push_back(lineFormated);
     }
 
-    //delete
+    // delete
     if (maxSizes) {
         delete [] maxSizes;
         maxSizes = NULL;
@@ -621,13 +632,13 @@ SKGError SKGServices::downloadToStream(const KUrl& iSourceUrl, QByteArray& oStre
     QString tmpFile;
     err = download(iSourceUrl, tmpFile);
     IFOK(err) {
-        //Open file
+        // Open file
         QFile file(tmpFile);
         if (Q_UNLIKELY(!file.open(QIODevice::ReadOnly))) err.setReturnCode(ERR_FAIL).setMessage(i18nc("An information message", "Open file '%1' failed", tmpFile));
         else {
             oStream = file.readAll();
 
-            //close file
+            // close file
             file.close();
         }
         QFile(tmpFile).remove();
@@ -654,7 +665,7 @@ SKGError SKGServices::upload(const KUrl& iSourceUrl, const KUrl& iDescUrl)
     SKGTRACEINRC(10, "SKGServices::upload", err);
     if (iDescUrl != iSourceUrl) {
         KIO::Job* getJob = KIO::file_copy(iSourceUrl, iDescUrl, -1, KIO::Overwrite | KIO::HideProgressInfo);
-        //getJob->ui()->setWindow(window);
+        // getJob->ui()->setWindow(window);
         if (!KIO::NetAccess::synchronousRun(getJob, 0)) err.setReturnCode(ERR_ABORT).setMessage(getJob->errorString());
     }
     return err;
@@ -666,12 +677,13 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
     SKGTRACEINRC(10, "SKGServices::cryptFile", err);
     SKGTRACEL(10) << "Input parameter [iFileSource]=[" << iFileSource << ']' << endl;
     SKGTRACEL(10) << "Input parameter [iFileTarget]=[" << iFileTarget << ']' << endl;
+    SKGTRACEL(10) << "Input parameter [iPassword]  =[" << iPassword << ']' << endl;
     SKGTRACEL(10) << "Input parameter [iHeaderFile]=[" << iHeaderFile << ']' << endl;
 
     QCA::Initializer init;
     if (!iPassword.isEmpty() && !QCA::isSupported("aes128-ecb")) {
-        //Set error message
-        err.setReturnCode(ERR_INSTALL); //To avoid password request
+        // Set error message
+        err.setReturnCode(ERR_INSTALL);  // To avoid password request
         err.setMessage(i18nc("An error message about encryption", "AES128 encryption is not supported. Please install qca-ossl."));
     } else {
         // Create a random key - you'd probably use one from another
@@ -682,24 +694,33 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
         // value to decrypt the resulting cipher text, but it
         // need not be kept secret (unlike the key).
         QCA::InitializationVector iv(iPassword.toAscii());
-
-        // create a 128 bit AES cipher object using Cipher Block Chaining (CBC) mode
         QCA::Cipher* cipher = NULL;
-        if (!iPassword.isEmpty()) cipher = new QCA::Cipher("aes128", QCA::Cipher::CBC,
-                    // use Default padding, which is equivalent to PKCS7 for CBC
-                    QCA::Cipher::DefaultPadding,
-                    iEncrypt ? QCA::Encode : QCA::Decode,
-                    key, iv);
 
+        // Read document
         QByteArray input;
         err = downloadToStream(KUrl(iFileSource), input);
         IFOK(err) {
-            //Read document
+            bool isFileEncrypted = (input.startsWith(QByteArray((iHeaderFile % "_ENCRYPTED-").toLatin1())));
+            SKGTRACEL(10) << "isFileEncrypted=[" << static_cast<unsigned int>(isFileEncrypted) << ']' << endl;
+            QCA::InitializationVector iv(iPassword.toAscii());
+
+            // Create a 128 bit AES cipher object using Cipher Block Chaining (CBC) mode
+            if ((isFileEncrypted || iEncrypt) && !iPassword.isEmpty()) cipher = new QCA::Cipher("aes128", QCA::Cipher::CBC,
+                        // use Default padding, which is equivalent to PKCS7 for CBC
+                        QCA::Cipher::DefaultPadding,
+                        iEncrypt ? QCA::Encode : QCA::Decode,
+                        key, iv);
+
+
             QByteArray h = (iHeaderFile % (!cipher ? "_DECRYPTED-" : "_ENCRYPTED-")).toLatin1();
-            //BUG 249955 vvv
-            if (!cipher && input.startsWith(QByteArray((iHeaderFile % "_ENCRYPTED-").toLatin1()))) err = SKGError(ERR_UNEXPECTED, i18nc("Error message about encrypting a file", "Encryption failed"));
-            //BUG 249955 ^^^
-            if (!iEncrypt && h.count() && input.startsWith(h)) input = input.right(input.length() - h.length());
+            // BUG 249955 vvv
+            if (!cipher && isFileEncrypted) {
+                err = SKGError(ERR_ENCRYPTION, i18nc("Error message about encrypting a file", "Encryption failed"));
+            }
+            // BUG 249955 ^^^
+            if (!iEncrypt && h.count() && input.startsWith(h)) {
+                input = input.right(input.length() - h.length());
+            }
 
             // we use the cipher object to encrypt the argument we passed in
             // the result of that is returned - note that if there is less than
@@ -710,20 +731,26 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
                 u = cipher->update(input);
 
                 // We need to check if that update() call worked.
-                if (!cipher->ok()) err = SKGError(ERR_UNEXPECTED, i18nc("Error message about encrypting a file", "Encryption failed"));
+                if (!cipher->ok()) {
+                    err = SKGError(ERR_UNEXPECTED, i18nc("Error message about encrypting a file", "Encryption failed"));
+                }
             }
 
             // output the results of that stage
             IFOK(err) {
                 KSaveFile fileOutput(iFileTarget);
-                if (!fileOutput.open()) err = SKGError(ERR_WRITEACCESS, i18nc("Error message: writing a file failed", "Write file '%1' failed", iFileTarget));
-                else {
-                    //Write header
-                    if (iEncrypt && h.count()) fileOutput.write(h);
+                if (!fileOutput.open()) {
+                    err = SKGError(ERR_WRITEACCESS, i18nc("Error message: writing a file failed", "Write file '%1' failed", iFileTarget));
+                } else {
+                    // Write header
+                    if (iEncrypt && h.count()) {
+                        fileOutput.write(h);
+                    }
 
-                    //Write document
-                    if (!cipher) fileOutput.write(input);
-                    else {
+                    // Write document
+                    if (!cipher) {
+                        fileOutput.write(input);
+                    } else {
                         fileOutput.write(u.toByteArray());
 
                         // Because we are using PKCS7 padding, we need to output the final (padded) block
@@ -731,14 +758,16 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
                         QCA::SecureArray f = cipher->final();
 
                         // Check if the final() call worked
-                        if (!cipher->ok()) err = SKGError(ERR_UNEXPECTED, i18nc("Error message about encrypting a file", "Encryption failed"));
+                        if (!cipher->ok()) {
+                            err = SKGError(ERR_UNEXPECTED, i18nc("Error message about encrypting a file", "Encryption failed"));
+                        }
 
                         // and output the resulting block. The ciphertext is the results of update()
                         // and the result of final()
                         fileOutput.write(f.toByteArray());
                     }
 
-                    //Close the file
+                    // Close the file
                     fileOutput.finalize();
                     fileOutput.close();
                 }
@@ -775,7 +804,7 @@ SKGError SKGServices::copySqliteDatabaseToXml(QSqlDatabase* iDb, QDomDocument& o
                 int nbRows = listRows.count();
                 if (nbRows) {
                     QStringList titles = listRows.at(0);
-                    for (int j = 1; !err && j < nbRows; ++j) { //Forget title
+                    for (int j = 1; !err && j < nbRows; ++j) {  // Forget title
                         QStringList values = listRows.at(j);
 
                         QDomElement row = oDocument.createElement("row");
@@ -813,50 +842,52 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
                     listTables);
 
             nb = listTables.count();
-            for (int i = 1; !err && i < nb; ++i) { //Forget header
+            for (int i = 1; !err && i < nb; ++i) {  // Forget header
                 QString val = listTables.at(i).at(0);
                 err = SKGServices::executeSqliteOrder((iFromFileToMemory ? iMemoryDb : iFileDb), val);
             }
         }
-        //Attach db
+        // Attach db
         IFOK(err) {
             SKGTRACEINRC(10, "SKGServices::copySqliteDatabase-ATTACH", err);
             err = SKGServices::executeSqliteOrder(iMemoryDb, "ATTACH DATABASE '" % dbFileName % "' as source");
         }
 
-        //Copy records
+        // Copy records
         IFOK(err) {
             SKGTRACEINRC(10, "SKGServices::copySqliteDatabase-COPY", err);
             err = SKGServices::executeSqliteOrder(iMemoryDb, "BEGIN");
             IFOK(err) {
-                for (int i = 1; !err && i < nb; ++i) { //Forget header
+                for (int i = 1; !err && i < nb; ++i) {  // Forget header
                     QString val = listTables.at(i).at(1);
-                    if (iFromFileToMemory)  err = SKGServices::executeSqliteOrder(iMemoryDb, "insert into main." % val % " select * from source." % val);
-                    else  err = SKGServices::executeSqliteOrder(iMemoryDb, "insert into source." % val % " select * from main." % val);
+                    if (iFromFileToMemory)  {
+                        err = SKGServices::executeSqliteOrder(iMemoryDb, "insert into main." % val % " select * from source." % val);
+                    } else {
+                        err = SKGServices::executeSqliteOrder(iMemoryDb, "insert into source." % val % " select * from main." % val);
+                    }
                 }
-
             }
             SKGServices::executeSqliteOrder(iMemoryDb, "COMMIT");
         }
 
-        //Detach
+        // Detach
         {
             SKGTRACEINRC(10, "SKGServices::copySqliteDatabase-DETACH", err);
             SKGError err2 = SKGServices::executeSqliteOrder(iMemoryDb, "DETACH DATABASE source");
-            if (!err && err2) err = err2;
+            if (!err && err2) {
+                err = err2;
+            }
         }
 
-        //Optimization
+        // Optimization
         IFOK(err) {
-
             QStringList optimization;
             optimization << "PRAGMA case_sensitive_like=true"
                          << "PRAGMA journal_mode=MEMORY"
                          << "PRAGMA temp_store=MEMORY"
                          << "PRAGMA locking_mode=EXCLUSIVE"
                          << "PRAGMA synchronous = OFF"
-                         << "PRAGMA recursive_triggers=true"
-                         ;
+                         << "PRAGMA recursive_triggers=true";
             err = SKGServices::executeSqliteOrders(iFromFileToMemory ? iMemoryDb : iFileDb, optimization);
         }
 
@@ -869,7 +900,7 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
                     listSqlOrder);
 
             int nb2 = listSqlOrder.count();
-            for (int i = 1; !err && i < nb2; ++i) { //Forget header
+            for (int i = 1; !err && i < nb2; ++i) {  // Forget header
                 QString val = listSqlOrder.at(i).at(0);
                 err = SKGServices::executeSqliteOrder((iFromFileToMemory ? iMemoryDb : iFileDb), val);
             }
@@ -884,7 +915,7 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
                     listSqlOrder);
 
             int nb2 = listSqlOrder.count();
-            for (int i = 1; !err && i < nb2; ++i) { //Forget header
+            for (int i = 1; !err && i < nb2; ++i) {  // Forget header
                 QString val = listSqlOrder.at(i).at(0);
                 err = SKGServices::executeSqliteOrder((iFromFileToMemory ? iMemoryDb : iFileDb), val);
             }
@@ -899,16 +930,20 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
                     listSqlOrder);
 
             int nb2 = listSqlOrder.count();
-            for (int i = 1; !err && i < nb2; ++i) { //Forget header
+            for (int i = 1; !err && i < nb2; ++i) {  // Forget header
                 QString val = listSqlOrder.at(i).at(0);
                 err = SKGServices::executeSqliteOrder((iFromFileToMemory ? iMemoryDb : iFileDb), val);
             }
         }
 
-        //Check if created file exists
-        if (!err && !iFromFileToMemory && !QFile(dbFileName).exists()) err.setReturnCode(ERR_FAIL).setMessage(i18nc("An error message: creating a file failed", "Creation file '%1' failed", dbFileName));
+        // Check if created file exists
+        if (!err && !iFromFileToMemory && !QFile(dbFileName).exists()) {
+            err.setReturnCode(ERR_FAIL).setMessage(i18nc("An error message: creating a file failed", "Creation file '%1' failed", dbFileName));
+        }
+    }
+    IFKO(err) {
+        err.addError(SQLLITEERROR + ERR_FAIL, i18nc("Error message: something failed", "%1 failed", QString("SKGServices::copySqliteDatabase()")));
     }
-    IFKO(err) err.addError(SQLLITEERROR + ERR_FAIL, i18nc("Error message: something failed", "%1 failed", QString("SKGServices::copySqliteDatabase()")));
     return err;
 }
 
@@ -938,10 +973,10 @@ SKGError SKGServices::executeSqliteOrder(QSqlDatabase* iDb, const QString& iSqlO
         double elapse = 0;
         if (SKGServices::SKGSqlTraces != -1)  elapse = SKGServices::getMicroTime();
 
-        //Prepare sql order
+        // Prepare sql order
         bool prep = query.prepare(iSqlOrder);
 
-        //Bind values
+        // Bind values
         QMapIterator<QString, QVariant> i(iBind);
         while (i.hasNext()) {
             i.next();
@@ -983,15 +1018,17 @@ SKGError SKGServices::dumpSelectSqliteOrder(QSqlDatabase* iDb, const QString& iS
     _SKGTRACEINRC(10, "SKGServices::dumpSelectSqliteOrder(QSqlDatabase)", err);
     SKGTRACEL(20) << "Input parameter [iSqlOrder]=[" << iSqlOrder << ']' << endl;
 
-    //initialisation
+    // initialisation
     QStringList oResult;
     err = SKGServices::dumpSelectSqliteOrder(iDb, iSqlOrder, oResult, iMode);
     IFOK(err) {
-        //dump
+        // dump
         int nb = oResult.size();
         for (int i = 0; i < nb; ++i) {
             if (oStream == NULL)  SKGTRACESUITE << oResult.at(i) << endl;
-            else  *oStream << oResult.at(i) << endl;
+            else {
+                *oStream << oResult.at(i) << endl;
+            }
         }
     }
     return err;
@@ -1001,13 +1038,13 @@ SKGError SKGServices::dumpSelectSqliteOrder(QSqlDatabase* iDb, const QString& iS
 {
     SKGError err;
     _SKGTRACEINRC(10, "SKGServices::dumpSelectSqliteOrder(QSqlDatabase)", err);
-    //initialisation
+    // initialisation
     oResult = "";
 
     QStringList oResultTmp;
     err = SKGServices::dumpSelectSqliteOrder(iDb, iSqlOrder, oResultTmp, iMode);
     IFOK(err) {
-        //dump
+        // dump
         int nb = oResultTmp.size();
         for (int i = 0; i < nb; ++i) {
             oResult += oResultTmp.at(i) % '\n';
@@ -1021,7 +1058,7 @@ SKGError SKGServices::dumpSelectSqliteOrder(QSqlDatabase* iDb, const QString& iS
     SKGError err;
     _SKGTRACEINRC(10, "SKGServices::dumpSelectSqliteOrder(QSqlDatabase)", err);
 
-    //Execution of sql order
+    // Execution of sql order
     SKGStringListList oResultTmp;
     err = executeSelectSqliteOrder(iDb, iSqlOrder, oResultTmp);
     IFOK(err) oResult = tableToDump(oResultTmp, iMode);
@@ -1032,7 +1069,7 @@ SKGError SKGServices::executeSelectSqliteOrder(QSqlDatabase* iDb, const QString&
 {
     SKGError err;
     _SKGTRACEINRC(10, "SKGServices::executeSelectSqliteOrder(QSqlDatabase)", err);
-    //initialisation
+    // initialisation
     oResult.clear();
 
     if (iDb == NULL) err = SKGError(ERR_POINTER, i18nc("Error message", "No database defined"));
@@ -1056,7 +1093,7 @@ SKGError SKGServices::executeSelectSqliteOrder(QSqlDatabase* iDb, const QString&
                 }
             }
 
-            //Addition of column names
+            // Addition of column names
             QSqlRecord rec = query.record();
             QStringList line;
             int index = 0;
@@ -1071,7 +1108,7 @@ SKGError SKGServices::executeSelectSqliteOrder(QSqlDatabase* iDb, const QString&
             }
             oResult.push_back(line);
 
-            //Addition of rows
+            // Addition of rows
             while (query.next()) {
                 QStringList line2;
                 int index2 = 0;
@@ -1102,15 +1139,15 @@ SKGError SKGServices::readPropertyFile(const QString& iFileName, QHash< QString,
     SKGError err;
     oProperties.clear();
 
-    //Open file
+    // Open file
     QFile file(iFileName);
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
         err = SKGError(ERR_FAIL, i18nc("An erro message", "Open file '%1' failed", iFileName));
     } else {
-        //Read file
+        // Read file
         QTextStream stream(&file);
         while (!stream.atEnd() && !err) {
-            //Read line
+            // Read line
             QString line = stream.readLine().trimmed();
             if (!line.isEmpty() && !line.startsWith(QLatin1String("#"))) {
                 int pos = line.indexOf("=");
@@ -1120,7 +1157,7 @@ SKGError SKGServices::readPropertyFile(const QString& iFileName, QHash< QString,
             }
         }
 
-        //close file
+        // close file
         file.close();
     }
     return err;
@@ -1134,10 +1171,10 @@ double SKGServices::getMicroTime()
     struct timeval tv;
     struct timezone tz;
 
-    //get time
+    // get time
     gettimeofday(&tv, &tz);
 
-    //return time
+    // return time
     return (static_cast<double>(1000.0 * tv.tv_sec)) + (static_cast<double>(tv.tv_usec / 1000));
 #endif
 }
@@ -1146,7 +1183,7 @@ SKGStringListList SKGServices::getBase100Table(const SKGStringListList& iTable)
 {
     SKGTRACEIN(10, "SKGServices::getBase100Table");
 
-    //Build history
+    // Build history
     SKGStringListList output;
 
     output.push_back(iTable.at(0));
@@ -1157,7 +1194,7 @@ SKGStringListList SKGServices::getBase100Table(const SKGStringListList& iTable)
         nbCols = iTable.at(0).count();
     }
 
-    //Create table
+    // Create table
     for (int i = 1; i < nblines; ++i) {
         QStringList newLine;
         newLine.push_back(iTable.at(i).at(0));
@@ -1184,7 +1221,7 @@ SKGStringListList SKGServices::getPercentTable(const SKGStringListList& iTable,
 {
     SKGTRACEIN(10, "SKGServices::getPercentTable");
 
-    //Build history
+    // Build history
     SKGStringListList output;
 
     output.push_back(iTable.at(0));
@@ -1195,13 +1232,12 @@ SKGStringListList SKGServices::getPercentTable(const SKGStringListList& iTable,
         nbCols = iTable.at(0).count();
     }
 
-    //Compute sums
+    // Compute sums
     QList<double> sums;
     if (iOfColumns) {
-        //Compute sum of columns
+        // Compute sum of columns
         for (int j = 1; j < nbCols; ++j) {
-
-            //Compute sum
+            // Compute sum
             double sum = 0;
             for (int i = 1; i < nblines; ++i) {
                 double v = SKGServices::stringToDouble(iTable.at(i).at(j));
@@ -1211,10 +1247,9 @@ SKGStringListList SKGServices::getPercentTable(const SKGStringListList& iTable,
             sums.push_back(sum);
         }
     } else {
-        //Compute sum of lines
+        // Compute sum of lines
         for (int j = 1; j < nblines; ++j) {
-
-            //Compute sum
+            // Compute sum
             double sum = 0;
             for (int i = 1; i < nbCols; ++i) {
                 double v = SKGServices::stringToDouble(iTable.at(j).at(i));
@@ -1225,7 +1260,7 @@ SKGStringListList SKGServices::getPercentTable(const SKGStringListList& iTable,
         }
     }
 
-    //Create table
+    // Create table
     for (int i = 1; i < nblines; ++i) {
         QStringList newLine;
         newLine.push_back(iTable.at(i).at(0));
@@ -1246,7 +1281,7 @@ SKGStringListList SKGServices::getHistorizedTable(const SKGStringListList& iTabl
 {
     SKGTRACEIN(10, "SKGServices::getHistorizedTable");
 
-    //Build history
+    // Build history
     SKGStringListList output;
 
     output.push_back(iTable.at(0));
